@@ -141,13 +141,13 @@ public class DBHelper {
 		}
 		sql.append(")");
 
-		try (Connection c = getConnection();) {
+		try (Connection c = getConnection()) {
 
 			String sqlString = sql.toString();
 			UtilityLogger.log(sqlString);
 
 			ParameterMetaData parameters = null;
-			try (PreparedStatement st = c.prepareStatement(sqlString);) {
+			try (PreparedStatement st = c.prepareStatement(sqlString)) {
 				for (int i = 0; i < values.length; i++) {
 
 					if (values[i] == null) {
