@@ -19,9 +19,12 @@
 package org.apache.cayenne.dbsync.reverse.dbimport;
 
 import org.apache.cayenne.CayenneRuntimeException;
+import org.apache.cayenne.configuration.DataChannelDescriptorLoader;
+import org.apache.cayenne.configuration.DataMapLoader;
 import org.apache.cayenne.configuration.DataNodeDescriptor;
 import org.apache.cayenne.configuration.server.DataSourceFactory;
 import org.apache.cayenne.configuration.server.DbAdapterFactory;
+import org.apache.cayenne.configuration.xml.DataChannelMetaData;
 import org.apache.cayenne.dba.DbAdapter;
 import org.apache.cayenne.dbsync.DbSyncModule;
 import org.apache.cayenne.dbsync.filter.NamePatternMatcher;
@@ -45,21 +48,24 @@ import org.apache.cayenne.di.DIBootstrap;
 import org.apache.cayenne.di.Injector;
 import org.apache.cayenne.map.DataMap;
 import org.apache.cayenne.map.DbEntity;
-import org.apache.cayenne.map.MapLoader;
 import org.apache.cayenne.project.FileProjectSaver;
 import org.apache.cayenne.project.Project;
+import org.apache.cayenne.project.extension.ProjectExtension;
+import org.apache.cayenne.resource.Resource;
 import org.apache.cayenne.resource.URLResource;
 import org.apache.cayenne.util.Util;
 import org.slf4j.Logger;
 import org.junit.Before;
 import org.junit.Test;
-import org.xml.sax.InputSource;
 
 import javax.sql.DataSource;
 import java.io.File;
 import java.net.URL;
+import java.nio.charset.Charset;
+import java.nio.file.Files;
 import java.sql.Connection;
 import java.sql.SQLException;
+import java.util.Collections;
 import java.util.LinkedList;
 import java.util.List;
 
@@ -73,7 +79,7 @@ import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
-import static org.mockito.Matchers.any;
+import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.Mockito.doNothing;
 import static org.mockito.Mockito.doThrow;
 import static org.mockito.Mockito.mock;
@@ -129,7 +135,7 @@ public class DefaultDbImportActionTest {
         };
 
         final boolean[] haveWeTriedToSave = {false};
-        DefaultDbImportAction action = buildDbImportAction(new FileProjectSaver() {
+        DefaultDbImportAction action = buildDbImportAction(new FileProjectSaver(Collections.emptyList()) {
             @Override
             public void save(Project project) {
                 haveWeTriedToSave[0] = true;
@@ -175,7 +181,7 @@ public class DefaultDbImportActionTest {
 
         final boolean[] haveWeTriedToSave = {false};
         DefaultDbImportAction action = buildDbImportAction(
-            new FileProjectSaver() {
+            new FileProjectSaver(Collections.<ProjectExtension>emptyList()) {
                 @Override
                 public void save(Project project) {
                     haveWeTriedToSave[0] = true;
@@ -192,9 +198,9 @@ public class DefaultDbImportActionTest {
                 }
             },
 
-            new MapLoader() {
+            new DataMapLoader() {
                 @Override
-                public synchronized DataMap loadDataMap(InputSource src) throws CayenneRuntimeException {
+                public DataMap load(Resource configurationResource) throws CayenneRuntimeException {
                     return new DataMapBuilder().with(
                             dbEntity("ARTGROUP").attributes(
                                     dbAttr("GROUP_ID").typeInt().primaryKey(),
@@ -236,8 +242,8 @@ public class DefaultDbImportActionTest {
         FileProjectSaver projectSaver = mock(FileProjectSaver.class);
         doNothing().when(projectSaver).save(any(Project.class));
 
-        MapLoader mapLoader = mock(MapLoader.class);
-        when(mapLoader.loadDataMap(any(InputSource.class))).thenReturn(new DataMapBuilder().with(
+        DataMapLoader mapLoader = mock(DataMapLoader.class);
+        when(mapLoader.load(any(Resource.class))).thenReturn(new DataMapBuilder().with(
                 dbEntity("ARTGROUP").attributes(
                         dbAttr("NAME").typeVarchar(100).mandatory()
                 )).build());
@@ -248,7 +254,7 @@ public class DefaultDbImportActionTest {
 
         // no changes - we still
         verify(projectSaver, never()).save(any(Project.class));
-        verify(mapLoader, times(1)).loadDataMap(any(InputSource.class));
+        verify(mapLoader, times(1)).load(any(Resource.class));
     }
 
     @Test
@@ -261,8 +267,8 @@ public class DefaultDbImportActionTest {
         FileProjectSaver projectSaver = mock(FileProjectSaver.class);
         doNothing().when(projectSaver).save(any(Project.class));
 
-        MapLoader mapLoader = mock(MapLoader.class);
-        when(mapLoader.loadDataMap(any(InputSource.class))).thenReturn(null);
+        DataMapLoader mapLoader = mock(DataMapLoader.class);
+        when(mapLoader.load(any(Resource.class))).thenReturn(null);
 
         DefaultDbImportAction action = buildDbImportAction(projectSaver, mapLoader, dbLoader);
 
@@ -274,10 +280,10 @@ public class DefaultDbImportActionTest {
         }
 
         verify(projectSaver, never()).save(any(Project.class));
-        verify(mapLoader, never()).loadDataMap(any(InputSource.class));
+        verify(mapLoader, never()).load(any(Resource.class));
     }
 
-    private DefaultDbImportAction buildDbImportAction(FileProjectSaver projectSaver, MapLoader mapLoader, final DbLoader dbLoader)
+    private DefaultDbImportAction buildDbImportAction(FileProjectSaver projectSaver, DataMapLoader mapLoader, final DbLoader dbLoader)
             throws Exception {
 
         Logger log = mock(Logger.class);
@@ -292,11 +298,13 @@ public class DefaultDbImportActionTest {
         DataSourceFactory dataSourceFactory = mock(DataSourceFactory.class);
         DataSource mock = mock(DataSource.class);
         when(dataSourceFactory.getDataSource((DataNodeDescriptor)any())).thenReturn(mock);
-
+        DataChannelMetaData metaData = mock(DataChannelMetaData.class);
         MergerTokenFactoryProvider mergerTokenFactoryProvider = mock(MergerTokenFactoryProvider.class);
         when(mergerTokenFactoryProvider.get((DbAdapter)any())).thenReturn(new DefaultMergerTokenFactory());
 
-        return new DefaultDbImportAction(log, projectSaver, dataSourceFactory, adapterFactory, mapLoader, mergerTokenFactoryProvider) {
+        DataChannelDescriptorLoader dataChannelDescriptorLoader = mock(DataChannelDescriptorLoader.class);
+
+        return new DefaultDbImportAction(log, projectSaver, dataSourceFactory, adapterFactory, mapLoader, mergerTokenFactoryProvider, dataChannelDescriptorLoader, metaData) {
 
             protected DbLoader createDbLoader(DbAdapter adapter,
                                                Connection connection,
@@ -306,26 +314,32 @@ public class DefaultDbImportActionTest {
         };
     }
 
-    @Test
-    public void testSaveLoaded() throws Exception {
-        Logger log = mock(Logger.class);
-        Injector i = DIBootstrap.createInjector(new DbSyncModule(), new ToolsModule(log), new DbImportModule());
-
-        DefaultDbImportAction action = (DefaultDbImportAction) i.getInstance(DbImportAction.class);
-
+    private URL getPackageURL() {
         String packagePath = getClass().getPackage().getName().replace('.', '/');
         URL packageUrl = getClass().getClassLoader().getResource(packagePath);
         assertNotNull(packageUrl);
-        URL outUrl = new URL(packageUrl, "dbimport/testSaveLoaded1.map.xml");
+        return packageUrl;
+    }
+
+    @Test
+    public void testSaveLoadedNoProject() throws Exception {
+        Logger log = mock(Logger.class);
+        Injector i = DIBootstrap.createInjector(new DbSyncModule(), new ToolsModule(log), new DbImportModule());
+        DbImportConfiguration params = mock(DbImportConfiguration.class);
+        when(params.getCayenneProject()).thenReturn(null);
+
+        URL outUrl = new URL(getPackageURL(), "dbimport/testSaveLoaded1.map.xml");
+
+        DefaultDbImportAction action = (DefaultDbImportAction) i.getInstance(DbImportAction.class);
 
         File out = new File(outUrl.toURI());
         out.delete();
-        assertFalse(out.isFile());
+        assertFalse(out.exists());
 
         DataMap map = new DataMap("testSaveLoaded1");
         map.setConfigurationSource(new URLResource(outUrl));
 
-        action.saveLoaded(map);
+        action.saveLoaded(map, params);
 
         assertTrue(out.isFile());
 
@@ -333,6 +347,145 @@ public class DefaultDbImportActionTest {
         assertTrue("Has no project version saved", contents.contains("project-version=\""));
     }
 
+    @Test
+    public void testSaveLoadedWithEmptyProject() throws Exception {
+        Logger log = mock(Logger.class);
+        Injector i = DIBootstrap.createInjector(new DbSyncModule(), new ToolsModule(log), new DbImportModule());
+        DbImportConfiguration params = mock(DbImportConfiguration.class);
+
+        URL projectURL = new URL(getPackageURL(), "dbimport/cayenne-testProject2.map.xml");
+        File projectFile = new File(projectURL.toURI());
+        projectFile.delete();
+        assertFalse(projectFile.exists());
+        when(params.getCayenneProject()).thenReturn(projectFile);
+
+        DefaultDbImportAction action = (DefaultDbImportAction) i.getInstance(DbImportAction.class);
+
+        URL dataMapURL = new URL(getPackageURL(), "dbimport/testSaveLoaded2.map.xml");
+
+        File dataMapFile = new File(dataMapURL.toURI());
+        dataMapFile.delete();
+        assertFalse(dataMapFile.exists());
+
+        DataMap map = new DataMap("testSaveLoaded2");
+        map.setConfigurationSource(new URLResource(dataMapURL));
+
+        action.saveLoaded(map, params);
+
+        assertTrue(dataMapFile.isFile());
+        assertTrue(projectFile.isFile());
+
+        String dataMapContents = Util.stringFromFile(dataMapFile);
+        assertTrue("Has no project version saved", dataMapContents.contains("project-version=\""));
+
+        String projectContents = Util.stringFromFile(projectFile);
+        assertTrue("Has no project version saved", projectContents.contains("project-version=\""));
+        assertTrue("Has no datamap in project", projectContents.contains("<map name=\"testSaveLoaded2\"/>"));
+    }
+
+    @Test
+    public void testSaveLoadedWithNonEmptyProject() throws Exception {
+        Logger log = mock(Logger.class);
+        Injector i = DIBootstrap.createInjector(new DbSyncModule(), new ToolsModule(log), new DbImportModule());
+        DbImportConfiguration params = mock(DbImportConfiguration.class);
+
+        URL projectURL = new URL(getPackageURL(), "dbimport/cayenne-testProject3.map.xml");
+        File projectFile = new File(projectURL.toURI());
+        projectFile.delete();
+        assertFalse(projectFile.exists());
+
+        Files.write(projectFile.toPath(), ("<?xml version=\"1.0\" encoding=\"utf-8\"?>\n" +
+                "<domain xmlns=\"http://cayenne.apache.org/schema/10/domain\"\n" +
+                "\t xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\"\n" +
+                "\t xsi:schemaLocation=\"http://cayenne.apache.org/schema/10/domain https://cayenne.apache.org/schema/10/domain.xsd\"\n" +
+                "\t project-version=\"10\">\n" +
+                "</domain>").getBytes(Charset.forName("UTF-8")));
+        assertTrue(projectFile.isFile());
+
+        when(params.getCayenneProject()).thenReturn(projectFile);
+
+        DefaultDbImportAction action = (DefaultDbImportAction) i.getInstance(DbImportAction.class);
+
+        URL dataMapURL = new URL(getPackageURL(), "dbimport/testSaveLoaded3.map.xml");
+
+        File dataMapFile = new File(dataMapURL.toURI());
+        dataMapFile.delete();
+        assertFalse(dataMapFile.exists());
+
+        DataMap map = new DataMap("testSaveLoaded3");
+        map.setConfigurationSource(new URLResource(dataMapURL));
+
+        action.saveLoaded(map, params);
+
+        assertTrue(dataMapFile.isFile());
+        assertTrue(projectFile.isFile());
+
+        String dataMapContents = Util.stringFromFile(dataMapFile);
+        assertTrue("Has no project version saved", dataMapContents.contains("project-version=\""));
+
+        String projectContents = Util.stringFromFile(projectFile);
+        assertTrue("Has no project version saved", projectContents.contains("project-version=\""));
+        assertTrue("Has no datamap in project", projectContents.contains("<map name=\"testSaveLoaded3\"/>"));
+    }
+
+    @Test
+    public void testSaveLoadedWithNonEmptyProjectAndNonEmptyDataMap() throws Exception {
+        Logger log = mock(Logger.class);
+        Injector i = DIBootstrap.createInjector(new DbSyncModule(), new ToolsModule(log), new DbImportModule());
+        DbImportConfiguration params = mock(DbImportConfiguration.class);
+
+        URL projectURL = new URL(getPackageURL(), "dbimport/cayenne-testProject4.map.xml");
+        File projectFile = new File(projectURL.toURI());
+        projectFile.delete();
+        assertFalse(projectFile.exists());
+
+        Files.write(projectFile.toPath(), ("<?xml version=\"1.0\" encoding=\"utf-8\"?>\n" +
+                "<domain xmlns=\"http://cayenne.apache.org/schema/10/domain\"\n" +
+                "\t xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\"\n" +
+                "\t xsi:schemaLocation=\"http://cayenne.apache.org/schema/10/domain https://cayenne.apache.org/schema/10/domain.xsd\"\n" +
+                "\t project-version=\"10\">\n" +
+                "\t<map name=\"testSaveLoaded4\"/>\n" +
+                "</domain>").getBytes(Charset.forName("UTF-8")));
+        assertTrue(projectFile.isFile());
+
+        when(params.getCayenneProject()).thenReturn(projectFile);
+
+        DefaultDbImportAction action = (DefaultDbImportAction) i.getInstance(DbImportAction.class);
+
+        URL dataMapURL = new URL(getPackageURL(), "dbimport/testSaveLoaded4.map.xml");
+
+        File dataMapFile = new File(dataMapURL.toURI());
+        dataMapFile.delete();
+        assertFalse(dataMapFile.exists());
+
+        Files.write(dataMapFile.toPath(), ("<?xml version=\"1.0\" encoding=\"utf-8\"?>\n" +
+                "<data-map xmlns=\"http://cayenne.apache.org/schema/10/modelMap\"\n" +
+                "\t xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\"\n" +
+                "\t xsi:schemaLocation=\"http://cayenne.apache.org/schema/10/modelMap https://cayenne.apache.org/schema/10/modelMap.xsd\"\n" +
+                "\t project-version=\"10\">\n" +
+                "\t<db-entity name=\"test\">\n" +
+                "\t\t<db-attribute name=\"test\" type=\"INT\"/>\n" +
+                "\t</db-entity>\n" +
+                "</data-map>").getBytes(Charset.forName("UTF-8")));
+        assertTrue(dataMapFile.isFile());
+
+        DataMap map = new DataMap("testSaveLoaded4");
+        map.setConfigurationSource(new URLResource(dataMapURL));
+
+        action.saveLoaded(map, params);
+
+        assertTrue(dataMapFile.isFile());
+        assertTrue(projectFile.isFile());
+
+        String dataMapContents = Util.stringFromFile(dataMapFile);
+        assertTrue("Has no project version saved", dataMapContents.contains("project-version=\""));
+        assertFalse(dataMapContents.contains("<db-entity"));
+
+        String projectContents = Util.stringFromFile(projectFile);
+        assertTrue("Has no project version saved", projectContents.contains("project-version=\""));
+        assertEquals("Has no or too many datamaps in project", 1, Util.countMatches(projectContents, "<map name=\"testSaveLoaded4\"/>"));
+    }
+
     @Test
     public void testMergeTokensSorting() {
         LinkedList<MergerToken> tokens = new LinkedList<MergerToken>();
