@@ -19,9 +19,7 @@
 package org.apache.cayenne.lifecycle.db;
 
 import org.apache.cayenne.lifecycle.db.auto._SortRoot;
-import org.apache.cayenne.lifecycle.sort.SortWeight;
 
-@SortWeight(2)
 public class SortRoot extends _SortRoot {
 	private static final long serialVersionUID = 1L;
 }
