@@ -44,7 +44,6 @@ import org.apache.cayenne.ResultIterator;
 import org.apache.cayenne.access.util.IteratedSelectObserver;
 import org.apache.cayenne.di.Injector;
 import org.apache.cayenne.event.EventManager;
-import org.apache.cayenne.event.NoopEventManager;
 import org.apache.cayenne.graph.ChildDiffLoader;
 import org.apache.cayenne.graph.CompoundDiff;
 import org.apache.cayenne.graph.GraphDiff;
@@ -54,12 +53,7 @@ import org.apache.cayenne.map.DbRelationship;
 import org.apache.cayenne.map.ObjAttribute;
 import org.apache.cayenne.map.ObjEntity;
 import org.apache.cayenne.map.ObjRelationship;
-import org.apache.cayenne.query.EntityResultSegment;
-import org.apache.cayenne.query.MappedExec;
-import org.apache.cayenne.query.MappedSelect;
-import org.apache.cayenne.query.Query;
-import org.apache.cayenne.query.QueryMetadata;
-import org.apache.cayenne.query.Select;
+import org.apache.cayenne.query.*;
 import org.apache.cayenne.reflect.AttributeProperty;
 import org.apache.cayenne.reflect.ClassDescriptor;
 import org.apache.cayenne.reflect.PropertyVisitor;
@@ -146,7 +140,7 @@ public class DataContext extends BaseContext {
 
         EventManager eventManager = channel.getEventManager();
 
-        if (eventManager != null && !(eventManager instanceof NoopEventManager)) {
+        if (eventManager != null) {
             mergeHandler = new DataContextMergeHandler(this);
 
             // listen to our channel events...
@@ -869,7 +863,7 @@ public class DataContext extends BaseContext {
             Transaction tx = getTransactionFactory().createTransaction();
             BaseTransaction.bindThreadTransaction(tx);
 
-            ResultIterator result;
+            ResultIterator<?> result;
             try {
                 result = internalPerformIteratedQuery(query);
             } catch (Exception e) {
@@ -895,7 +889,7 @@ public class DataContext extends BaseContext {
                 }
             }
 
-            return new TransactionResultIteratorDecorator(result, tx);
+            return new TransactionResultIteratorDecorator<>(result, tx);
         }
     }
 
@@ -1070,7 +1064,6 @@ public class DataContext extends BaseContext {
         synchronized (getObjectStore()) {
             out.defaultWriteObject();
         }
-
         // Serialize local snapshots cache
         if (!isUsingSharedSnapshotCache()) {
             out.writeObject(objectStore.getDataRowCache());
