@@ -152,7 +152,7 @@ public class DefaultSelectTranslator extends QueryAssembler implements SelectTra
 		StringBuilder whereQualifierBuffer = qualifierTranslator.appendPart(new StringBuilder());
 
 		// build having qualifier
-		Expression havingQualifier = ((SelectQuery)query).getHavingQualifier();
+		Expression havingQualifier = getSelectQuery().getHavingQualifier();
 		StringBuilder havingQualifierBuffer = null;
 		if(havingQualifier != null) {
 			haveAggregate = true;
@@ -261,6 +261,10 @@ public class DefaultSelectTranslator extends QueryAssembler implements SelectTra
 	 * Warn user in case query uses both limit and joint prefetch, as we don't support this combination.
 	 */
 	private void checkLimitAndJointPrefetch() {
+		if(queryMetadata.getPrefetchTree() == null) {
+			return;
+		}
+
 		if(queryMetadata.getFetchLimit() == 0 && queryMetadata.getFetchOffset() == 0) {
 			return;
 		}
@@ -427,13 +431,8 @@ public class DefaultSelectTranslator extends QueryAssembler implements SelectTra
 		QualifierTranslator qualifierTranslator = adapter.getQualifierTranslator(this);
 		AccumulatingBindingListener bindingListener = new AccumulatingBindingListener();
 		final String[] joinTableAliasForProperty = {null};
-		joinListener = new AddJoinListener() {
-			@Override
-			public void joinAdded() {
-				// capture last alias for joined table, will use it to resolve object columns
-				joinTableAliasForProperty[0] = getCurrentAlias();
-			}
-		};
+		// capture last alias for joined table, will use it to resolve object columns
+		joinListener = () -> joinTableAliasForProperty[0] = getCurrentAlias();
 		setAddBindingListener(bindingListener);
 
 		for(Property<?> property : query.getColumns()) {
@@ -625,6 +624,19 @@ public class DefaultSelectTranslator extends QueryAssembler implements SelectTra
 
 			public boolean visitToOne(ToOneProperty property) {
 				visitRelationship(property);
+
+				// add PKs for flattened tables in flattened path
+				ObjRelationship rel = property.getRelationship();
+				for(int i=0; i<rel.getDbRelationships().size() - 1; i++) {
+					DbRelationship dbRel = rel.getDbRelationships().get(i);
+					dbRelationshipAdded(dbRel, JoinType.LEFT_OUTER, null);
+
+					// append path PK attributes
+					for(DbAttribute dba : dbRel.getTargetEntity().getPrimaryKeys()) {
+						appendColumn(columns, null, dba, attributes, dbRel.getName() + '.' + dba.getName());
+					}
+				}
+
 				return true;
 			}
 
@@ -659,7 +671,7 @@ public class DefaultSelectTranslator extends QueryAssembler implements SelectTra
 		if (query instanceof PrefetchSelectQuery) {
 
 			// for each relationship path add PK of the target entity...
-			for (String path : ((PrefetchSelectQuery) query).getResultPaths()) {
+			for (String path : ((PrefetchSelectQuery<?>) query).getResultPaths()) {
 
 				ASTDbPath pathExp = (ASTDbPath) oe.translateToDbPath(ExpressionFactory.exp(path));
 
@@ -744,7 +756,7 @@ public class DefaultSelectTranslator extends QueryAssembler implements SelectTra
 				ObjRelationship targetRel = (ObjRelationship) prefetchExp.evaluate(oe);
 				ObjEntity targetEntity = targetRel.getTargetEntity();
 
-				final String labelPrefix = dbPrefetch.getPath();
+				String labelPrefix = dbPrefetch.getPath();
 
 				PropertyVisitor prefetchVisitor = new PropertyVisitor() {
 					public boolean visitAttribute(AttributeProperty property) {
@@ -890,7 +902,7 @@ public class DefaultSelectTranslator extends QueryAssembler implements SelectTra
 
 	@Override
 	public String getAliasForExpression(Expression exp) {
-		Collection<Property<?>> columns = ((SelectQuery<?>)query).getColumns();
+		Collection<Property<?>> columns = getSelectQuery().getColumns();
 		if(columns == null) {
 			return null;
 		}
@@ -966,9 +978,6 @@ public class DefaultSelectTranslator extends QueryAssembler implements SelectTra
 		}
 
 		public boolean haveJointNode(PrefetchTreeNode prefetchTree) {
-			if(prefetchTree == null) {
-				return false;
-			}
 			haveJointNode = false;
 			prefetchTree.traverse(this);
 			return haveJointNode;
