@@ -19,6 +19,7 @@
 package org.apache.cayenne.access;
 
 import org.apache.cayenne.ObjectContext;
+import org.apache.cayenne.configuration.server.ServerRuntime;
 import org.apache.cayenne.di.Inject;
 import org.apache.cayenne.query.EJBQLQuery;
 import org.apache.cayenne.query.ObjectSelect;
@@ -30,8 +31,7 @@ import org.apache.cayenne.testdo.inheritance_vertical.*;
 import org.apache.cayenne.unit.di.server.CayenneProjects;
 import org.apache.cayenne.unit.di.server.ServerCase;
 import org.apache.cayenne.unit.di.server.UseServerRuntime;
-import org.apache.cayenne.validation.ValidationException;
-import org.junit.Ignore;
+import org.junit.Before;
 import org.junit.Test;
 
 import java.sql.SQLException;
@@ -43,6 +43,7 @@ import java.util.Map;
 
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNotSame;
 import static org.junit.Assert.assertNull;
 import static org.junit.Assert.assertTrue;
 
@@ -55,12 +56,46 @@ public class VerticalInheritanceIT extends ServerCase {
 	@Inject
 	protected DBHelper dbHelper;
 
+	@Inject
+	protected ServerRuntime runtime;
+
+	private TableHelper ivRootTable;
+	private TableHelper ivSub1Table;
+	private TableHelper ivSub2Table;
+	private TableHelper ivSub3Table;
+	private TableHelper ivSub1Sub1Table;
+	private TableHelper iv1RootTable;
+	private TableHelper iv1Sub1Table;
+
+
+	@Before
+	public void createTableHelpers() {
+		ivRootTable = new TableHelper(dbHelper, "IV_ROOT");
+		ivRootTable.setColumns("ID", "NAME", "DISCRIMINATOR").setColumnTypes(
+				Types.INTEGER, Types.VARCHAR, Types.VARCHAR);
+
+		ivSub1Table = new TableHelper(dbHelper, "IV_SUB1");
+		ivSub1Table.setColumns("ID", "SUB1_NAME");
+
+		ivSub2Table = new TableHelper(dbHelper, "IV_SUB2");
+		ivSub2Table.setColumns("ID", "SUB2_NAME", "SUB2_ATTR");
+
+		ivSub3Table = new TableHelper(dbHelper, "IV_SUB3");
+		ivSub3Table.setColumns("ID", "IV_ROOT_ID");
+
+		ivSub1Sub1Table = new TableHelper(dbHelper, "IV_SUB1_SUB1");
+		ivSub1Sub1Table.setColumns("ID", "SUB1_SUB1_NAME");
+
+		iv1RootTable = new TableHelper(dbHelper, "IV1_ROOT");
+		iv1RootTable.setColumns("ID", "NAME", "DISCRIMINATOR").setColumnTypes(
+				Types.INTEGER, Types.VARCHAR, Types.VARCHAR);
+
+		iv1Sub1Table = new TableHelper(dbHelper, "IV1_SUB1");
+		iv1Sub1Table.setColumns("ID", "SUB1_NAME");
+	}
+
     @Test
 	public void testInsert_Root() throws Exception {
-
-		TableHelper ivRootTable = new TableHelper(dbHelper, "IV_ROOT");
-		ivRootTable.setColumns("ID", "NAME", "DISCRIMINATOR");
-
 		assertEquals(0, ivRootTable.getRowCount());
 
 		IvRoot root = context.newObject(IvRoot.class);
@@ -79,13 +114,6 @@ public class VerticalInheritanceIT extends ServerCase {
 
     @Test
 	public void testInsert_Sub1() throws Exception {
-
-		TableHelper ivRootTable = new TableHelper(dbHelper, "IV_ROOT");
-		ivRootTable.setColumns("ID", "NAME", "DISCRIMINATOR");
-
-		TableHelper ivSub1Table = new TableHelper(dbHelper, "IV_SUB1");
-		ivSub1Table.setColumns("ID", "SUB1_NAME");
-
 		IvSub1 sub1 = context.newObject(IvSub1.class);
 		sub1.setName("XyZX");
 		sub1.getObjectContext().commitChanges();
@@ -128,13 +156,6 @@ public class VerticalInheritanceIT extends ServerCase {
 
     @Test
 	public void testInsert_Sub2() throws Exception {
-
-		TableHelper ivRootTable = new TableHelper(dbHelper, "IV_ROOT");
-		ivRootTable.setColumns("ID", "NAME", "DISCRIMINATOR");
-
-		TableHelper ivSub2Table = new TableHelper(dbHelper, "IV_SUB2");
-		ivSub2Table.setColumns("ID", "SUB2_NAME", "SUB2_ATTR");
-
 		IvSub2 sub2 = context.newObject(IvSub2.class);
 		sub2.setName("XyZX");
 		sub2.getObjectContext().commitChanges();
@@ -197,14 +218,7 @@ public class VerticalInheritanceIT extends ServerCase {
 	 * @link https://issues.apache.org/jira/browse/CAY-2146
 	 */
     @Test(expected = org.apache.cayenne.validation.ValidationException.class)
-    public void testValidationOnInsert_Sub3_Exception() throws Exception {
-
-        TableHelper ivRootTable = new TableHelper(dbHelper, "IV_ROOT");
-        ivRootTable.setColumns("ID", "NAME", "DISCRIMINATOR");
-
-        TableHelper ivSub3Table = new TableHelper(dbHelper, "IV_SUB3");
-        ivSub3Table.setColumns("ID", "IV_ROOT_ID");
-
+    public void testValidationOnInsert_Sub3_Exception() {
         IvSub3 sub3 = context.newObject(IvSub3.class);
         sub3.setName("XyZX");
 		context.commitChanges();
@@ -215,13 +229,6 @@ public class VerticalInheritanceIT extends ServerCase {
 	 */
 	@Test
 	public void testValidationOnInsert_Sub3_Ok() throws Exception {
-
-		TableHelper ivRootTable = new TableHelper(dbHelper, "IV_ROOT");
-		ivRootTable.setColumns("ID", "NAME", "DISCRIMINATOR");
-
-		TableHelper ivSub3Table = new TableHelper(dbHelper, "IV_SUB3");
-		ivSub3Table.setColumns("ID", "IV_ROOT_ID");
-
 		IvSub3 sub3 = context.newObject(IvSub3.class);
 		sub3.setName("XyZX");
 		sub3.setIvRoot(sub3);
@@ -234,17 +241,12 @@ public class VerticalInheritanceIT extends ServerCase {
 	/**
 	 * @link https://issues.apache.org/jira/browse/CAY-2282
 	 */
-	@Ignore("Test case for unfixed issue CAY-2282")
 	@Test
 	public void testUpdateRelation_Sub3() throws Exception {
-		TableHelper ivRootTable = new TableHelper(dbHelper, "IV_ROOT");
-		ivRootTable.setColumns("ID", "NAME", "DISCRIMINATOR");
-		ivRootTable.insert(1, null, null);
-		ivRootTable.insert(2, null, null);
+		ivRootTable.insert(1, "root1", null);
+		ivRootTable.insert(2, "root2", null);
 		ivRootTable.insert(3, "name", "IvSub3");
 
-		TableHelper ivSub3Table = new TableHelper(dbHelper, "IV_SUB3");
-		ivSub3Table.setColumns("ID", "IV_ROOT_ID");
 		ivSub3Table.insert(3, 1);
 
 		IvRoot root = SelectById.query(IvRoot.class, 2).selectOne(context);
@@ -255,20 +257,21 @@ public class VerticalInheritanceIT extends ServerCase {
 		// this will create 3 queries...
 		// update for name, insert for new relationship, delete for old relationship
 		context.commitChanges();
+
+		ObjectContext cleanContext = runtime.newContext();
+		IvSub3 sub3Clean = SelectById.query(IvSub3.class, 3).selectOne(cleanContext);
+
+		assertNotNull(sub3Clean);
+		assertNotSame(sub3, sub3Clean);
+
+		assertEquals("new name", sub3.getName());
+		assertNotNull(sub3Clean.getIvRoot());
+		assertEquals("root2", sub3Clean.getIvRoot().getName());
+
 	}
 
     @Test
 	public void testInsert_Sub1Sub1() throws Exception {
-
-		TableHelper ivRootTable = new TableHelper(dbHelper, "IV_ROOT");
-		ivRootTable.setColumns("ID", "NAME", "DISCRIMINATOR");
-
-		TableHelper ivSub1Table = new TableHelper(dbHelper, "IV_SUB1");
-		ivSub1Table.setColumns("ID", "SUB1_NAME");
-
-		TableHelper ivSub1Sub1Table = new TableHelper(dbHelper, "IV_SUB1_SUB1");
-		ivSub1Sub1Table.setColumns("ID", "SUB1_SUB1_NAME");
-
 		IvSub1Sub1 sub1Sub1 = context.newObject(IvSub1Sub1.class);
 		sub1Sub1.setName("XyZN");
 		sub1Sub1.setSub1Name("mDA");
@@ -299,21 +302,13 @@ public class VerticalInheritanceIT extends ServerCase {
 
     @Test
 	public void testSelectQuery_SuperSub() throws Exception {
-
-		TableHelper ivRootTable = new TableHelper(dbHelper, "IV_ROOT");
-		ivRootTable.setColumns("ID", "NAME", "DISCRIMINATOR").setColumnTypes(
-				Types.INTEGER, Types.VARCHAR, Types.VARCHAR);
-
-		TableHelper ivSub1Table = new TableHelper(dbHelper, "IV_SUB1");
-		ivSub1Table.setColumns("ID", "SUB1_NAME");
-
 		// insert
 		ivRootTable.insert(1, "xROOT", null);
 		ivRootTable.insert(2, "xSUB1_ROOT", "IvSub1");
 		ivSub1Table.insert(2, "xSUB1");
 
-		SelectQuery query = new SelectQuery(IvRoot.class);
-		List<IvRoot> results = context.performQuery(query);
+		SelectQuery<IvRoot> query = new SelectQuery<>(IvRoot.class);
+		List<IvRoot> results = context.select(query);
 
 		assertEquals(2, results.size());
 
@@ -341,20 +336,6 @@ public class VerticalInheritanceIT extends ServerCase {
 
     @Test
 	public void testSelectQuery_DeepAndWide() throws Exception {
-
-		TableHelper ivRootTable = new TableHelper(dbHelper, "IV_ROOT");
-		ivRootTable.setColumns("ID", "NAME", "DISCRIMINATOR").setColumnTypes(
-				Types.INTEGER, Types.VARCHAR, Types.VARCHAR);
-
-		TableHelper ivSub1Table = new TableHelper(dbHelper, "IV_SUB1");
-		ivSub1Table.setColumns("ID", "SUB1_NAME");
-
-		TableHelper ivSub2Table = new TableHelper(dbHelper, "IV_SUB2");
-		ivSub2Table.setColumns("ID", "SUB2_NAME");
-
-		TableHelper ivSub1Sub1Table = new TableHelper(dbHelper, "IV_SUB1_SUB1");
-		ivSub1Sub1Table.setColumns("ID", "SUB1_SUB1_NAME");
-
 		// insert
 		ivRootTable.insert(1, "xROOT", null);
 
@@ -366,10 +347,10 @@ public class VerticalInheritanceIT extends ServerCase {
 		ivSub1Sub1Table.insert(3, "xSUB1_SUB1");
 
 		ivRootTable.insert(4, "xROOT_SUB2", "IvSub2");
-		ivSub2Table.insert(4, "xSUB2");
+		ivSub2Table.insert(4, "xSUB2", "");
 
-		SelectQuery query = new SelectQuery(IvRoot.class);
-		List<IvRoot> results = context.performQuery(query);
+		SelectQuery<IvRoot> query = new SelectQuery<>(IvRoot.class);
+		List<IvRoot> results = context.select(query);
 
 		assertEquals(4, results.size());
 
@@ -411,20 +392,6 @@ public class VerticalInheritanceIT extends ServerCase {
 
     @Test
 	public void testSelectQuery_MiddleLeaf() throws Exception {
-
-		TableHelper ivRootTable = new TableHelper(dbHelper, "IV_ROOT");
-		ivRootTable.setColumns("ID", "NAME", "DISCRIMINATOR").setColumnTypes(
-				Types.INTEGER, Types.VARCHAR, Types.VARCHAR);
-
-		TableHelper ivSub1Table = new TableHelper(dbHelper, "IV_SUB1");
-		ivSub1Table.setColumns("ID", "SUB1_NAME");
-
-		TableHelper ivSub2Table = new TableHelper(dbHelper, "IV_SUB2");
-		ivSub2Table.setColumns("ID", "SUB2_NAME");
-
-		TableHelper ivSub1Sub1Table = new TableHelper(dbHelper, "IV_SUB1_SUB1");
-		ivSub1Sub1Table.setColumns("ID", "SUB1_SUB1_NAME");
-
 		// insert
 		ivRootTable.insert(1, "xROOT", null);
 
@@ -436,10 +403,10 @@ public class VerticalInheritanceIT extends ServerCase {
 		ivSub1Sub1Table.insert(3, "xSUB1_SUB1");
 
 		ivRootTable.insert(4, "xROOT_SUB2", "IvSub2");
-		ivSub2Table.insert(4, "xSUB2");
+		ivSub2Table.insert(4, "xSUB2", "");
 
-		SelectQuery query = new SelectQuery(IvSub1.class);
-		List<IvRoot> results = context.performQuery(query);
+		SelectQuery<IvSub1> query = new SelectQuery<>(IvSub1.class);
+		List<IvSub1> results = context.select(query);
 
 		assertEquals(2, results.size());
 
@@ -470,20 +437,6 @@ public class VerticalInheritanceIT extends ServerCase {
 
     @Test
 	public void testDelete_Mix() throws Exception {
-
-		TableHelper ivRootTable = new TableHelper(dbHelper, "IV_ROOT");
-		ivRootTable.setColumns("ID", "NAME", "DISCRIMINATOR").setColumnTypes(
-				Types.INTEGER, Types.VARCHAR, Types.VARCHAR);
-
-		TableHelper ivSub1Table = new TableHelper(dbHelper, "IV_SUB1");
-		ivSub1Table.setColumns("ID", "SUB1_NAME");
-
-		TableHelper ivSub2Table = new TableHelper(dbHelper, "IV_SUB2");
-		ivSub2Table.setColumns("ID", "SUB2_NAME");
-
-		TableHelper ivSub1Sub1Table = new TableHelper(dbHelper, "IV_SUB1_SUB1");
-		ivSub1Sub1Table.setColumns("ID", "SUB1_SUB1_NAME");
-
 		// insert
 		ivRootTable.insert(1, "xROOT", null);
 
@@ -495,11 +448,11 @@ public class VerticalInheritanceIT extends ServerCase {
 		ivSub1Sub1Table.insert(3, "xSUB1_SUB1");
 
 		ivRootTable.insert(4, "xROOT_SUB2", "IvSub2");
-		ivSub2Table.insert(4, "xSUB2");
+		ivSub2Table.insert(4, "xSUB2", "");
 
-		SelectQuery query = new SelectQuery(IvRoot.class);
+		SelectQuery<IvRoot> query = new SelectQuery<>(IvRoot.class);
 
-		List<IvRoot> results = context.performQuery(query);
+		List<IvRoot> results = context.select(query);
 
 		assertEquals(4, results.size());
 		Map<String, IvRoot> resultTypes = new HashMap<>();
@@ -523,27 +476,19 @@ public class VerticalInheritanceIT extends ServerCase {
 		assertEquals(1, ivSub1Sub1Table.getRowCount());
 		assertEquals(1, ivSub2Table.getRowCount());
 
-		results = context.performQuery(query);
+		results = context.select(query);
 		assertEquals(2, results.size());
 	}
 
     @Test
 	public void testSelectQuery_AttributeOverrides() throws Exception {
-
-		TableHelper iv1RootTable = new TableHelper(dbHelper, "IV1_ROOT");
-		iv1RootTable.setColumns("ID", "NAME", "DISCRIMINATOR").setColumnTypes(
-				Types.INTEGER, Types.VARCHAR, Types.VARCHAR);
-
-		TableHelper iv1Sub1Table = new TableHelper(dbHelper, "IV1_SUB1");
-		iv1Sub1Table.setColumns("ID", "SUB1_NAME");
-
 		// insert
 		iv1RootTable.insert(1, "xROOT", null);
 		iv1RootTable.insert(2, "xSUB1_ROOT", "Iv1Sub1");
 		iv1Sub1Table.insert(2, "xSUB1");
 
-		SelectQuery query = new SelectQuery(Iv1Root.class);
-		List<Iv1Root> results = context.performQuery(query);
+		SelectQuery<Iv1Root> query = new SelectQuery<>(Iv1Root.class);
+		List<Iv1Root> results = context.select(query);
 
 		assertEquals(2, results.size());
 
@@ -614,7 +559,7 @@ public class VerticalInheritanceIT extends ServerCase {
 		context.commitChanges();
 	}
 
-	@Test(expected = ValidationException.class) // other2 is missing now
+	@Test//(expected = ValidationException.class) // other2 is not mandatory for now
 	public void testInsertWithAttributeAndRelationship() {
 		IvOther other = context.newObject(IvOther.class);
 		other.setName("other");
@@ -676,51 +621,6 @@ public class VerticalInheritanceIT extends ServerCase {
 		assertEquals(2, ObjectSelect.query(IvImpl.class).selectCount(context));
 	}
 
-	/**
-	 * @link https://issues.apache.org/jira/browse/CAY-2282
-	 */
-	@Ignore("Test case for unfixed issue CAY-2282")
-	@Test
-	public void testUpdateTwoObjectsWithMultipleAttributeAndMultipleRelationship() throws SQLException {
-		TableHelper ivOtherTable = new TableHelper(dbHelper, "IV_OTHER");
-		ivOtherTable.setColumns("ID", "NAME").setColumnTypes(Types.INTEGER, Types.VARCHAR);
-
-		TableHelper ivBaseTable = new TableHelper(dbHelper, "IV_BASE");
-		ivBaseTable.setColumns("ID", "NAME", "TYPE")
-				.setColumnTypes(Types.INTEGER, Types.VARCHAR, Types.CHAR);
-
-		TableHelper ivImplTable = new TableHelper(dbHelper, "IV_IMPL");
-		ivImplTable.setColumns("ID", "ATTR1", "ATTR2", "OTHER1_ID", "OTHER2_ID")
-				.setColumnTypes(Types.INTEGER, Types.VARCHAR, Types.VARCHAR, Types.INTEGER, Types.INTEGER);
-
-		// Insert records we want to update
-		ivOtherTable.insert(1, "other1");
-		ivOtherTable.insert(2, "other2");
-
-		ivBaseTable.insert(1, "Impl 1", "I");
-		ivBaseTable.insert(2, "Impl 2", "I");
-
-		ivImplTable.insert(1, "attr1", "attr2", 1, 2);
-		ivImplTable.insert(2, "attr1", "attr2", 1, 2);
-
-		// Fetch and update the records
-		IvOther other1 = ObjectSelect.query(IvOther.class).where(IvOther.NAME.eq("other1")).selectOne(context);
-		IvOther other2 = ObjectSelect.query(IvOther.class).where(IvOther.NAME.eq("other2")).selectOne(context);
-
-		for(IvImpl record : ObjectSelect.query(IvImpl.class).select(context)) {
-			record.setName(record.getName() + "-Change");
-			record.setAttr1(record.getAttr1() + "-Change");
-			record.setAttr2(record.getAttr2() + "-Change");
-			record.setOther1(other2);
-			record.setOther2(other1);
-		}
-
-		context.commitChanges();
-
-		// todo: add some assertions after fixing commit bug above
-
-	}
-
 	/**
 	 * @link https://issues.apache.org/jira/browse/CAY-2282
 	 */
@@ -756,17 +656,7 @@ public class VerticalInheritanceIT extends ServerCase {
 
 	@Test
 	public void testCountEjbqlQuery() throws Exception {
-		TableHelper ivRootTable = new TableHelper(dbHelper, "IV_ROOT");
-		ivRootTable.setColumns("ID", "NAME", "DISCRIMINATOR");
-
-		TableHelper ivSub1Table = new TableHelper(dbHelper, "IV_SUB1");
-		ivSub1Table.setColumns("ID", "SUB1_NAME");
-
-		TableHelper ivSub2Table = new TableHelper(dbHelper, "IV_SUB2");
-		ivSub2Table.setColumns("ID", "SUB2_ATTR", "SUB2_NAME");
-
 		// Root, IvSub1, IvSub2
-
 		ivRootTable.insert(1, "root1", "");
 
 		ivRootTable.insert(2, "sub11", "IvSub1");
@@ -774,8 +664,8 @@ public class VerticalInheritanceIT extends ServerCase {
 
 		ivRootTable.insert(3, "sub21", "IvSub2");
 		ivRootTable.insert(4, "sub22", "IvSub2");
-		ivSub2Table.insert(3, "attr1", "sub_name2_1");
-		ivSub2Table.insert(4, "attr2", "sub_name2_2");
+		ivSub2Table.insert(3, "sub_name2_1", "attr1");
+		ivSub2Table.insert(4, "sub_name2_2", "attr2");
 
 		EJBQLQuery query1 = new EJBQLQuery("SELECT COUNT(a) FROM IvRoot a");
 		assertEquals(Collections.singletonList(4L), context.performQuery(query1));
