@@ -18,18 +18,15 @@
  ****************************************************************/
 package org.apache.cayenne.exp;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotEquals;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertTrue;
-
 import java.util.Arrays;
 import java.util.List;
 
+import org.apache.cayenne.CayenneRuntimeException;
 import org.apache.cayenne.exp.parser.ASTAbs;
 import org.apache.cayenne.exp.parser.ASTAvg;
 import org.apache.cayenne.exp.parser.ASTConcat;
 import org.apache.cayenne.exp.parser.ASTCount;
+import org.apache.cayenne.exp.parser.ASTDistinct;
 import org.apache.cayenne.exp.parser.ASTLength;
 import org.apache.cayenne.exp.parser.ASTLocate;
 import org.apache.cayenne.exp.parser.ASTLower;
@@ -47,6 +44,11 @@ import org.apache.cayenne.exp.parser.PatternMatchNode;
 import org.apache.cayenne.reflect.TstJavaBean;
 import org.junit.Test;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotEquals;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertTrue;
+
 public class PropertyTest {
 
     @Test
@@ -288,15 +290,6 @@ public class PropertyTest {
         assertEquals("test.path", ex.toString());
     }
 
-    @SuppressWarnings("deprecation")
-    @Test
-    public void testDeprecatedConstruct() {
-        Property<String> p = new Property<>("p");
-        assertNull(p.getType());
-        assertEquals("p", p.getName());
-        assertEquals(new ASTObjPath("p"), p.getExpression());
-    }
-
     @Test
     public void testCreationWithName() {
         Property<String> p1 = new Property<>("p1", String.class);
@@ -357,6 +350,15 @@ public class PropertyTest {
         assertEquals(p.getExpression(), newProp.getExpression().getOperand(0));
     }
 
+    @Test
+    public void testCountDistinct() {
+        Property<String> p = Property.create("test", String.class);
+        Property<Long> newProp = p.countDistinct();
+        assertTrue(newProp.getExpression() instanceof ASTCount);
+        assertTrue(newProp.getExpression().getOperand(0) instanceof ASTDistinct);
+        assertEquals(p.getExpression(), ((ASTDistinct)newProp.getExpression().getOperand(0)).getOperand(0));
+    }
+
     @Test
     public void testMin() {
         Property<String> p = Property.create("test", String.class);
@@ -488,4 +490,13 @@ public class PropertyTest {
         assertEquals(3, newProp.getExpression().getOperand(2)); // getOperand unwrapping ASTScalar
         assertEquals(p2.getExpression(), newProp.getExpression().getOperand(3));
     }
+
+    @Test(expected = CayenneRuntimeException.class)
+    public void testMixDbAndObjPath() {
+        Property<Integer> dbPathProperty = Property
+                .create(ExpressionFactory.dbPathExp("db_path"), Integer.class);
+        Property<String> objPathProperty = Property
+                .create(ExpressionFactory.pathExp("obj_path"), String.class);
+        objPathProperty.dot(dbPathProperty);
+    }
 }
