@@ -21,12 +21,8 @@ package org.apache.cayenne.asciidoc;
 
 import java.io.BufferedWriter;
 import java.io.IOException;
-import java.io.OutputStreamWriter;
-import java.io.Writer;
-import java.nio.charset.CharsetEncoder;
-import java.nio.charset.StandardCharsets;
 import java.nio.file.FileSystems;
-import java.nio.file.OpenOption;
+import java.nio.file.Files;
 import java.nio.file.Path;
 import java.nio.file.StandardOpenOption;
 import java.util.Collections;
@@ -36,7 +32,6 @@ import org.asciidoctor.Options;
 import org.asciidoctor.ast.Document;
 import org.asciidoctor.extension.Postprocessor;
 import org.jsoup.Jsoup;
-import org.jsoup.nodes.Element;
 
 /**
  * <p>
@@ -63,10 +58,12 @@ public class CayennePostProcessor extends Postprocessor {
     private static final String POSITION_BODY = "body";
     private static final String POSITION_BOTTOM = "bottom";
 
+    @SuppressWarnings("unused")
     public CayennePostProcessor() {
         super();
     }
 
+    @SuppressWarnings("unused")
     public CayennePostProcessor(Map<String, Object> config) {
         super(config);
     }
@@ -92,12 +89,12 @@ public class CayennePostProcessor extends Postprocessor {
                 .addClass("fa-lightbulb-o")
                 .addClass("fa-2x");
 
-        for(Element el : jsoupDoc.select("code")) {
+        jsoupDoc.select("code").forEach(el -> {
             String codeClass = el.attr("data-lang");
             if(!codeClass.isEmpty()) {
                 el.addClass(codeClass);
             }
-        }
+        });
 
         jsoupDoc.select("div#preamble").remove();
 
@@ -135,7 +132,7 @@ public class CayennePostProcessor extends Postprocessor {
                 StandardOpenOption.CREATE,
                 StandardOpenOption.WRITE
         };
-        try(BufferedWriter br = newBufferedWriter(path, options)) {
+        try(BufferedWriter br = Files.newBufferedWriter(path, options)) {
             br.write(toc, 0, toc.length());
             br.flush();
         } catch (IOException ex) {
@@ -149,21 +146,15 @@ public class CayennePostProcessor extends Postprocessor {
         return output.substring(0, start) + output.substring(end);
     }
 
-    static BufferedWriter newBufferedWriter(Path path, OpenOption... options) throws IOException {
-        CharsetEncoder encoder = StandardCharsets.UTF_8.newEncoder();
-        Writer writer = new OutputStreamWriter(path.getFileSystem().provider().newOutputStream(path, options), encoder);
-        return new BufferedWriter(writer);
-    }
-
     protected String processHeader(Document document, String output) {
-        String headerFile = (String) document.getAttr("cayenne-header", "");
-        String headerPosition = (String)document.getAttr("cayenne-header-position", POSITION_TOP);
+        String headerFile = (String) document.getAttribute("cayenne-header", "");
+        String headerPosition = (String)document.getAttribute("cayenne-header-position", POSITION_TOP);
 
         if(headerFile.isEmpty()) {
             return output;
         }
 
-        String header = "";
+        String header;
         // inject empty front matter
         if(FRONT_MATTER.equals(headerFile.trim())) {
             header = EMPTY_FRONT_MATTER ;
@@ -189,8 +180,8 @@ public class CayennePostProcessor extends Postprocessor {
     }
 
     protected String processFooter(Document document, String output) {
-        String footerFile = (String) document.getAttr("cayenne-footer", "");
-        String footerPosition = (String)document.getAttr("cayenne-footer-position", POSITION_BOTTOM);
+        String footerFile = (String) document.getAttribute("cayenne-footer", "");
+        String footerPosition = (String)document.getAttribute("cayenne-footer-position", POSITION_BOTTOM);
 
         if(footerFile.isEmpty()) {
             return output;
@@ -213,4 +204,4 @@ public class CayennePostProcessor extends Postprocessor {
                 return output + footer;
         }
     }
-}
\ No newline at end of file
+}
