@@ -18,25 +18,6 @@
  ****************************************************************/
 package org.apache.cayenne.tools;
 
-import org.apache.cayenne.dbsync.reverse.dbimport.Catalog;
-import org.apache.cayenne.dbsync.reverse.dbimport.DbImportConfiguration;
-import org.apache.cayenne.dbsync.reverse.dbimport.IncludeTable;
-import org.apache.cayenne.dbsync.reverse.dbimport.Schema;
-import org.apache.cayenne.test.jdbc.SQLReader;
-import org.apache.cayenne.test.resource.ResourceUtil;
-import org.slf4j.Logger;
-import org.apache.maven.plugin.MojoExecutionException;
-import org.apache.maven.plugin.testing.AbstractMojoTestCase;
-import org.codehaus.plexus.util.FileUtils;
-import org.custommonkey.xmlunit.DetailedDiff;
-import org.custommonkey.xmlunit.Diff;
-import org.custommonkey.xmlunit.ElementNameAndAttributeQualifier;
-import org.custommonkey.xmlunit.XMLUnit;
-import org.junit.AfterClass;
-import org.junit.BeforeClass;
-import org.junit.Ignore;
-import org.junit.Test;
-
 import java.io.File;
 import java.io.FileReader;
 import java.io.IOException;
@@ -49,7 +30,31 @@ import java.sql.Statement;
 import java.util.Iterator;
 import java.util.Objects;
 
-import static org.apache.commons.lang.StringUtils.isBlank;
+import org.apache.cayenne.dbsync.reverse.dbimport.Catalog;
+import org.apache.cayenne.dbsync.reverse.dbimport.DbImportConfiguration;
+import org.apache.cayenne.dbsync.reverse.dbimport.IncludeTable;
+import org.apache.cayenne.dbsync.reverse.dbimport.Schema;
+import org.apache.cayenne.test.jdbc.SQLReader;
+import org.apache.cayenne.test.resource.ResourceUtil;
+import org.apache.maven.execution.DefaultMavenExecutionRequest;
+import org.apache.maven.execution.MavenExecutionRequest;
+import org.apache.maven.plugin.MojoExecutionException;
+import org.apache.maven.plugin.testing.AbstractMojoTestCase;
+import org.apache.maven.project.MavenProject;
+import org.apache.maven.project.ProjectBuilder;
+import org.apache.maven.project.ProjectBuildingRequest;
+import org.codehaus.plexus.util.FileUtils;
+import org.custommonkey.xmlunit.DetailedDiff;
+import org.custommonkey.xmlunit.Diff;
+import org.custommonkey.xmlunit.ElementNameAndAttributeQualifier;
+import org.custommonkey.xmlunit.XMLUnit;
+import org.junit.AfterClass;
+import org.junit.BeforeClass;
+import org.junit.Ignore;
+import org.junit.Test;
+import org.slf4j.Logger;
+
+import static org.apache.cayenne.util.Util.isBlank;
 import static org.mockito.Mockito.mock;
 
 
@@ -163,6 +168,21 @@ public class DbImporterMojoTest extends AbstractMojoTestCase {
         test("testOneToOne");
     }
 
+    @Test
+    public void testExcludeRelationship() throws Exception {
+        test("testExcludeRelationship");
+    }
+
+    @Test
+    public void testExcludeRelationshipFirst() throws Exception {
+        test("testExcludeRelationshipFirst");
+    }
+
+    @Test
+    public void testNamingStrategy() throws Exception {
+        test("testNamingStrategy");
+    }
+
     /**
      * Q: what happens if an attribute or relationship is unmapped in the object layer, but then the underlying table
      * changes.
@@ -219,6 +239,16 @@ public class DbImporterMojoTest extends AbstractMojoTestCase {
         test("testComplexChangeOrder");
     }
 
+    @Test
+    public void testConfigFromDataMap() throws Exception {
+        test("testConfigFromDataMap");
+    }
+
+    @Test
+    public void testTableTypesFromDataMapConfig() throws Exception {
+        test("testTableTypesMap");
+    }
+
     /**
      * CREATE TABLE APP.A (
      * id INTEGER NOT NULL,
@@ -355,25 +385,25 @@ public class DbImporterMojoTest extends AbstractMojoTestCase {
             mapFileCopy = mapFile;
         }
 
-        DbImportConfiguration parameters = cdbImport.createConfig(mock(Logger.class));
-        prepareDatabase(name, parameters);
+        DbImportDataSourceConfig dataSource = cdbImport.getDataSource();
+        prepareDatabase(name, dataSource);
 
         try {
             cdbImport.execute();
             verifyResult(mapFile, mapFileCopy);
         } finally {
-            cleanDb(parameters);
+            cleanDb(dataSource);
         }
     }
 
-    private void cleanDb(DbImportConfiguration dbImportConfiguration) throws Exception {
+    private void cleanDb(DbImportDataSourceConfig dataSource) throws Exception {
 
         // TODO: refactor to common DB management code... E.g. bootique-jdbc-test?
         // TODO: with in-memory Derby, it is easier to just stop and delete the database.. again see bootique-jdbc-test
 
-        Class.forName(dbImportConfiguration.getDriver()).newInstance();
+        Class.forName(dataSource.getDriver()).newInstance();
 
-        try (Connection connection = DriverManager.getConnection(dbImportConfiguration.getUrl())) {
+        try (Connection connection = DriverManager.getConnection(dataSource.getUrl())) {
 
             try (Statement stmt = connection.createStatement()) {
 
@@ -437,15 +467,15 @@ public class DbImporterMojoTest extends AbstractMojoTestCase {
         }
     }
 
-    private void prepareDatabase(String sqlFile, DbImportConfiguration dbImportConfiguration) throws Exception {
+    private void prepareDatabase(String sqlFile, DbImportDataSourceConfig dataSource) throws Exception {
 
         URL sqlUrl = Objects.requireNonNull(ResourceUtil.getResource(getClass(), "dbimport/" + sqlFile + ".sql"));
 
         // TODO: refactor to common DB management code... E.g. bootique-jdbc-test?
 
-        Class.forName(dbImportConfiguration.getDriver()).newInstance();
+        Class.forName(dataSource.getDriver()).newInstance();
 
-        try (Connection connection = DriverManager.getConnection(dbImportConfiguration.getUrl())) {
+        try (Connection connection = DriverManager.getConnection(dataSource.getUrl())) {
             try (Statement stmt = connection.createStatement();) {
                 for (String sql : SQLReader.statements(sqlUrl, ";")) {
                     stmt.execute(sql);
@@ -453,4 +483,13 @@ public class DbImporterMojoTest extends AbstractMojoTestCase {
             }
         }
     }
+
+
+    private MavenProject getMavenProject(String pomPath) throws Exception {
+        File pom = new File(pomPath);
+        MavenExecutionRequest request = new DefaultMavenExecutionRequest();
+        request.setPom(pom);
+        ProjectBuildingRequest configuration = request.getProjectBuildingRequest();
+        return lookup( ProjectBuilder.class ).build( pom, configuration ).getProject();
+    }
 }
