@@ -56,35 +56,24 @@ public class OSXPlatformInitializer implements PlatformInitializer {
 
         // configure special Mac menu handlers
         OSXApplicationWrapper wrapper = new OSXApplicationWrapper(Application.getApplication());
-        wrapper.setAboutHandler(new Runnable() {
-            @Override
-            public void run() {
-                actionManager.getAction(AboutAction.class).showAboutDialog();
-            }
-        });
+        wrapper.setAboutHandler(()
+                -> actionManager.getAction(AboutAction.class).showAboutDialog());
 
-        wrapper.setPreferencesHandler(new Runnable() {
-            @Override
-            public void run() {
-                actionManager.getAction(ConfigurePreferencesAction.class).showPreferencesDialog();
-            }
-        });
+        wrapper.setPreferencesHandler(()
+                -> actionManager.getAction(ConfigurePreferencesAction.class).showPreferencesDialog());
 
-        wrapper.setQuitHandler(new OSXQuitHandler() {
-            @Override
-            public void handle(OSXQuitResponseWrapper response) {
-                if (!actionManager.getAction(ExitAction.class).exit()) {
-                    response.cancelQuit();
-                } else {
-                    response.performQuit();
-                }
+        wrapper.setQuitHandler(r -> {
+            if(!actionManager.getAction(ExitAction.class).exit()) {
+                r.cancelQuit();
+            } else {
+                r.performQuit();
             }
         });
     }
 
     private void overrideUIDefaults() {
-        final Color lightGrey = new Color(0xEEEEEE);
-        final Color darkGrey  = new Color(225, 225, 225);
+        Color lightGrey = new Color(0xEEEEEE);
+        Color darkGrey  = new Color(225, 225, 225);
         Border darkBorder = BorderFactory.createLineBorder(darkGrey);
 
         UIManager.put("ToolBarSeparatorUI",           OSXToolBarSeparatorUI.class.getName());
@@ -98,13 +87,16 @@ public class OSXPlatformInitializer implements PlatformInitializer {
         UIManager.put("Table.scrollPaneBorder",       darkBorder);
         UIManager.put("SplitPane.border",             BorderFactory.createEmptyBorder());
         UIManager.put("SplitPane.background",         darkGrey);
+        UIManager.put("Tree.rendererFillBackground",  Boolean.TRUE);
         UIManager.put("ComboBox.background",          Color.WHITE);
         UIManager.put("ComboBox.selectionBackground", darkGrey);
         UIManager.put("ComboBox.selectionForeground", Color.BLACK);
-        UIManager.put("Tree.rendererFillBackground",  Boolean.TRUE);
         UIManager.put("Tree.selectionForeground",     Color.BLACK);
         UIManager.put("Tree.selectionBackground",     lightGrey);
         UIManager.put("Tree.selectionBorderColor",    lightGrey);
+        UIManager.put("Table.selectionForeground",    Color.BLACK);
+        UIManager.put("Table.selectionBackground",    lightGrey);
+        UIManager.put("Table.focusCellHighlightBorder", BorderFactory.createEmptyBorder());
 
         Border backgroundPainter = new AbstractBorder() {
             @Override
