@@ -24,6 +24,7 @@ import org.apache.cayenne.modeler.action.ExitAction;
 import org.apache.cayenne.modeler.action.OpenProjectAction;
 import org.apache.cayenne.modeler.dialog.validator.ValidatorDialog;
 import org.apache.cayenne.modeler.editor.EditorView;
+import org.apache.cayenne.modeler.editor.DbImportController;
 import org.apache.cayenne.modeler.init.platform.PlatformInitializer;
 import org.apache.cayenne.modeler.pref.ComponentGeometry;
 import org.apache.cayenne.modeler.pref.FSPath;
@@ -66,7 +67,10 @@ public class CayenneModelerController extends CayenneController {
     protected CayenneModelerFrame frame;
 	private EditorView editorView;
 
-    public CayenneModelerController(){}
+	private DbImportController dbImportController;
+
+    public CayenneModelerController(){
+    }
 
     public CayenneModelerController(Application application) {
         super(application);
@@ -74,6 +78,7 @@ public class CayenneModelerController extends CayenneController {
         this.frame = new CayenneModelerFrame(application.getActionManager());
         application.getInjector().getInstance(PlatformInitializer.class).setupMenus(frame);
         this.projectController = new ProjectController(this);
+        this.dbImportController = new DbImportController();
     }
 
     @Override
@@ -113,12 +118,7 @@ public class CayenneModelerController extends CayenneController {
         // Register a hook to save the window position when quit via the app menu.
         // This is in Mac OSX only.
         if (System.getProperty("os.name").startsWith("Mac OS")) {
-            Runnable runner = new Runnable() {
-                @Override
-                public void run() {
-                    PROJECT_STATE_UTIL.saveLastState(projectController);
-                }
-            };
+            Runnable runner = () -> PROJECT_STATE_UTIL.saveLastState(projectController);
             Runtime.getRuntime().addShutdownHook(new Thread(runner, "Window Prefs Hook"));
         }
 
@@ -225,6 +225,7 @@ public class CayenneModelerController extends CayenneController {
             } catch (URISyntaxException ignore) {
             }
         }
+
         frame.setTitle(getProjectLocationString());
 
         PROJECT_STATE_UTIL.fireLastState(projectController);
@@ -290,26 +291,27 @@ public class CayenneModelerController extends CayenneController {
     /**
      * Performs status bar update with a message. Message will disappear in 6 seconds.
      */
-    public void updateStatus(final String message) {
+    public void updateStatus(String message) {
         frame.getStatus().setText(message);
 
         // start message cleanup thread that would remove the message after X seconds
         if (message != null && message.trim().length() > 0) {
-            new Thread(new Runnable() {
-                @Override
-                public void run() {
-                    try {
-                        Thread.sleep(6 * 10000);
-                    } catch (InterruptedException ignore) {
-                    }
-                    if (message.equals(frame.getStatus().getText())) {
-                        CayenneModelerController.this.updateStatus(null);
-                    }
+            new Thread(() -> {
+                try {
+                    Thread.sleep(6 * 10000);
+                } catch (InterruptedException ignore){
+                }
+                if (message.equals(frame.getStatus().getText())) {
+                    updateStatus(null);
                 }
             }).start();
         }
     }
 
+    public DbImportController getDbImportController() {
+        return dbImportController;
+    }
+
     protected String getProjectLocationString() {
         if(projectController.getProject().getConfigurationResource() == null) {
             return "[New Project]";
