@@ -105,9 +105,9 @@ public class Main {
     }
 
     protected Collection<Module> appendModules(Collection<Module> modules) {
-        // TODO: this is dirty... "CayenneModeler" is not a project name, and ServerModule is out of place inside
-        // the Modeler... If we need ServerRuntime for certain operations, those should start their own stack...
-        modules.add(new ServerModule("CayenneModeler"));
+        // TODO: this is dirty... ServerModule is out of place inside the Modeler...
+        // If we need ServerRuntime for certain operations, those should start their own stack...
+        modules.add(new ServerModule());
 
         modules.add(new ProjectModule());
         modules.add(new DbSyncModule());
