@@ -19,6 +19,20 @@
 
 package org.apache.cayenne.modeler;
 
+import javax.swing.event.EventListenerList;
+import java.awt.Component;
+import java.util.ArrayList;
+import java.util.Arrays;
+import java.util.Collection;
+import java.util.Collections;
+import java.util.EventListener;
+import java.util.EventObject;
+import java.util.HashSet;
+import java.util.Iterator;
+import java.util.List;
+import java.util.Set;
+import java.util.prefs.Preferences;
+
 import org.apache.cayenne.CayenneRuntimeException;
 import org.apache.cayenne.configuration.ConfigurationNode;
 import org.apache.cayenne.configuration.DataChannelDescriptor;
@@ -47,6 +61,7 @@ import org.apache.cayenne.map.ObjEntity;
 import org.apache.cayenne.map.ObjRelationship;
 import org.apache.cayenne.map.Procedure;
 import org.apache.cayenne.map.ProcedureParameter;
+import org.apache.cayenne.map.QueryDescriptor;
 import org.apache.cayenne.map.event.AttributeEvent;
 import org.apache.cayenne.map.event.DbAttributeListener;
 import org.apache.cayenne.map.event.DbEntityListener;
@@ -68,7 +83,42 @@ import org.apache.cayenne.modeler.action.SaveAction;
 import org.apache.cayenne.modeler.action.SaveAsAction;
 import org.apache.cayenne.modeler.editor.CallbackType;
 import org.apache.cayenne.modeler.editor.ObjCallbackMethod;
-import org.apache.cayenne.modeler.event.*;
+import org.apache.cayenne.modeler.event.AttributeDisplayEvent;
+import org.apache.cayenne.modeler.event.CallbackMethodEvent;
+import org.apache.cayenne.modeler.event.CallbackMethodListener;
+import org.apache.cayenne.modeler.event.DataMapDisplayEvent;
+import org.apache.cayenne.modeler.event.DataMapDisplayListener;
+import org.apache.cayenne.modeler.event.DataNodeDisplayEvent;
+import org.apache.cayenne.modeler.event.DataNodeDisplayListener;
+import org.apache.cayenne.modeler.event.DataSourceModificationEvent;
+import org.apache.cayenne.modeler.event.DataSourceModificationListener;
+import org.apache.cayenne.modeler.event.DbAttributeDisplayListener;
+import org.apache.cayenne.modeler.event.DbEntityDisplayListener;
+import org.apache.cayenne.modeler.event.DbRelationshipDisplayListener;
+import org.apache.cayenne.modeler.event.DisplayEvent;
+import org.apache.cayenne.modeler.event.DomainDisplayEvent;
+import org.apache.cayenne.modeler.event.DomainDisplayListener;
+import org.apache.cayenne.modeler.event.EmbeddableAttributeDisplayEvent;
+import org.apache.cayenne.modeler.event.EmbeddableAttributeDisplayListener;
+import org.apache.cayenne.modeler.event.EmbeddableDisplayEvent;
+import org.apache.cayenne.modeler.event.EmbeddableDisplayListener;
+import org.apache.cayenne.modeler.event.EntityDisplayEvent;
+import org.apache.cayenne.modeler.event.EntityListenerEvent;
+import org.apache.cayenne.modeler.event.EntityListenerListener;
+import org.apache.cayenne.modeler.event.MultipleObjectsDisplayEvent;
+import org.apache.cayenne.modeler.event.MultipleObjectsDisplayListener;
+import org.apache.cayenne.modeler.event.ObjAttributeDisplayListener;
+import org.apache.cayenne.modeler.event.ObjEntityDisplayListener;
+import org.apache.cayenne.modeler.event.ObjRelationshipDisplayListener;
+import org.apache.cayenne.modeler.event.ProcedureDisplayEvent;
+import org.apache.cayenne.modeler.event.ProcedureDisplayListener;
+import org.apache.cayenne.modeler.event.ProcedureParameterDisplayEvent;
+import org.apache.cayenne.modeler.event.ProcedureParameterDisplayListener;
+import org.apache.cayenne.modeler.event.ProjectOnSaveEvent;
+import org.apache.cayenne.modeler.event.ProjectOnSaveListener;
+import org.apache.cayenne.modeler.event.QueryDisplayEvent;
+import org.apache.cayenne.modeler.event.QueryDisplayListener;
+import org.apache.cayenne.modeler.event.RelationshipDisplayEvent;
 import org.apache.cayenne.modeler.pref.DataMapDefaults;
 import org.apache.cayenne.modeler.pref.DataNodeDefaults;
 import org.apache.cayenne.modeler.pref.ProjectStatePreferences;
@@ -77,24 +127,8 @@ import org.apache.cayenne.modeler.util.CircularArray;
 import org.apache.cayenne.modeler.util.Comparators;
 import org.apache.cayenne.project.ConfigurationNodeParentGetter;
 import org.apache.cayenne.project.Project;
-import org.apache.cayenne.map.QueryDescriptor;
 import org.apache.cayenne.util.IDUtil;
 
-import javax.swing.event.EventListenerList;
-import java.awt.Component;
-import java.util.ArrayList;
-import java.util.Arrays;
-import java.util.Collection;
-import java.util.Collections;
-import java.util.EventListener;
-import java.util.EventObject;
-import java.util.HashSet;
-import java.util.Iterator;
-import java.util.List;
-import java.util.Set;
-import java.util.Vector;
-import java.util.prefs.Preferences;
-
 /**
  * A controller that works with the project tree, tracking selection and
  * dispatching project events.
@@ -130,12 +164,12 @@ public class ProjectController extends CayenneController {
         /**
          * Paths of multiple selection
          */
-        private Object[] paths;
+        private ConfigurationNode[] paths;
 
         /**
          * Parent path of multiple selection
          */
-        private Object parentPath;
+        private ConfigurationNode parentPath;
 
         /**
          * currently selecte entity listener class
@@ -207,7 +241,7 @@ public class ProjectController extends CayenneController {
     protected Preferences projectControllerPreferences;
 
     protected ControllerState currentState;
-    protected CircularArray controllerStateHistory;
+    protected CircularArray<ControllerState> controllerStateHistory;
     protected int maxHistorySize = 20;
 
     private EntityResolver entityResolver;
@@ -221,7 +255,7 @@ public class ProjectController extends CayenneController {
     public ProjectController(CayenneModelerController parent) {
         super(parent);
         this.listenerList = new EventListenerList();
-        controllerStateHistory = new CircularArray(maxHistorySize);
+        controllerStateHistory = new CircularArray<>(maxHistorySize);
         currentState = new ControllerState();
     }
 
@@ -230,6 +264,10 @@ public class ProjectController extends CayenneController {
         return parent.getView();
     }
 
+    public void setCurrentDataMap(DataMap dataMap) {
+        currentState.map = dataMap;
+    }
+
     public Project getProject() {
         return project;
     }
@@ -260,8 +298,7 @@ public class ProjectController extends CayenneController {
 
                 fileChangeTracker.reconfigure();
 
-                entityResolver = new EntityResolver(
-                        ((DataChannelDescriptor) currentProject.getRootNode()).getDataMaps());
+                entityResolver = new EntityResolver();
 
                 updateEntityResolver();
             }
@@ -272,9 +309,8 @@ public class ProjectController extends CayenneController {
 
         Collection<DataMap> dataMaps = ((DataChannelDescriptor) project.getRootNode()).getDataMaps();
 
-        entityResolver.setDataMaps(dataMaps);
-
         for (DataMap dataMap : dataMaps) {
+            entityResolver.addDataMap(dataMap);
             dataMap.setNamespace(entityResolver);
         }
     }
@@ -401,8 +437,9 @@ public class ProjectController extends CayenneController {
     /** Resets all current models to null. */
     private void clearState() {
         // don't clear if we are refiring events for history navigation
-        if (currentState.isRefiring)
+        if (currentState.isRefiring) {
             return;
+        }
 
         currentState = new ControllerState();
     }
@@ -417,16 +454,14 @@ public class ProjectController extends CayenneController {
     private void removeFromHistory(EventObject e) {
 
         int count = controllerStateHistory.size();
-        List<Object> removeList = new ArrayList<>();
+        List<ControllerState> removeList = new ArrayList<>();
 
         for (int i = 0; i < count; i++) {
-            ControllerState cs = (ControllerState) controllerStateHistory.get(i);
-
-            EventObject csEvent = cs.event;
-
-            if (csEvent == null) {
+            ControllerState cs = controllerStateHistory.get(i);
+            if (cs == null || cs.event == null) {
                 continue;
             }
+            EventObject csEvent = cs.event;
 
             if (e instanceof EntityEvent && csEvent instanceof EntityDisplayEvent) {
                 if (((EntityEvent) e).getEntity() == ((EntityDisplayEvent) csEvent).getEntity()) {
@@ -459,7 +494,7 @@ public class ProjectController extends CayenneController {
             }
         }
 
-        for (Object o : removeList) {
+        for (ControllerState o : removeList) {
             controllerStateHistory.remove(o);
         }
     }
@@ -535,11 +570,11 @@ public class ProjectController extends CayenneController {
         return currentState.procedureParameters;
     }
 
-    public Object[] getCurrentPaths() {
+    public ConfigurationNode[] getCurrentPaths() {
         return currentState.paths;
     }
 
-    public Object getCurrentParentPath() {
+    public ConfigurationNode getCurrentParentPath() {
         return currentState.parentPath;
     }
 
@@ -814,6 +849,7 @@ public class ProjectController extends CayenneController {
         if (!changed) {
             changed = currentState.dbEntity != null || currentState.objEntity != null || currentState.procedure != null
                     || currentState.query != null || currentState.embeddable != null;
+            currentState.node = e.getDataNode();
         }
 
         if (!e.isRefired()) {
@@ -822,7 +858,7 @@ public class ProjectController extends CayenneController {
             if (changed) {
                 clearState();
                 currentState.domain = e.getDomain();
-                currentState.node = e.getDataNode();
+                currentState.node  = e.getDataNode();
                 currentState.map = e.getDataMap();
             }
         }
@@ -1019,30 +1055,31 @@ public class ProjectController extends CayenneController {
 
     public void fireNavigationEvent(EventObject e) {
         Object source = e.getSource();
-        if (source == null)
+        if (source == null) {
             return;
+        }
 
         int size = controllerStateHistory.size();
         if (size == 0)
             return;
 
         int i = controllerStateHistory.indexOf(currentState);
-        ControllerState cs = null;
+        ControllerState cs;
         if (size == 1) {
-            cs = (ControllerState) controllerStateHistory.get(0);
+            cs = controllerStateHistory.get(0);
         } else if (source instanceof NavigateForwardAction) {
             int counter = 0;
             while (true) {
                 if (i < 0) {
                     // a new state got created without it being saved.
                     // just move to the beginning of the list
-                    cs = (ControllerState) controllerStateHistory.get(0);
+                    cs = controllerStateHistory.get(0);
                 } else if (i + 1 < size) {
                     // move forward
-                    cs = (ControllerState) controllerStateHistory.get(i + 1);
+                    cs = controllerStateHistory.get(i + 1);
                 } else {
                     // wrap around
-                    cs = (ControllerState) controllerStateHistory.get(0);
+                    cs = controllerStateHistory.get(0);
                 }
                 if (!cs.isEquivalent(currentState)) {
                     break;
@@ -1061,34 +1098,36 @@ public class ProjectController extends CayenneController {
                 if (i < 0) {
                     // a new state got created without it being saved.
                     try {
-                        cs = (ControllerState) controllerStateHistory.get(size - 2);
+                        cs = controllerStateHistory.get(size - 2);
                     } catch (ArrayIndexOutOfBoundsException ex) {
-                        cs = (ControllerState) controllerStateHistory.get(size - 1);
+                        cs = controllerStateHistory.get(size - 1);
                     }
                 } else if (i - 1 >= 0) {
                     // move to the previous one
-                    cs = (ControllerState) controllerStateHistory.get(i - 1);
+                    cs = controllerStateHistory.get(i - 1);
                 } else {
                     // wrap around
-                    cs = (ControllerState) controllerStateHistory.get(size - 1);
+                    cs = controllerStateHistory.get(size - 1);
                 }
                 if (!cs.isEquivalent(currentState)) {
                     break;
                 }
-                // if it doesn't find it within 5 tries it is probably stuck in
-                // a loop
+                // if it doesn't find it within 5 tries it is probably stuck in a loop
                 if (++counter > 5) {
                     break;
                 }
                 i--;
             }
+        } else {
+            throw new IllegalStateException("Unknown source for navigation event: " + e.getSource());
         }
 
         // reset the current state to the one we just navigated to
         currentState = cs;
         DisplayEvent de = cs.event;
-        if (de == null)
+        if (de == null) {
             return;
+        }
 
         // make sure that isRefiring is turned off prior to exiting this routine
         // this flag is used to tell the controller to not create new states
@@ -1096,8 +1135,7 @@ public class ProjectController extends CayenneController {
         currentState.isRefiring = true;
 
         // the order of the following is checked in most specific to generic
-        // because
-        // of the inheritance heirarchy
+        // because of the inheritance hierarchy
         de.setRefired(true);
         if (de instanceof EntityDisplayEvent) {
             EntityDisplayEvent ede = (EntityDisplayEvent) de;
@@ -1543,21 +1581,21 @@ public class ProjectController extends CayenneController {
     }
 
     /**
-     * @return currently selecte entity listener class
+     * set current entity listener class
      */
     public void setCurrentListenerClass(String listenerClass) {
         currentState.listenerClass = listenerClass;
     }
 
     /**
-     * @return currently selected callback type
+     * set current callback type
      */
     public void setCurrentCallbackType(CallbackType callbackType) {
         currentState.callbackType = callbackType;
     }
 
     /**
-     * @return currently selected callback methods
+     * set current callback methods
      */
     public void setCurrentCallbackMethods(ObjCallbackMethod[] callbackMethods) {
         currentState.callbackMethods = callbackMethods;
@@ -1645,7 +1683,6 @@ public class ProjectController extends CayenneController {
      * Returns currently selected object, null if there are none, List if there
      * are several
      */
-    @SuppressWarnings("unchecked")
     public Object getCurrentObject() {
         if (getCurrentObjEntity() != null) {
             return getCurrentObjEntity();
@@ -1664,24 +1701,23 @@ public class ProjectController extends CayenneController {
         } else if (getCurrentDataChanel() != null) {
             return getCurrentDataChanel();
         } else if (getCurrentPaths() != null) { // multiple objects
-            Object[] paths = getCurrentPaths();
-            List<Object> result = new Vector<Object>();
+            ConfigurationNode[] paths = getCurrentPaths();
 
-            ConfigurationNodeParentGetter parentGetter = getApplication().getInjector().getInstance(
-                    ConfigurationNodeParentGetter.class);
-            Object parent = parentGetter.getParent((ConfigurationNode) paths[0]);
+            ConfigurationNodeParentGetter parentGetter = getApplication().getInjector()
+                    .getInstance(ConfigurationNodeParentGetter.class);
+            Object parent = parentGetter.getParent(paths[0]);
 
-            for (Object path : paths) {
-                result.add(path);
-            }
+            List<ConfigurationNode> result = new ArrayList<>();
+            result.addAll(Arrays.asList(paths));
 
-            /**
+            /*
              * Here we sort the list of objects to minimize the risk that
              * objects will be pasted incorrectly. For instance, ObjEntity
              * should go before Query, to increase chances that Query's root
              * would be set.
              */
-            Collections.sort(result, parent instanceof DataMap ? Comparators.getDataMapChildrenComparator()
+            Collections.sort(result, parent instanceof DataMap
+                    ? Comparators.getDataMapChildrenComparator()
                     : Comparators.getDataDomainChildrenComparator());
 
             return result;
@@ -1829,7 +1865,7 @@ public class ProjectController extends CayenneController {
     
     /**
      * If true, all save buttons become available.
-     * @param enable
+     * @param enable or not save button
      */
     public void enableSave(boolean enable) {
         application.getActionManager().getAction(SaveAction.class).setEnabled(enable);
@@ -1837,29 +1873,29 @@ public class ProjectController extends CayenneController {
     }
 
     /**
-    * Set currently selected ObjAttributes
-    */
+     * Set currently selected ObjAttributes
+     */
     public void setCurrentObjAttributes(ObjAttribute[] attrs) {
-currentState.objAttrs = attrs;
-}
+        currentState.objAttrs = attrs;
+    }
 
     /**
-    * Set currently selected ObjRelationships
-    */
+     * Set currently selected ObjRelationships
+     */
     public void setCurrentObjRelationships(ObjRelationship[] rels) {
-currentState.objRels = rels;
-}
+        currentState.objRels = rels;
+    }
 
     /**
-    * Set currently selected DbAttributes
-    */
+     * Set currently selected DbAttributes
+     */
     public void setCurrentDbAttributes(DbAttribute[] attrs) {
         currentState.dbAttrs = attrs;
     }
 
     /**
-    * Set currently selected DbRelationships
-    */
+     * Set currently selected DbRelationships
+     */
     public void setCurrentDbRelationships(DbRelationship[] rels) {
         currentState.dbRels = rels;
     }
