@@ -22,6 +22,19 @@ import org.apache.cayenne.configuration.ConfigurationNameMapper;
 import org.apache.cayenne.configuration.ConfigurationNode;
 import org.apache.cayenne.di.Inject;
 import org.apache.cayenne.modeler.Application;
+import org.apache.cayenne.modeler.action.dbimport.AddCatalogAction;
+import org.apache.cayenne.modeler.action.dbimport.AddExcludeColumnAction;
+import org.apache.cayenne.modeler.action.dbimport.AddExcludeProcedureAction;
+import org.apache.cayenne.modeler.action.dbimport.AddExcludeTableAction;
+import org.apache.cayenne.modeler.action.dbimport.AddIncludeColumnAction;
+import org.apache.cayenne.modeler.action.dbimport.AddIncludeProcedureAction;
+import org.apache.cayenne.modeler.action.dbimport.AddIncludeTableAction;
+import org.apache.cayenne.modeler.action.dbimport.AddSchemaAction;
+import org.apache.cayenne.modeler.action.dbimport.DeleteNodeAction;
+import org.apache.cayenne.modeler.action.dbimport.EditNodeAction;
+import org.apache.cayenne.modeler.action.dbimport.MoveImportNodeAction;
+import org.apache.cayenne.modeler.action.dbimport.MoveInvertNodeAction;
+import org.apache.cayenne.modeler.action.dbimport.ReverseEngineeringToolMenuAction;
 import org.apache.cayenne.modeler.graph.action.ShowGraphEntityAction;
 import org.apache.cayenne.modeler.util.CayenneAction;
 import org.apache.cayenne.project.ConfigurationNodeParentGetter;
@@ -95,9 +108,24 @@ public class DefaultActionManager implements ActionManager {
         registerAction(new ObjEntityToSuperEntityAction(application));
         registerAction(new ReverseEngineeringAction(application));
         registerAction(new InferRelationshipsAction(application));
+        registerAction(new ReverseEngineeringToolMenuAction(application));
         registerAction(new ImportEOModelAction(application));
         registerAction(new GenerateDBAction(application));
         registerAction(new MigrateAction(application));
+        registerAction(new AddSchemaAction(application)).setAlwaysOn(true);
+        registerAction(new AddCatalogAction(application)).setAlwaysOn(true);
+        registerAction(new AddIncludeTableAction(application)).setAlwaysOn(true);
+        registerAction(new AddExcludeTableAction(application)).setAlwaysOn(true);
+        registerAction(new AddIncludeColumnAction(application)).setAlwaysOn(true);
+        registerAction(new AddExcludeColumnAction(application)).setAlwaysOn(true);
+        registerAction(new AddIncludeProcedureAction(application)).setAlwaysOn(true);
+        registerAction(new AddExcludeProcedureAction(application)).setAlwaysOn(true);
+        registerAction(new GetDbConnectionAction(application)).setAlwaysOn(true);
+        registerAction(new EditNodeAction(application)).setAlwaysOn(true);
+        registerAction(new DeleteNodeAction(application)).setAlwaysOn(true);
+        registerAction(new MoveImportNodeAction(application)).setAlwaysOn(true);
+        registerAction(new LoadDbSchemaAction(application)).setAlwaysOn(true);
+        registerAction(new MoveInvertNodeAction(application)).setAlwaysOn(true);
         registerAction(new AboutAction(application)).setAlwaysOn(true);
         registerAction(new DocumentationAction(application)).setAlwaysOn(true);
         registerAction(new ConfigurePreferencesAction(application)).setAlwaysOn(true);
@@ -166,7 +194,8 @@ public class DefaultActionManager implements ActionManager {
                 ImportEOModelAction.class.getName(),
                 GenerateCodeAction.class.getName(),
                 GenerateDBAction.class.getName(),
-                PasteAction.class.getName()));
+                PasteAction.class.getName(),
+                ReverseEngineeringToolMenuAction.class.getName()));
 
         DATA_NODE_ACTIONS = new HashSet<>(DOMAIN_ACTIONS);
         DATA_NODE_ACTIONS.addAll(Arrays.asList(
@@ -264,7 +293,7 @@ public class DefaultActionManager implements ActionManager {
     }
 
     public void projectClosed() {
-        processActionsState(Collections.<String> emptySet());
+        processActionsState(Collections.emptySet());
         updateActions("");
     }
 
