@@ -19,15 +19,14 @@
 
 package org.apache.cayenne.modeler.action;
 
+
 import org.apache.cayenne.configuration.DataChannelDescriptor;
-import org.apache.cayenne.map.DataMap;
 import org.apache.cayenne.modeler.Application;
-import org.apache.cayenne.modeler.dialog.codegen.CodeGeneratorController;
+import org.apache.cayenne.modeler.event.DomainDisplayEvent;
 import org.apache.cayenne.modeler.util.CayenneAction;
-import org.apache.cayenne.project.Project;
 
 import java.awt.event.ActionEvent;
-import java.util.Collection;
+
 
 public class GenerateCodeAction extends CayenneAction {
 
@@ -44,9 +43,6 @@ public class GenerateCodeAction extends CayenneAction {
     }
 
     public void performAction(ActionEvent e) {
-        Collection<DataMap> dataMaps;
-        Project project = getProjectController().getProject();
-        dataMaps = ((DataChannelDescriptor) project.getRootNode()).getDataMaps();
-        new CodeGeneratorController(getApplication().getFrameController(), dataMaps).startup();
+        getProjectController().fireDomainDisplayEvent(new DomainDisplayEvent(this, (DataChannelDescriptor) getProjectController().getProject().getRootNode()));
     }
 }
