@@ -188,11 +188,11 @@ public class RemoveAction extends CayenneAction {
         } else if (mediator.getCurrentPaths() != null) { // multiple deletion
             if (dialog.shouldDelete("selected objects")) {
 
-                Object[] paths = mediator.getCurrentPaths();
-                Object parentPath = mediator.getCurrentParentPath();
+                ConfigurationNode[] paths = mediator.getCurrentPaths();
+                ConfigurationNode parentPath = mediator.getCurrentParentPath();
 
                 CompoundEdit compoundEdit = new RemoveCompoundUndoableEdit();
-                for (Object path : paths) {
+                for (ConfigurationNode path : paths) {
                     compoundEdit.addEdit(removeLastPathComponent(path, parentPath));
                 }
                 compoundEdit.end();
@@ -487,7 +487,7 @@ public class RemoveAction extends CayenneAction {
     /**
      * Removes an object, depending on its type
      */
-    private UndoableEdit removeLastPathComponent(Object object, Object parentObject) {
+    private UndoableEdit removeLastPathComponent(ConfigurationNode object, ConfigurationNode parentObject) {
 
         UndoableEdit undo = null;
 
