@@ -87,7 +87,7 @@ public class SaveAsAction extends CayenneAction {
 
         if (projectDir.exists() && !projectDir.canWrite()) {
             JOptionPane.showMessageDialog(Application.getFrame(), "Can't save project - unable to write to file \""
-                    + projectDir.getPath() + "\"", "Can't Save Project", JOptionPane.OK_OPTION);
+                    + projectDir.getPath() + "\"", "Can't Save Project", JOptionPane.ERROR_MESSAGE);
             return false;
         }
 
@@ -129,6 +129,7 @@ public class SaveAsAction extends CayenneAction {
 
                     RenamedPreferences.copyPreferences(newPref, tempOldPref, false);
                     tempOldPref.removeNode();
+                    Application.getInstance().getFrameController().getLastDirectory().setDirectory(projectDir);
                 }
             }
         }
