@@ -50,8 +50,6 @@ import javax.swing.table.TableColumn;
 import java.awt.BorderLayout;
 import java.awt.Dimension;
 import java.awt.FlowLayout;
-import java.awt.event.ActionEvent;
-import java.awt.event.ActionListener;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
@@ -217,14 +215,14 @@ public class ResolveDbRelationshipDialog extends CayenneDialog {
         table.setModel(new DbJoinTableModel(relationship, getMediator(), this, true));
         TableColumn sourceColumn = table.getColumnModel().getColumn(DbJoinTableModel.SOURCE);
         JComboBox comboBox = Application.getWidgetFactory().createComboBox(
-                ModelerUtil.getDbAttributeNames(getMediator(), relationship.getSourceEntity()), true);
+                ModelerUtil.getDbAttributeNames(relationship.getSourceEntity()), true);
 
         AutoCompletion.enable(comboBox);
         sourceColumn.setCellEditor(Application.getWidgetFactory().createCellEditor(comboBox));
 
         TableColumn targetColumn = table.getColumnModel().getColumn(DbJoinTableModel.TARGET);
         comboBox = Application.getWidgetFactory().createComboBox(
-                ModelerUtil.getDbAttributeNames(getMediator(), relationship.getTargetEntity()), true);
+                ModelerUtil.getDbAttributeNames(relationship.getTargetEntity()), true);
         AutoCompletion.enable(comboBox);
 
         targetColumn.setCellEditor(Application.getWidgetFactory().createCellEditor(comboBox));
@@ -233,53 +231,41 @@ public class ResolveDbRelationshipDialog extends CayenneDialog {
     }
 
     private void initController() {
-        addButton.addActionListener(new ActionListener() {
-            @Override
-            public void actionPerformed(ActionEvent e) {
-                DbJoinTableModel model = (DbJoinTableModel) table.getModel();
+        addButton.addActionListener(e -> {
+            DbJoinTableModel model = (DbJoinTableModel) table.getModel();
 
-                DbJoin join = new DbJoin(relationship);
-                model.addRow(join);
+            DbJoin join = new DbJoin(relationship);
+            model.addRow(join);
 
-                undo.addDbJoinAddUndo(join);
+            undo.addDbJoinAddUndo(join);
 
-                table.select(model.getRowCount() - 1);
-            }
+            table.select(model.getRowCount() - 1);
         });
 
-        removeButton.addActionListener(new ActionListener() {
-            @Override
-            public void actionPerformed(ActionEvent e) {
-                DbJoinTableModel model = (DbJoinTableModel) table.getModel();
-                ResolveDbRelationshipDialog.this.stopEditing();
-                int row = table.getSelectedRow();
+        removeButton.addActionListener(e -> {
+            DbJoinTableModel model = (DbJoinTableModel) table.getModel();
+            stopEditing();
+            int row = table.getSelectedRow();
 
-                DbJoin join = model.getJoin(row);
-                undo.addDbJoinRemoveUndo(join);
+            DbJoin join = model.getJoin(row);
+            undo.addDbJoinRemoveUndo(join);
 
-                model.removeRow(join);
-            }
+            model.removeRow(join);
         });
 
-        saveButton.addActionListener(new ActionListener() {
-            @Override
-            public void actionPerformed(ActionEvent e) {
-                cancelPressed = false;
+        saveButton.addActionListener(e -> {
+            cancelPressed = false;
 
-                if (editable) {
-                    ResolveDbRelationshipDialog.this.save();
-                }
-
-                ResolveDbRelationshipDialog.this.dispose();
+            if (editable) {
+                save();
             }
+
+            dispose();
         });
 
-        cancelButton.addActionListener(new ActionListener() {
-            @Override
-            public void actionPerformed(ActionEvent e) {
-                cancelPressed = true;
-                ResolveDbRelationshipDialog.this.setVisible(false);
-            }
+        cancelButton.addActionListener(e -> {
+            cancelPressed = true;
+            setVisible(false);
         });
     }
 
