@@ -19,30 +19,41 @@
 
 package org.apache.cayenne.modeler.dialog.db;
 
-import org.apache.cayenne.dba.DbAdapter;
-import org.apache.cayenne.modeler.ClassLoadingService;
-import org.apache.cayenne.modeler.dialog.pref.GeneralPreferences;
-import org.apache.cayenne.modeler.dialog.pref.PreferenceDialog;
-import org.apache.cayenne.modeler.event.DataSourceModificationEvent;
-import org.apache.cayenne.modeler.event.DataSourceModificationListener;
-import org.apache.cayenne.modeler.pref.DBConnectionInfo;
-import org.apache.cayenne.modeler.util.CayenneController;
-import org.apache.cayenne.swing.BindingBuilder;
-import org.apache.cayenne.swing.ObjectBinding;
-
 import javax.sql.DataSource;
-import javax.swing.*;
-import java.awt.*;
+import javax.swing.DefaultComboBoxModel;
+import javax.swing.JOptionPane;
+import javax.swing.WindowConstants;
+import java.awt.Component;
 import java.sql.Connection;
 import java.sql.SQLException;
 import java.util.Arrays;
 import java.util.Map;
 import java.util.prefs.Preferences;
 
+import org.apache.cayenne.dba.DbAdapter;
+import org.apache.cayenne.modeler.ClassLoadingService;
+import org.apache.cayenne.modeler.ProjectController;
+import org.apache.cayenne.modeler.action.GetDbConnectionAction;
+import org.apache.cayenne.modeler.dialog.pref.GeneralPreferences;
+import org.apache.cayenne.modeler.dialog.pref.PreferenceDialog;
+import org.apache.cayenne.modeler.event.DataSourceModificationEvent;
+import org.apache.cayenne.modeler.event.DataSourceModificationListener;
+import org.apache.cayenne.modeler.pref.DBConnectionInfo;
+import org.apache.cayenne.modeler.pref.DataMapDefaults;
+import org.apache.cayenne.modeler.util.CayenneController;
+import org.apache.cayenne.swing.BindingBuilder;
+import org.apache.cayenne.swing.ObjectBinding;
+
+import static org.apache.cayenne.modeler.pref.DBConnectionInfo.DB_ADAPTER_PROPERTY;
+import static org.apache.cayenne.modeler.pref.DBConnectionInfo.JDBC_DRIVER_PROPERTY;
+import static org.apache.cayenne.modeler.pref.DBConnectionInfo.PASSWORD_PROPERTY;
+import static org.apache.cayenne.modeler.pref.DBConnectionInfo.URL_PROPERTY;
+import static org.apache.cayenne.modeler.pref.DBConnectionInfo.USER_NAME_PROPERTY;
+
 /**
  * A subclass of ConnectionWizard that tests configured DataSource, but does not
  * keep an open connection.
- * 
+ *
  */
 public class DataSourceWizard extends CayenneController {
 
@@ -50,6 +61,7 @@ public class DataSourceWizard extends CayenneController {
 	private ObjectBinding dataSourceBinding;
 	private Map<String, DBConnectionInfo> dataSources;
 	private String dataSourceKey;
+	private ProjectController projectController;
 
 	// this object is a clone of an object selected from the dropdown, as we
 	// need to allow
@@ -63,26 +75,38 @@ public class DataSourceWizard extends CayenneController {
 	private DbAdapter adapter;
 	private DataSource dataSource;
 
-	public DataSourceWizard(CayenneController parent, String title) {
+	public DataSourceWizard(final CayenneController parent, final String title) {
 		super(parent);
 
-		this.view = createView();
+		this.view = createView(title);
 		this.view.setTitle(title);
 		this.connectionInfo = new DBConnectionInfo();
+		this.projectController = (ProjectController) parent;
 
 		initBindings();
 		initDataSourceListener();
 	}
 
+	private String[] getLabelsForDialog(final String viewTitle) {
+		switch (viewTitle) {
+			case GetDbConnectionAction.DIALOG_TITLE: {
+				return new String[]{"Save", "Cancel"};
+			}
+			default:
+				return new String[]{"Continue", "Cancel"};
+		}
+	}
+
 	/**
 	 * Creates swing dialog for this wizard
 	 */
-	private DataSourceWizardView createView() {
-		return new DataSourceWizardView(this);
+	private DataSourceWizardView createView(final String viewTitle) {
+		final String[] labels = getLabelsForDialog(viewTitle);
+		return new DataSourceWizardView(this, labels);
 	}
 
 	protected void initBindings() {
-		BindingBuilder builder = new BindingBuilder(getApplication().getBindingFactory(), this);
+		final BindingBuilder builder = new BindingBuilder(getApplication().getBindingFactory(), this);
 
 		dataSourceBinding = builder.bindToComboSelection(view.getDataSources(), "dataSourceKey");
 
@@ -107,9 +131,9 @@ public class DataSourceWizard extends CayenneController {
 	}
 
 	private void initFavouriteDataSource() {
-		Preferences pref = getApplication().getPreferencesNode(GeneralPreferences.class, "");
-		String favouriteDataSource = pref.get(GeneralPreferences.FAVOURITE_DATA_SOURCE, null);
-		if(favouriteDataSource != null && dataSources.containsKey(favouriteDataSource)) {
+		final Preferences pref = getApplication().getPreferencesNode(GeneralPreferences.class, "");
+		final String favouriteDataSource = pref.get(GeneralPreferences.FAVOURITE_DATA_SOURCE, null);
+		if (favouriteDataSource != null && dataSources.containsKey(favouriteDataSource)) {
 			setDataSourceKey(favouriteDataSource);
 			dataSourceBinding.updateView();
 		}
@@ -120,21 +144,32 @@ public class DataSourceWizard extends CayenneController {
 				.removeDataSourceModificationListener(dataSourceListener);
 	}
 
+	private DBConnectionInfo getConnectionInfoFromPreferences() {
+		final DBConnectionInfo connectionInfo = new DBConnectionInfo();
+		final DataMapDefaults dataMapDefaults = projectController.
+				getDataMapPreferences(projectController.getCurrentDataMap());
+		connectionInfo.setDbAdapter(dataMapDefaults.getCurrentPreference().get(DB_ADAPTER_PROPERTY, null));
+		connectionInfo.setUrl(dataMapDefaults.getCurrentPreference().get(URL_PROPERTY, null));
+		connectionInfo.setUserName(dataMapDefaults.getCurrentPreference().get(USER_NAME_PROPERTY, null));
+		connectionInfo.setPassword(dataMapDefaults.getCurrentPreference().get(PASSWORD_PROPERTY, null));
+		connectionInfo.setJdbcDriver(dataMapDefaults.getCurrentPreference().get(JDBC_DRIVER_PROPERTY, null));
+		return connectionInfo;
+	}
+
 	public String getDataSourceKey() {
 		return dataSourceKey;
 	}
 
-	public void setDataSourceKey(String dataSourceKey) {
+	public void setDataSourceKey(final String dataSourceKey) {
 		this.dataSourceKey = dataSourceKey;
 
 		// update a clone object that will be used to obtain connection...
-		DBConnectionInfo currentInfo = dataSources.get(dataSourceKey);
+		final DBConnectionInfo currentInfo = dataSources.get(dataSourceKey);
 		if (currentInfo != null) {
 			currentInfo.copyTo(connectionInfo);
 		} else {
 			connectionInfo = new DBConnectionInfo();
 		}
-
 		view.getConnectionInfo().setConnectionInfo(connectionInfo);
 	}
 
@@ -144,13 +179,18 @@ public class DataSourceWizard extends CayenneController {
 	 */
 	public boolean startupAction() {
 		this.canceled = true;
-
 		refreshDataSources();
 		initFavouriteDataSource();
 
+		final DataMapDefaults dataMapDefaults = projectController.
+				getDataMapPreferences(projectController.getCurrentDataMap());
+		if (dataMapDefaults.getCurrentPreference().get(DB_ADAPTER_PROPERTY, null) != null) {
+			getConnectionInfoFromPreferences().copyTo(connectionInfo);
+		}
 		view.pack();
 		view.setDefaultCloseOperation(WindowConstants.DISPOSE_ON_CLOSE);
 		view.setModal(true);
+		view.connectionInfo.setConnectionInfo(connectionInfo);
 		makeCloseableOnEscape();
 		centerView();
 		view.setVisible(true);
@@ -167,16 +207,22 @@ public class DataSourceWizard extends CayenneController {
 	 * conneciton. Does not store the open connection.
 	 */
 	public void okAction() {
-		DBConnectionInfo info = getConnectionInfo();
-		ClassLoadingService classLoader = getApplication().getClassLoadingService();
+		final DBConnectionInfo info = getConnectionInfo();
+		final ClassLoadingService classLoader = getApplication().getClassLoadingService();
 
 		// doing connection testing...
 		try {
-			this.adapter = info.makeAdapter(classLoader);
-			this.dataSource = info.makeDataSource(classLoader);
-			try (Connection connection = dataSource.getConnection()) {
+			try {
+				this.adapter = info.makeAdapter(classLoader);
+				this.dataSource = info.makeDataSource(classLoader);
 			} catch (SQLException ignore) {
+				showNoConnectorDialog("Unable to load driver '" + info.getJdbcDriver() + "'");
+				return;
 			}
+
+			// Test connection
+			try (Connection connection = dataSource.getConnection()) {
+            }
 		} catch (Throwable th) {
 			reportError("Connection Error", th);
 			return;
@@ -191,7 +237,7 @@ public class DataSourceWizard extends CayenneController {
 	/**
 	 * On close handler. Introduced to remove data source listener.
 	 */
-	protected void onClose(boolean canceled) {
+	protected void onClose(final boolean canceled) {
 		// set success flag, and unblock the caller...
 		this.canceled = canceled;
 		view.dispose();
@@ -206,18 +252,27 @@ public class DataSourceWizard extends CayenneController {
 	 * Opens preferences panel to allow configuration of DataSource presets.
 	 */
 	public void dataSourceConfigAction() {
-		PreferenceDialog prefs = new PreferenceDialog(this);
+		final PreferenceDialog prefs = new PreferenceDialog(this);
 		prefs.showDataSourceEditorAction(dataSourceKey);
 		refreshDataSources();
 	}
 
+	/**
+	 * Opens preferences panel to allow configuration of classpath.
+	 */
+	public void classPathConfigAction() {
+		final PreferenceDialog prefs = new PreferenceDialog(this);
+		prefs.showClassPathEditorAction();
+		refreshDataSources();
+	}
+
 	public Component getView() {
 		return view;
 	}
 
 	@SuppressWarnings("unchecked")
 	private void refreshDataSources() {
-		this.dataSources = (Map<String, DBConnectionInfo>)getApplication().getCayenneProjectPreferences().getDetailObject(DBConnectionInfo.class)
+		this.dataSources = (Map<String, DBConnectionInfo>) getApplication().getCayenneProjectPreferences().getDetailObject(DBConnectionInfo.class)
 				.getChildrenPreferences();
 
 		// 1.2 migration fix - update data source adapter names
@@ -228,7 +283,7 @@ public class DataSourceWizard extends CayenneController {
 			}
 		}
 
-		String[] keys = dataSources.keySet().toArray(new String[0]);
+		final String[] keys = dataSources.keySet().toArray(new String[0]);
 		Arrays.sort(keys);
 		view.getDataSources().setModel(new DefaultComboBoxModel<>(keys));
 
@@ -243,6 +298,16 @@ public class DataSourceWizard extends CayenneController {
 		dataSourceBinding.updateView();
 	}
 
+	protected void showNoConnectorDialog(String message) {
+		final String[] options = {"Setup driver", "Cancel"};
+
+		final int selection = JOptionPane.showOptionDialog(getView(), message, "Configuration error",
+				JOptionPane.OK_CANCEL_OPTION, JOptionPane.ERROR_MESSAGE, null, options, options[0]);
+		if (selection == 0) {
+			classPathConfigAction();
+		}
+	}
+
 	public DataSource getDataSource() {
 		return dataSource;
 	}
