@@ -18,21 +18,20 @@
  ****************************************************************/
 package org.apache.cayenne.modeler.dialog.objentity;
 
-import org.apache.cayenne.map.DbEntity;
-import org.apache.cayenne.modeler.ProjectController;
-import org.apache.cayenne.modeler.util.CayenneController;
-import org.apache.cayenne.modeler.util.Comparators;
+import java.awt.Component;
+import java.util.ArrayList;
+import java.util.List;
 
+import javax.swing.DefaultComboBoxModel;
 import javax.swing.JOptionPane;
 import javax.swing.WindowConstants;
-import javax.swing.event.ChangeEvent;
-import javax.swing.event.ChangeListener;
-import java.awt.Component;
-import java.awt.event.ActionEvent;
-import java.awt.event.ActionListener;
-import java.util.ArrayList;
-import java.util.Collections;
-import java.util.List;
+
+import org.apache.cayenne.map.DbEntity;
+import org.apache.cayenne.map.EntityResolver;
+import org.apache.cayenne.modeler.ProjectController;
+import org.apache.cayenne.modeler.util.CayenneController;
+import org.apache.cayenne.modeler.util.CellRenderers;
+import org.apache.cayenne.modeler.util.Comparators;
 
 public class DbRelationshipTarget extends CayenneController {
 
@@ -42,7 +41,7 @@ public class DbRelationshipTarget extends CayenneController {
     protected List<DbEntity> relTargets;
 
     protected DbEntity source;
-    protected ProjectController mediator;
+    protected CayenneController mediator;
     protected boolean source1Selected;
     protected DbRelationshipTargetView view;
     protected boolean toMany;
@@ -58,45 +57,25 @@ public class DbRelationshipTarget extends CayenneController {
         this.mediator = mediator;
         this.source1 = source1;
         this.source2 = source2;
-        this.relTargets = new ArrayList<>(source1.getDataMap().getDbEntities());
-        Collections.sort(relTargets, Comparators.getNamedObjectComparator());
+
+        EntityResolver resolver = mediator.getEntityResolver();
+        this.relTargets = new ArrayList<>(resolver.getDbEntities());
+        relTargets.sort(Comparators.getNamedObjectComparator());
+
+        DbEntity[] dbEntities = relTargets.toArray(new DbEntity[0]);
+
+        DefaultComboBoxModel<DbEntity> dbModel = new DefaultComboBoxModel<>(dbEntities);
+        view.targetCombo.setRenderer(CellRenderers.entityListRendererWithIcons(mediator.getCurrentDataMap()));
         view.targetCombo.removeAllItems();
-        for (DbEntity d : relTargets) {
-            view.targetCombo.addItem(d.getName());
-        }
+        view.targetCombo.setModel(dbModel);
     }
         
     private void initController() {
-        view.getCancelButton().addActionListener(new ActionListener() {
-            @Override
-            public void actionPerformed(ActionEvent e) {
-                view.dispose();
-            }
-        });
-        view.getSaveButton().addActionListener(new ActionListener() {
-            @Override
-            public void actionPerformed(ActionEvent e) {
-                DbRelationshipTarget.this.save();
-            }
-        });
-        view.getSource1Button().addActionListener(new ActionListener() {
-            @Override
-            public void actionPerformed(ActionEvent e) {
-                DbRelationshipTarget.this.setSource(source1, true);
-            }
-        });
-        view.getSource2Button().addActionListener(new ActionListener() {
-            @Override
-            public void actionPerformed(ActionEvent e) {
-                DbRelationshipTarget.this.setSource(source2, false);
-            }
-        });
-        view.getToManyCheckBox().addChangeListener(new ChangeListener() {
-            @Override
-            public void stateChanged(ChangeEvent e) {
-                toMany = view.getToManyCheckBox().isSelected();
-            }
-        });
+        view.getCancelButton().addActionListener(e -> view.dispose());
+        view.getSaveButton().addActionListener(e -> save());
+        view.getSource1Button().addActionListener(e -> setSource(source1, true));
+        view.getSource2Button().addActionListener(e -> setSource(source2, false));
+        view.getToManyCheckBox().addChangeListener(e -> toMany = view.getToManyCheckBox().isSelected());
     }
     
     @Override
