@@ -47,13 +47,9 @@ import javax.swing.event.TreeSelectionEvent;
 import javax.swing.event.TreeSelectionListener;
 import javax.swing.tree.TreePath;
 import java.awt.Component;
-import java.awt.event.ActionEvent;
-import java.awt.event.ActionListener;
 import java.awt.event.ItemEvent;
-import java.awt.event.ItemListener;
 import java.util.ArrayList;
 import java.util.Collection;
-import java.util.Collections;
 import java.util.List;
 import java.util.Objects;
 
@@ -141,52 +137,19 @@ public class ObjRelationshipInfo extends CayenneController implements TreeSelect
     }
 
     private void initController() {
-        view.getCancelButton().addActionListener(new ActionListener() {
-            @Override
-            public void actionPerformed(ActionEvent e) {
-                view.dispose();
-            }
-        });
-        view.getSaveButton().addActionListener(new ActionListener() {
-            @Override
-            public void actionPerformed(ActionEvent e) {
-                ObjRelationshipInfo.this.saveMapping();
-            }
-        });
-        view.getNewRelButton().addActionListener(new ActionListener() {
-            @Override
-            public void actionPerformed(ActionEvent e) {
-                ObjRelationshipInfo.this.createRelationship();
-            }
-        });
-        view.getSelectPathButton().addActionListener(new ActionListener() {
-            @Override
-            public void actionPerformed(ActionEvent e) {
-                ObjRelationshipInfo.this.selectPath();
-            }
-        });
-        view.getCollectionTypeCombo().addActionListener(new ActionListener() {
-            @Override
-            public void actionPerformed(ActionEvent e) {
-                ObjRelationshipInfo.this.setCollectionType();
-            }
-        });
-        view.getMapKeysCombo().addActionListener(new ActionListener() {
-            @Override
-            public void actionPerformed(ActionEvent e) {
-                ObjRelationshipInfo.this.setMapKey();
-            }
-        });
-        view.getTargetCombo().addItemListener(new ItemListener() {
-            @Override
-            public void itemStateChanged(ItemEvent e) {
-                if (e.getStateChange() == ItemEvent.SELECTED) {
-                    Object targetName = e.getItem();
-                    for (ObjEntity target : objectTargets) {
-                        if (Objects.equals(target.getName(), targetName)) {
-                            ObjRelationshipInfo.this.setObjectTarget(target);
-                            return;
-                        }
+        view.getCancelButton().addActionListener(e -> view.dispose());
+        view.getSaveButton().addActionListener(e -> saveMapping());
+        view.getNewRelButton().addActionListener(e -> createRelationship());
+        view.getSelectPathButton().addActionListener(e -> selectPath());
+        view.getCollectionTypeCombo().addActionListener(e -> setCollectionType());
+        view.getMapKeysCombo().addActionListener(e -> setMapKey());
+        view.getTargetCombo().addItemListener(e -> {
+            if (e.getStateChange() == ItemEvent.SELECTED) {
+                Object targetName = e.getItem();
+                for (ObjEntity target : objectTargets) {
+                    if (Objects.equals(target.getName(), targetName)) {
+                        setObjectTarget(target);
+                        return;
                     }
                 }
             }
@@ -292,7 +255,7 @@ public class ObjRelationshipInfo extends CayenneController implements TreeSelect
      */
     protected void clearPath() {
         getPathBrowser().clearSelection();
-        setDbRelationships(new ArrayList<DbRelationship>());
+        setDbRelationships(new ArrayList<>());
     }
 
     protected void saveMapping() {
@@ -456,7 +419,7 @@ public class ObjRelationshipInfo extends CayenneController implements TreeSelect
 
         if (dbTarget != null) {
             objectTargets.addAll(dbTarget.getDataMap().getMappedEntities(dbTarget));
-            Collections.sort(objectTargets, Comparators.getNamedObjectComparator());
+            objectTargets.sort(Comparators.getNamedObjectComparator());
         }
         view.targetCombo.removeAllItems();
         for (ObjEntity s : objectTargets) {
