@@ -27,11 +27,11 @@ import java.sql.SQLException;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.StringTokenizer;
 import java.util.prefs.Preferences;
+import java.util.stream.Collectors;
 
 import javax.swing.DefaultComboBoxModel;
 import javax.swing.JOptionPane;
@@ -39,7 +39,6 @@ import javax.swing.JOptionPane;
 import org.apache.cayenne.datasource.DriverDataSource;
 import org.apache.cayenne.map.event.MapEvent;
 import org.apache.cayenne.modeler.FileClassLoadingService;
-import org.apache.cayenne.modeler.ProjectController;
 import org.apache.cayenne.modeler.event.DataSourceModificationEvent;
 import org.apache.cayenne.modeler.pref.DBConnectionInfo;
 import org.apache.cayenne.modeler.util.CayenneController;
@@ -48,8 +47,6 @@ import org.apache.cayenne.pref.ChildrenMapPreference;
 import org.apache.cayenne.pref.PreferenceEditor;
 import org.apache.cayenne.swing.BindingBuilder;
 import org.apache.cayenne.util.Util;
-import org.apache.commons.collections.CollectionUtils;
-import org.apache.commons.collections.Transformer;
 
 /**
  * Editor for the local DataSources configured in preferences.
@@ -80,7 +77,7 @@ public class DataSourcePreferences extends CayenneController {
 
 		Object[] keys = dataSources.keySet().toArray();
 		Arrays.sort(keys);
-		DefaultComboBoxModel dataSourceModel = new DefaultComboBoxModel(keys);
+		DefaultComboBoxModel<Object> dataSourceModel = new DefaultComboBoxModel<>(keys);
 		view.getDataSources().setModel(dataSourceModel);
 
 		initBindings();
@@ -127,7 +124,6 @@ public class DataSourcePreferences extends CayenneController {
 	 * Shows a dialog to create new local DataSource configuration.
 	 */
 	public void newDataSourceAction() {
-
 		DataSourceCreator creatorWizard = new DataSourceCreator(this);
 		DBConnectionInfo dataSource = creatorWizard.startupAction();
 
@@ -137,7 +133,7 @@ public class DataSourcePreferences extends CayenneController {
 
 			Object[] keys = dataSources.keySet().toArray();
 			Arrays.sort(keys);
-			view.getDataSources().setModel(new DefaultComboBoxModel(keys));
+			view.getDataSources().setModel(new DefaultComboBoxModel<>(keys));
 			view.getDataSources().setSelectedItem(creatorWizard.getName());
 			editDataSourceAction();
 			fireEvent(creatorWizard.getName(), MapEvent.ADD);
@@ -159,7 +155,7 @@ public class DataSourcePreferences extends CayenneController {
 
 				Object[] keys = dataSources.keySet().toArray();
 				Arrays.sort(keys);
-				view.getDataSources().setModel(new DefaultComboBoxModel(keys));
+				view.getDataSources().setModel(new DefaultComboBoxModel<>(keys));
 				view.getDataSources().setSelectedItem(wizard.getName());
 				editDataSourceAction();
 				fireEvent(wizard.getName(), MapEvent.ADD);
@@ -178,7 +174,7 @@ public class DataSourcePreferences extends CayenneController {
 			dataSources = dataSourcePreferences.getChildrenPreferences();
 			Object[] keys = dataSources.keySet().toArray();
 			Arrays.sort(keys);
-			view.getDataSources().setModel(new DefaultComboBoxModel(keys));
+			view.getDataSources().setModel(new DefaultComboBoxModel<>(keys));
 			editDataSourceAction(keys.length > 0 ? keys[0] : null);
 			fireEvent(key, MapEvent.REMOVE);
 		}
@@ -215,12 +211,12 @@ public class DataSourcePreferences extends CayenneController {
 		}
 
 		if (currentDataSource.getJdbcDriver() == null) {
-			JOptionPane.showMessageDialog(null, "No JDBC Driver specified", "Warning", JOptionPane.WARNING_MESSAGE);
+			JOptionPane.showMessageDialog(view, "No JDBC Driver specified", "Warning", JOptionPane.WARNING_MESSAGE);
 			return;
 		}
 
 		if (currentDataSource.getUrl() == null) {
-			JOptionPane.showMessageDialog(null, "No Database URL specified", "Warning", JOptionPane.WARNING_MESSAGE);
+			JOptionPane.showMessageDialog(view, "No Database URL specified", "Warning", JOptionPane.WARNING_MESSAGE);
 			return;
 		}
 
@@ -260,17 +256,7 @@ public class DataSourcePreferences extends CayenneController {
 			}
 
 			if (details.size() > 0) {
-
-				// transform preference to file...
-				Transformer transformer = new Transformer() {
-
-					public Object transform(Object object) {
-						String pref = (String) object;
-						return new File(pref);
-					}
-				};
-
-				classLoader.setPathFiles(CollectionUtils.collect(details, transformer));
+				classLoader.setPathFiles(details.stream().map(File::new).collect(Collectors.toList()));
 			}
 
 			Class<Driver> driverClass = classLoader.loadClass(Driver.class, currentDataSource.getJdbcDriver());
@@ -287,7 +273,7 @@ public class DataSourcePreferences extends CayenneController {
 				// i guess we can ignore this...
 			}
 
-			JOptionPane.showMessageDialog(null, "Connected Successfully", "Success", JOptionPane.INFORMATION_MESSAGE);
+			JOptionPane.showMessageDialog(view, "Connected Successfully", "Success", JOptionPane.INFORMATION_MESSAGE);
 		} catch (Throwable th) {
 			th = Util.unwindException(th);
 			String message = "Error connecting to DB: " + th.getLocalizedMessage();
@@ -308,7 +294,7 @@ public class DataSourcePreferences extends CayenneController {
 				sbMessage.append(tempString).append(" ");
 			}
 
-			JOptionPane.showMessageDialog(null, sbMessage.toString(), "Warning", JOptionPane.WARNING_MESSAGE);
+			JOptionPane.showMessageDialog(view, sbMessage.toString(), "Warning", JOptionPane.WARNING_MESSAGE);
 		}
 	}
 }
