@@ -19,14 +19,6 @@
 
 package org.apache.cayenne.modeler.dialog.pref;
 
-import java.awt.Component;
-import java.util.ArrayList;
-import java.util.List;
-import java.util.prefs.BackingStoreException;
-import java.util.prefs.Preferences;
-
-import javax.swing.table.AbstractTableModel;
-
 import org.apache.cayenne.modeler.CodeTemplateManager;
 import org.apache.cayenne.modeler.pref.FSPath;
 import org.apache.cayenne.modeler.util.CayenneController;
@@ -38,6 +30,14 @@ import org.apache.cayenne.swing.TableBindingBuilder;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import javax.swing.table.AbstractTableModel;
+import java.awt.Component;
+import java.nio.file.Paths;
+import java.util.ArrayList;
+import java.util.List;
+import java.util.prefs.BackingStoreException;
+import java.util.prefs.Preferences;
+
 public class TemplatePreferences extends CayenneController {
 
     protected TemplatePreferencesView view;
@@ -120,9 +120,28 @@ public class TemplatePreferences extends CayenneController {
     }
 
     public void addTemplateAction() {
-
         FSPath path = new TemplateCreator(this).startupAction();
+        addToTemplateEntries(path);
+    }
 
+    void addTemplateAction(String templatePath, String superTemplatePath) {
+        if(templatePath != null) {
+            createTemplate(templatePath);
+        }
+        if(superTemplatePath != null) {
+            createTemplate(superTemplatePath);
+        }
+    }
+
+    private void createTemplate(String templatePath) {
+        TemplateCreator templateCreator = new TemplateCreator(this);
+        TemplateCreatorView creatorView = (TemplateCreatorView)templateCreator.getView();
+        creatorView.getTemplateChooser().setFile(Paths.get(templatePath).toFile());
+        FSPath path = templateCreator.startupAction();
+        addToTemplateEntries(path);
+    }
+
+    private void addToTemplateEntries(FSPath path) {
         if (path != null) {
             int len = templateEntries.size();
             templateEntries.add(path);
