@@ -26,6 +26,7 @@ import org.apache.cayenne.access.DataDomain;
 import org.apache.cayenne.configuration.DataChannelDescriptor;
 import org.apache.cayenne.configuration.event.DomainEvent;
 import org.apache.cayenne.modeler.Application;
+import org.apache.cayenne.swing.components.JCayenneCheckBox;
 import org.apache.cayenne.modeler.ProjectController;
 import org.apache.cayenne.modeler.event.DomainDisplayEvent;
 import org.apache.cayenne.modeler.event.DomainDisplayListener;
@@ -38,8 +39,6 @@ import javax.swing.JCheckBox;
 import javax.swing.JPanel;
 import javax.swing.JTextField;
 import java.awt.BorderLayout;
-import java.awt.event.ActionEvent;
-import java.awt.event.ActionListener;
 import java.util.Map;
 import java.util.prefs.Preferences;
 
@@ -74,8 +73,8 @@ public class DataDomainView extends JPanel implements DomainDisplayListener {
             }
         };
 
-        this.objectValidation = new JCheckBox();
-        this.sharedCache = new JCheckBox();
+        this.objectValidation = new JCayenneCheckBox();
+        this.sharedCache = new JCayenneCheckBox();
 
         // assemble
         CellConstraints cc = new CellConstraints();
@@ -103,27 +102,21 @@ public class DataDomainView extends JPanel implements DomainDisplayListener {
     protected void initController() {
         projectController.addDomainDisplayListener(this);
 
-        // add action listener to checkboxes
-        objectValidation.addActionListener(new ActionListener() {
-
-            public void actionPerformed(ActionEvent e) {
-                String value = objectValidation.isSelected() ? "true" : "false";
-                setDomainProperty(
-                        DataDomain.VALIDATING_OBJECTS_ON_COMMIT_PROPERTY,
-                        value,
-                        Boolean.toString(DataDomain.VALIDATING_OBJECTS_ON_COMMIT_DEFAULT));
-            }
+        // add item listener to checkboxes
+        objectValidation.addItemListener(e -> {
+            String value = objectValidation.isSelected() ? "true" : "false";
+            setDomainProperty(
+                    DataDomain.VALIDATING_OBJECTS_ON_COMMIT_PROPERTY,
+                    value,
+                    Boolean.toString(DataDomain.VALIDATING_OBJECTS_ON_COMMIT_DEFAULT));
         });
 
-        sharedCache.addActionListener(new ActionListener() {
-
-            public void actionPerformed(ActionEvent e) {
-                String value = sharedCache.isSelected() ? "true" : "false";
-                setDomainProperty(
-                        DataDomain.SHARED_CACHE_ENABLED_PROPERTY,
-                        value,
-                        Boolean.toString(DataDomain.SHARED_CACHE_ENABLED_DEFAULT));
-            }
+        sharedCache.addItemListener(e -> {
+            String value = sharedCache.isSelected() ? "true" : "false";
+            setDomainProperty(
+                    DataDomain.SHARED_CACHE_ENABLED_PROPERTY,
+                    value,
+                    Boolean.toString(DataDomain.SHARED_CACHE_ENABLED_DEFAULT));
         });
 
     }
@@ -152,8 +145,8 @@ public class DataDomainView extends JPanel implements DomainDisplayListener {
             value = null;
         }
 
-        Map properties = domain.getProperties();
-        Object oldValue = properties.get(property);
+        Map<String, String> properties = domain.getProperties();
+        String oldValue = properties.get(property);
         if (!Util.nullSafeEquals(value, oldValue)) {
             properties.put(property, value);
 
@@ -172,7 +165,7 @@ public class DataDomainView extends JPanel implements DomainDisplayListener {
             return null;
         }
 
-        String value = (String) domain.getProperties().get(property);
+        String value = domain.getProperties().get(property);
         return value != null ? value : defaultValue;
     }
 
