@@ -27,6 +27,7 @@ import org.apache.cayenne.configuration.event.DataMapEvent;
 import org.apache.cayenne.map.DataMap;
 import org.apache.cayenne.map.ObjEntity;
 import org.apache.cayenne.modeler.Application;
+import org.apache.cayenne.swing.components.JCayenneCheckBox;
 import org.apache.cayenne.modeler.ProjectController;
 import org.apache.cayenne.modeler.action.LinkDataMapAction;
 import org.apache.cayenne.modeler.dialog.datamap.CatalogUpdateController;
@@ -34,13 +35,12 @@ import org.apache.cayenne.modeler.dialog.datamap.LockingUpdateController;
 import org.apache.cayenne.modeler.dialog.datamap.PackageUpdateController;
 import org.apache.cayenne.modeler.dialog.datamap.SchemaUpdateController;
 import org.apache.cayenne.modeler.dialog.datamap.SuperclassUpdateController;
-import org.apache.cayenne.modeler.event.DataMapDisplayEvent;
-import org.apache.cayenne.modeler.event.DataMapDisplayListener;
 import org.apache.cayenne.modeler.pref.DataMapDefaults;
 import org.apache.cayenne.modeler.util.CellRenderers;
 import org.apache.cayenne.modeler.util.Comparators;
 import org.apache.cayenne.modeler.util.ProjectUtil;
 import org.apache.cayenne.modeler.util.TextAdapter;
+import org.apache.cayenne.project.extension.info.ObjectInfo;
 import org.apache.cayenne.util.Util;
 import org.apache.cayenne.validation.ValidationException;
 
@@ -52,8 +52,6 @@ import javax.swing.JLabel;
 import javax.swing.JPanel;
 import javax.swing.JTextField;
 import java.awt.BorderLayout;
-import java.awt.event.ActionEvent;
-import java.awt.event.ActionListener;
 import java.util.Arrays;
 
 /**
@@ -65,7 +63,7 @@ public class DataMapView extends JPanel {
 
     protected TextAdapter name;
     protected JLabel location;
-    protected JComboBox nodeSelector;
+    protected JComboBox<DataNodeDescriptor> nodeSelector;
     protected JCheckBox defaultLockType;
     protected TextAdapter defaultCatalog;
     protected TextAdapter defaultSchema;
@@ -73,6 +71,8 @@ public class DataMapView extends JPanel {
     protected TextAdapter defaultSuperclass;
     protected JCheckBox quoteSQLIdentifiers;
 
+    protected TextAdapter comment;
+
     protected JButton updateDefaultCatalog;
     protected JButton updateDefaultSchema;
     protected JButton updateDefaultPackage;
@@ -125,7 +125,14 @@ public class DataMapView extends JPanel {
             }
         };
 
-        quoteSQLIdentifiers = new JCheckBox();
+        quoteSQLIdentifiers = new JCayenneCheckBox();
+
+        comment = new TextAdapter(new JTextField()) {
+            @Override
+            protected void updateModel(String text) throws ValidationException {
+                updateComment(text);
+            }
+        };
 
         updateDefaultPackage = new JButton("Update...");
         defaultPackage = new TextAdapter(new JTextField()) {
@@ -144,9 +151,9 @@ public class DataMapView extends JPanel {
         };
 
         updateDefaultLockType = new JButton("Update...");
-        defaultLockType = new JCheckBox();
+        defaultLockType = new JCayenneCheckBox();
 
-        clientSupport = new JCheckBox();
+        clientSupport = new JCayenneCheckBox();
         updateDefaultClientPackage = new JButton("Update...");
         defaultClientPackage = new TextAdapter(new JTextField()) {
 
@@ -175,6 +182,7 @@ public class DataMapView extends JPanel {
         builder.append("File:", location, 3);
         builder.append("DataNode:", nodeSelector, 2);
         builder.append("Quote SQL Identifiers:", quoteSQLIdentifiers, 3);
+        builder.append("Comment:", comment.getComponent(), 2);
 
         builder.appendSeparator("Entity Defaults");
         builder.append("DB Catalog:", defaultCatalog.getComponent(), updateDefaultCatalog);
@@ -205,94 +213,26 @@ public class DataMapView extends JPanel {
     }
 
     private void initController() {
-        eventController.addDataMapDisplayListener(new DataMapDisplayListener() {
-
-            public void currentDataMapChanged(DataMapDisplayEvent e) {
-                DataMap map = e.getDataMap();
-                if (map != null) {
-                    initFromModel(map);
-                }
+        eventController.addDataMapDisplayListener(e -> {
+            DataMap map = e.getDataMap();
+            if (map != null) {
+                initFromModel(map);
             }
         });
 
-        nodeSelector.addActionListener(new ActionListener() {
-
-            public void actionPerformed(ActionEvent e) {
-                setDataNode();
-            }
-        });
-
-        quoteSQLIdentifiers.addActionListener(new ActionListener() {
-
-            public void actionPerformed(ActionEvent e) {
-                setQuoteSQLIdentifiers(quoteSQLIdentifiers.isSelected());
-            }
-        });
-
-        defaultLockType.addActionListener(new ActionListener() {
-
-            public void actionPerformed(ActionEvent e) {
-                setDefaultLockType(defaultLockType.isSelected()
-                        ? ObjEntity.LOCK_TYPE_OPTIMISTIC
-                        : ObjEntity.LOCK_TYPE_NONE);
-            }
-        });
-
-        clientSupport.addActionListener(new ActionListener() {
-
-            public void actionPerformed(ActionEvent e) {
-                setClientSupport(clientSupport.isSelected());
-            }
-        });
-
-        updateDefaultClientPackage.addActionListener(new ActionListener() {
-
-            public void actionPerformed(ActionEvent e) {
-                updateDefaultClientPackage();
-            }
-        });
-
-        updateDefaultClientSuperclass.addActionListener(new ActionListener() {
-
-            public void actionPerformed(ActionEvent e) {
-                updateDefaultClientSuperclass();
-            }
-        });
-        
-        updateDefaultCatalog.addActionListener(new ActionListener() {
-
-            public void actionPerformed(ActionEvent e) {
-                updateDefaultCatalog();
-            }
-        });
-
-        updateDefaultSchema.addActionListener(new ActionListener() {
-
-            public void actionPerformed(ActionEvent e) {
-                updateDefaultSchema();
-            }
-        });
-
-        updateDefaultPackage.addActionListener(new ActionListener() {
-
-            public void actionPerformed(ActionEvent e) {
-                updateDefaultPackage();
-            }
-        });
-
-        updateDefaultSuperclass.addActionListener(new ActionListener() {
-
-            public void actionPerformed(ActionEvent e) {
-                updateDefaultSuperclass();
-            }
-        });
-
-        updateDefaultLockType.addActionListener(new ActionListener() {
-
-            public void actionPerformed(ActionEvent e) {
-                updateDefaultLockType();
-            }
-        });
+        nodeSelector.addActionListener(e -> setDataNode());
+        quoteSQLIdentifiers.addItemListener(e -> setQuoteSQLIdentifiers(quoteSQLIdentifiers.isSelected()));
+        defaultLockType.addItemListener(e -> setDefaultLockType(defaultLockType.isSelected()
+                ? ObjEntity.LOCK_TYPE_OPTIMISTIC
+                : ObjEntity.LOCK_TYPE_NONE));
+        clientSupport.addItemListener(e -> setClientSupport(clientSupport.isSelected()));
+        updateDefaultClientPackage.addActionListener(e -> updateDefaultClientPackage());
+        updateDefaultClientSuperclass.addActionListener(e -> updateDefaultClientSuperclass());
+        updateDefaultCatalog.addActionListener(e -> updateDefaultCatalog());
+        updateDefaultSchema.addActionListener(e -> updateDefaultSchema());
+        updateDefaultPackage.addActionListener(e -> updateDefaultPackage());
+        updateDefaultSuperclass.addActionListener(e -> updateDefaultSuperclass());
+        updateDefaultLockType.addActionListener(e -> updateDefaultLockType());
     }
 
     /**
@@ -301,19 +241,17 @@ public class DataMapView extends JPanel {
      */
     private void initFromModel(DataMap map) {
         name.setText(map.getName());
-        String locationText = map.getLocation();
-        location.setText((locationText != null) ? locationText : "(no file)");
-
+        location.setText((map.getLocation() != null) ? map.getLocation() : "(no file)");
         quoteSQLIdentifiers.setSelected(map.isQuotingSQLIdentifiers());
+        comment.setText(getComment(map));
+
         // rebuild data node list
 
-        Object nodes[] = ((DataChannelDescriptor) eventController
-                .getProject()
-                .getRootNode()).getNodeDescriptors().toArray();
+        DataNodeDescriptor nodes[] = ((DataChannelDescriptor) eventController.getProject().getRootNode())
+                .getNodeDescriptors().toArray(new DataNodeDescriptor[0]);
 
         // add an empty item to the front
-        Object[] objects = new Object[nodes.length + 1];
-        // objects[0] = null;
+        DataNodeDescriptor[] objects = new DataNodeDescriptor[nodes.length + 1];
 
         // now add the entities
         if (nodes.length > 0) {
@@ -321,11 +259,10 @@ public class DataMapView extends JPanel {
             System.arraycopy(nodes, 0, objects, 1, nodes.length);
         }
 
-        DefaultComboBoxModel model = new DefaultComboBoxModel(objects);
+        DefaultComboBoxModel<DataNodeDescriptor> model = new DefaultComboBoxModel<>(objects);
 
         // find selected node
-        for (int i = 0; i < nodes.length; i++) {
-            DataNodeDescriptor node = (DataNodeDescriptor) nodes[i];
+        for (DataNodeDescriptor node : nodes) {
             if (node.getDataMapNames().contains(map.getName())) {
                 model.setSelectedItem(node);
                 break;
@@ -475,7 +412,7 @@ public class DataMapView extends JPanel {
         dataMap.setDefaultClientSuperclass(newSuperclass);
         eventController.fireDataMapEvent(new DataMapEvent(this, dataMap));
     }
-    
+
     void setDefaultCatalog(String newCatalog) {
         DataMap dataMap = eventController.getCurrentDataMap();
 
@@ -579,7 +516,7 @@ public class DataMapView extends JPanel {
         LinkDataMapAction action = eventController.getApplication().getActionManager().getAction(LinkDataMapAction.class);
         action.linkDataMap(map, node);
     }
-    
+
     void updateDefaultCatalog() {
         DataMap dataMap = eventController.getCurrentDataMap();
 
@@ -663,4 +600,18 @@ public class DataMapView extends JPanel {
             new LockingUpdateController(eventController, dataMap).startup();
         }
     }
+
+    void updateComment(String comment) {
+        DataMap dataMap = eventController.getCurrentDataMap();
+        if (dataMap == null) {
+            return;
+        }
+
+        ObjectInfo.putToMetaData(eventController.getApplication().getMetaData(), dataMap, ObjectInfo.COMMENT, comment);
+        eventController.fireDataMapEvent(new DataMapEvent(this, dataMap));
+    }
+
+    private String getComment(DataMap dataMap) {
+        return ObjectInfo.getFromMetaData(eventController.getApplication().getMetaData(), dataMap, ObjectInfo.COMMENT);
+    }
 }
