@@ -28,6 +28,7 @@ import org.apache.cayenne.modeler.ProjectController;
 import org.apache.cayenne.modeler.util.ProjectUtil;
 import org.apache.cayenne.modeler.util.TextAdapter;
 import org.apache.cayenne.map.QueryDescriptor;
+import org.apache.cayenne.project.extension.info.ObjectInfo;
 import org.apache.cayenne.util.Util;
 import org.apache.cayenne.validation.ValidationException;
 import com.jgoodies.forms.builder.PanelBuilder;
@@ -39,6 +40,7 @@ public class EjbqlQueryMainTab extends JPanel{
 
     protected ProjectController mediator;
     protected TextAdapter name;
+    protected TextAdapter comment;
     protected EjbqlQueryPropertiesPanel properties;
     protected TextAdapter qualifier;
 
@@ -50,23 +52,32 @@ public class EjbqlQueryMainTab extends JPanel{
     private void initView() {
         // create widgets
         name = new TextAdapter(new JTextField()) {
-
+            @Override
             protected void updateModel(String text) {
                 setQueryName(text);
             }
         };
 
+        comment = new TextAdapter(new JTextField()) {
+            @Override
+            protected void updateModel(String text) {
+                setQueryComment(text);
+            }
+        };
+
         properties = new EjbqlQueryPropertiesPanel(mediator);
         // assemble
         CellConstraints cc = new CellConstraints();
         FormLayout layout = new FormLayout(
                 "right:max(80dlu;pref), 3dlu, fill:max(200dlu;pref)",
-                "p, 3dlu, p");
+                "p, 3dlu, p, 3dlu, p");
         PanelBuilder builder = new PanelBuilder(layout);
         builder.setDefaultDialogBorder();
         builder.addSeparator("EJBQL Query Settings", cc.xywh(1, 1, 3, 1));
         builder.addLabel("Query Name:", cc.xy(1, 3));
         builder.add(name.getComponent(), cc.xy(3, 3));
+        builder.addLabel("Comment:", cc.xy(1, 5));
+        builder.add(comment.getComponent(), cc.xy(3, 5));
 
         this.setLayout(new BorderLayout());
         this.add(builder.getPanel(), BorderLayout.NORTH);
@@ -86,6 +97,7 @@ public class EjbqlQueryMainTab extends JPanel{
         }
 
         name.setText(query.getName());
+        comment.setText(getQueryComment(query));
         properties.initFromModel(query);
         setVisible(true);
     }
@@ -132,4 +144,17 @@ public class EjbqlQueryMainTab extends JPanel{
                     + "'. Use a different name.");
         }
     }
+
+    private void setQueryComment(String text) {
+        QueryDescriptor query = getQuery();
+        if (query == null) {
+            return;
+        }
+        ObjectInfo.putToMetaData(mediator.getApplication().getMetaData(), query, ObjectInfo.COMMENT, text);
+        mediator.fireQueryEvent(new QueryEvent(this, query));
+    }
+
+    private String getQueryComment(QueryDescriptor queryDescriptor) {
+        return ObjectInfo.getFromMetaData(mediator.getApplication().getMetaData(), queryDescriptor, ObjectInfo.COMMENT);
+    }
 }
