@@ -78,7 +78,6 @@ import java.awt.Component;
 import java.awt.Font;
 import java.awt.Point;
 import java.awt.Rectangle;
-import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.awt.event.MouseAdapter;
 import java.awt.event.MouseEvent;
@@ -86,8 +85,9 @@ import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.HashMap;
-import java.util.Map;
 import java.util.List;
+import java.util.Map;
+
 
 /**
  * Detail view of the ObjEntity attributes.
@@ -95,6 +95,8 @@ import java.util.List;
 public class ObjEntityAttributePanel extends JPanel implements ObjEntityDisplayListener,
         ObjEntityListener, ObjAttributeListener, ProjectOnSaveListener {
 
+    private static final ImageIcon INHERITANCE_ICON = ModelerUtil.buildIcon("icon-inheritance.png");
+
     private ProjectController mediator;
     private CayenneTable table;
     private TableColumnPreferences tablePreferences;
@@ -176,27 +178,24 @@ public class ObjEntityAttributePanel extends JPanel implements ObjEntityDisplayL
         mediator.addObjEntityListener(this);
         mediator.addObjAttributeListener(this);
 
-        resolver = new ActionListener() {
-
-            public void actionPerformed(ActionEvent e) {
-                int row = table.getSelectedRow();
-                if (row < 0) {
-                    return;
-                }
-
-                ObjAttributeTableModel model = (ObjAttributeTableModel) table.getModel();
-
-                // ... show dialog...
-                new ObjAttributeInfoDialog(mediator, row, model).startupAction();
-
-                // This is required for a table to be updated properly
-                table.cancelEditing();
-
-                // need to refresh selected row... do this by unselecting/selecting the row
-                table.getSelectionModel().clearSelection();
-                table.select(row);
-                enabledResolve = false;
+        resolver = e -> {
+            int row = table.getSelectedRow();
+            if (row < 0) {
+                return;
             }
+
+            ObjAttributeTableModel model = (ObjAttributeTableModel) table.getModel();
+
+            // ... show dialog...
+            new ObjAttributeInfoDialog(mediator, row, model).startupAction();
+
+            // This is required for a table to be updated properly
+            table.cancelEditing();
+
+            // need to refresh selected row... do this by unselecting/selecting the row
+            table.getSelectionModel().clearSelection();
+            table.select(row);
+            enabledResolve = false;
         };
         resolveMenu.addActionListener(resolver);
 
@@ -252,6 +251,9 @@ public class ObjEntityAttributePanel extends JPanel implements ObjEntityDisplayL
         }
 
         table.select(newSel);
+
+        parentPanel.getResolve().removeActionListener(getResolver());
+        parentPanel.getResolve().addActionListener(getResolver());
     }
 
     public void objAttributeChanged(AttributeEvent e) {
@@ -460,8 +462,7 @@ public class ObjEntityAttributePanel extends JPanel implements ObjEntityDisplayL
                 Font newFont = font.deriveFont(Font.ITALIC);
                 setFont(newFont);
                 if(column == ObjAttributeTableModel.OBJ_ATTRIBUTE) {
-                    ImageIcon icon = ModelerUtil.buildIcon("icon-inheritance.png");
-                    setIcon(icon);
+                    setIcon(INHERITANCE_ICON);
                 }
             }
 
@@ -473,8 +474,7 @@ public class ObjEntityAttributePanel extends JPanel implements ObjEntityDisplayL
 
         public void mouseClicked(MouseEvent event, int x) {
             Point point = event.getPoint();
-            ImageIcon icon = ModelerUtil.buildIcon("icon-inheritance.png");
-            if(point.x - x <= icon.getIconWidth()) {
+            if(point.x - x <= INHERITANCE_ICON.getIconWidth()) {
                 ActionManager actionManager = Application.getInstance().getActionManager();
                 actionManager.getAction(ObjEntityToSuperEntityAction.class).performAction(null);
             }
