@@ -42,6 +42,7 @@ import org.apache.cayenne.modeler.pref.TableColumnPreferences;
 import org.apache.cayenne.modeler.util.CayenneAction;
 import org.apache.cayenne.modeler.util.CayenneTable;
 import org.apache.cayenne.modeler.util.CellRenderers;
+import org.apache.cayenne.modeler.util.Comparators;
 import org.apache.cayenne.modeler.util.DbRelationshipPathComboBoxEditor;
 import org.apache.cayenne.modeler.util.ModelerUtil;
 import org.apache.cayenne.modeler.util.PanelFactory;
@@ -64,8 +65,6 @@ import javax.swing.ListSelectionModel;
 import javax.swing.UIManager;
 import javax.swing.event.ListSelectionEvent;
 import javax.swing.event.ListSelectionListener;
-import javax.swing.event.TableModelEvent;
-import javax.swing.event.TableModelListener;
 import javax.swing.table.DefaultTableCellRenderer;
 import javax.swing.table.TableCellRenderer;
 import javax.swing.table.TableColumn;
@@ -74,11 +73,9 @@ import java.awt.Color;
 import java.awt.Component;
 import java.awt.Point;
 import java.awt.Rectangle;
-import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.awt.event.MouseAdapter;
 import java.awt.event.MouseEvent;
-import java.util.Collection;
 import java.util.List;
 
 /**
@@ -89,6 +86,8 @@ public class ObjEntityRelationshipPanel extends JPanel implements ObjEntityDispl
 
     private static Logger logObj = LoggerFactory.getLogger(ObjEntityRelationshipPanel.class);
 
+    private static final ImageIcon INHERITANCE_ICON = ModelerUtil.buildIcon("icon-inheritance.png");
+
     private static final Object[] DELETE_RULES = new Object[]{
             DeleteRule.deleteRuleName(DeleteRule.NO_ACTION),
             DeleteRule.deleteRuleName(DeleteRule.NULLIFY),
@@ -177,25 +176,22 @@ public class ObjEntityRelationshipPanel extends JPanel implements ObjEntityDispl
         mediator.addObjEntityListener(this);
         mediator.addObjRelationshipListener(this);
 
-        resolver = new ActionListener() {
-            @Override
-            public void actionPerformed(ActionEvent e) {
-                int row = table.getSelectedRow();
-                if (row < 0) {
-                    return;
-                }
-
-                ObjRelationshipTableModel model = (ObjRelationshipTableModel) table.getModel();
-                new ObjRelationshipInfo(mediator, model.getRelationship(row)).startupAction();
-
-                // This is required for a table to be updated properly
-                table.cancelEditing();
-
-                // need to refresh selected row... do this by unselecting/selecting the row
-                table.getSelectionModel().clearSelection();
-                table.select(row);
-                enabledResolve = false;
+        resolver = e -> {
+            int row = table.getSelectedRow();
+            if (row < 0) {
+                return;
             }
+
+            ObjRelationshipTableModel model = (ObjRelationshipTableModel) table.getModel();
+            new ObjRelationshipInfo(mediator, model.getRelationship(row)).startupAction();
+
+            // This is required for a table to be updated properly
+            table.cancelEditing();
+
+            // need to refresh selected row... do this by unselecting/selecting the row
+            table.getSelectionModel().clearSelection();
+            table.select(row);
+            enabledResolve = false;
         };
         resolveMenu.addActionListener(resolver);
 
@@ -274,8 +270,9 @@ public class ObjEntityRelationshipPanel extends JPanel implements ObjEntityDispl
             return new Object[0];
         }
 
-        Collection objEntities = map.getNamespace().getObjEntities();
-        return objEntities.toArray();
+        return map.getNamespace().getObjEntities().stream()
+                .sorted(Comparators.getDataMapChildrenComparator())
+                .toArray();
     }
 
     public void objEntityChanged(EntityEvent e) {
@@ -300,7 +297,7 @@ public class ObjEntityRelationshipPanel extends JPanel implements ObjEntityDispl
 
     public void objRelationshipRemoved(RelationshipEvent e) {
         ObjRelationshipTableModel model = (ObjRelationshipTableModel) table.getModel();
-        int ind = model.getObjectList().indexOf((ObjRelationship)e.getRelationship());
+        int ind = model.getObjectList().indexOf(e.getRelationship());
         model.removeRow((ObjRelationship) e.getRelationship());
         table.select(ind);
     }
@@ -337,14 +334,11 @@ public class ObjEntityRelationshipPanel extends JPanel implements ObjEntityDispl
                 mediator,
                 this);
 
-        model.addTableModelListener(new TableModelListener() {
-
-            public void tableChanged(TableModelEvent e) {
-                if (table.getSelectedRow() >= 0) {
-                    ObjRelationship rel = model.getRelationship(table.getSelectedRow());
-                    enabledResolve = rel.getSourceEntity().getDbEntity() != null;
-                    resolveMenu.setEnabled(enabledResolve);
-                }
+        model.addTableModelListener(e -> {
+            if (table.getSelectedRow() >= 0) {
+                ObjRelationship rel = model.getRelationship(table.getSelectedRow());
+                enabledResolve = rel.getSourceEntity().getDbEntity() != null;
+                resolveMenu.setEnabled(enabledResolve);
             }
         });
 
@@ -452,8 +446,7 @@ public class ObjEntityRelationshipPanel extends JPanel implements ObjEntityDispl
                     && relationship.getSourceEntity() != model.getEntity()) {
                 setForeground(isSelected ? new Color(0xEEEEEE) : Color.GRAY);
                 if(column == ObjRelationshipTableModel.REL_NAME) {
-                    ImageIcon icon = ModelerUtil.buildIcon("icon-inheritance.png");
-                    setIcon(icon);
+                    setIcon(INHERITANCE_ICON);
                 }
             } else {
                 setForeground(isSelected && !hasFocus
@@ -469,8 +462,7 @@ public class ObjEntityRelationshipPanel extends JPanel implements ObjEntityDispl
 
         public void mouseClicked(MouseEvent event, int x) {
             Point point = event.getPoint();
-            ImageIcon icon = ModelerUtil.buildIcon("icon-inheritance.png");
-            if(point.x - x <= icon.getIconWidth()) {
+            if(point.x - x <= INHERITANCE_ICON.getIconWidth()) {
                 ActionManager actionManager = Application.getInstance().getActionManager();
                 actionManager.getAction(ObjEntityToSuperEntityAction.class).performAction(null);
             }
