@@ -22,12 +22,11 @@ package org.apache.cayenne.modeler.editor;
 import java.awt.BorderLayout;
 import java.awt.Color;
 import java.awt.Insets;
-import java.awt.event.ActionEvent;
-import java.awt.event.ActionListener;
 import java.util.Arrays;
 import java.util.EventObject;
 import java.util.LinkedList;
 import java.util.List;
+import java.util.stream.Collectors;
 
 import javax.swing.BorderFactory;
 import javax.swing.DefaultComboBoxModel;
@@ -50,6 +49,7 @@ import org.apache.cayenne.map.ObjAttribute;
 import org.apache.cayenne.map.ObjEntity;
 import org.apache.cayenne.map.event.EntityEvent;
 import org.apache.cayenne.modeler.Application;
+import org.apache.cayenne.swing.components.JCayenneCheckBox;
 import org.apache.cayenne.modeler.ProjectController;
 import org.apache.cayenne.modeler.action.ActionManager;
 import org.apache.cayenne.modeler.action.CreateAttributeAction;
@@ -66,11 +66,10 @@ import org.apache.cayenne.modeler.util.Comparators;
 import org.apache.cayenne.modeler.util.ExpressionConvertor;
 import org.apache.cayenne.modeler.util.TextAdapter;
 import org.apache.cayenne.modeler.util.combo.AutoCompletion;
+import org.apache.cayenne.project.extension.info.ObjectInfo;
 import org.apache.cayenne.util.CayenneMapEntry;
 import org.apache.cayenne.util.Util;
 import org.apache.cayenne.validation.ValidationException;
-import org.apache.commons.collections.CollectionUtils;
-import org.apache.commons.collections.Predicate;
 
 import com.jgoodies.forms.builder.DefaultFormBuilder;
 import com.jgoodies.forms.layout.FormLayout;
@@ -78,22 +77,9 @@ import com.jgoodies.forms.layout.FormLayout;
 /**
  * Detail view of the ObjEntity properties.
  */
-public class ObjEntityTab extends JPanel implements ObjEntityDisplayListener,
-        ExistingSelectionProcessor {
+public class ObjEntityTab extends JPanel implements ObjEntityDisplayListener, ExistingSelectionProcessor {
 
-    private static final Object noInheritance = new CayenneMapEntry() {
-
-        public String getName() {
-            return "Direct Mapping to Table/View";
-        }
-
-        public Object getParent() {
-            return null;
-        }
-
-        public void setParent(Object parent) {
-        }
-    };
+    private static final ObjEntity NO_INHERITANCE = new ObjEntity("Direct Mapping to Table/View");
 
     protected ProjectController mediator;
     protected TextAdapter name;
@@ -102,13 +88,11 @@ public class ObjEntityTab extends JPanel implements ObjEntityDisplayListener,
     protected JLabel superclassLabel;
     protected TextAdapter superClassName;
     protected TextAdapter qualifier;
-    protected JComboBox dbEntityCombo;
-    protected JComboBox superEntityCombo;
+    protected JComboBox<DbEntity> dbEntityCombo;
+    protected JComboBox<ObjEntity> superEntityCombo;
     protected JButton tableLabel;
     protected JCheckBox readOnly;
     protected JCheckBox optimisticLocking;
-    protected JCheckBox excludeSuperclassListeners;
-    protected JCheckBox excludeDefaultListeners;
 
     protected JComponent clientSeparator;
     protected JLabel isAbstractLabel;
@@ -118,6 +102,7 @@ public class ObjEntityTab extends JPanel implements ObjEntityDisplayListener,
 
     protected JCheckBox serverOnly;
     protected JCheckBox isAbstract;
+    protected TextAdapter comment;
     protected TextAdapter clientClassName;
     protected TextAdapter clientSuperClassName;
 
@@ -147,28 +132,24 @@ public class ObjEntityTab extends JPanel implements ObjEntityDisplayListener,
 
         // create widgets
         name = new TextAdapter(new JTextField()) {
-
             @Override
             protected void updateModel(String text) {
                 setEntityName(text);
             }
         };
         superClassName = new TextAdapter(new JTextField()) {
-
             @Override
             protected void updateModel(String text) {
                 setSuperClassName(text);
             }
         };
         className = new TextAdapter(new JTextField()) {
-
             @Override
             protected void updateModel(String text) {
                 setClassName(text);
             }
         };
         qualifier = new TextAdapter(new JTextField()) {
-
             @Override
             protected void updateModel(String text) {
                 setQualifier(text);
@@ -181,10 +162,9 @@ public class ObjEntityTab extends JPanel implements ObjEntityDisplayListener,
         AutoCompletion.enable(dbEntityCombo);
         AutoCompletion.enable(superEntityCombo);
 
-        readOnly = new JCheckBox();
-        optimisticLocking = new JCheckBox();
-        excludeSuperclassListeners = new JCheckBox();
-        excludeDefaultListeners = new JCheckBox();
+        readOnly = new JCayenneCheckBox();
+
+        optimisticLocking = new JCayenneCheckBox();
 
         // borderless clickable button used as a label
         tableLabel = new JButton("Table/View:");
@@ -195,17 +175,22 @@ public class ObjEntityTab extends JPanel implements ObjEntityDisplayListener,
         tableLabel.setBorder(null);
 
 
-        isAbstract = new JCheckBox();
-        serverOnly = new JCheckBox();
-        clientClassName = new TextAdapter(new JTextField()) {
+        isAbstract = new JCayenneCheckBox();
+        serverOnly = new JCayenneCheckBox();
 
+        comment = new TextAdapter(new JTextField()) {
+            @Override
+            protected void updateModel(String text) throws ValidationException {
+                setComment(text);
+            }
+        };
+        clientClassName = new TextAdapter(new JTextField()) {
             @Override
             protected void updateModel(String text) {
                 setClientClassName(text);
             }
         };
         clientSuperClassName = new TextAdapter(new JTextField()) {
-
             @Override
             protected void updateModel(String text) {
                 setClientSuperClassName(text);
@@ -222,6 +207,7 @@ public class ObjEntityTab extends JPanel implements ObjEntityDisplayListener,
         builder.append("Inheritance:", superEntityCombo);
         builder.append(tableLabel, dbEntityCombo);
         isAbstractLabel = builder.append("Abstract class:", isAbstract);
+        builder.append("Comment:", comment.getComponent());
         builder.appendSeparator();
 
         builder.append("Java Class:", className.getComponent());
@@ -230,9 +216,6 @@ public class ObjEntityTab extends JPanel implements ObjEntityDisplayListener,
         builder.append("Qualifier:", qualifier.getComponent());
         builder.append("Read-Only:", readOnly);
         builder.append("Optimistic Locking:", optimisticLocking);
-        // add callback-related stuff
-        builder.append("Exclude superclass listeners:", excludeSuperclassListeners);
-        builder.append("Exclude default listeners:", excludeDefaultListeners);
 
         clientSeparator = builder.appendSeparator("Java Client");
         serverOnlyLabel = builder.append("Not for Client Use:", serverOnly);
@@ -247,184 +230,118 @@ public class ObjEntityTab extends JPanel implements ObjEntityDisplayListener,
 
         mediator.addObjEntityDisplayListener(this);
 
-        dbEntityCombo.addActionListener(new ActionListener() {
+        dbEntityCombo.addActionListener(e -> {
+            // Change DbEntity for current ObjEntity
+            ObjEntity entity = mediator.getCurrentObjEntity();
+            DbEntity dbEntity = (DbEntity) dbEntityCombo.getSelectedItem();
 
-            public void actionPerformed(ActionEvent e) {
-                // Change DbEntity for current ObjEntity
-                ObjEntity entity = mediator.getCurrentObjEntity();
-                DbEntity dbEntity = (DbEntity) dbEntityCombo.getSelectedItem();
-       
 
-                if (dbEntity != entity.getDbEntity()) {
-                    entity.setDbEntity(dbEntity);
-                    mediator.fireObjEntityEvent(new EntityEvent(this, entity));
-                }
+            if (dbEntity != entity.getDbEntity()) {
+                entity.setDbEntity(dbEntity);
+                mediator.fireObjEntityEvent(new EntityEvent(ObjEntityTab.this, entity));
             }
         });
 
-        superEntityCombo.addActionListener(new ActionListener() {
+        superEntityCombo.addActionListener(e -> {
+            // Change super-entity
+            ObjEntity superEntity = (ObjEntity) superEntityCombo.getSelectedItem();
+            String name = (superEntity == null || superEntity == NO_INHERITANCE)
+                    ? null
+                    : superEntity.getName();
 
-            public void actionPerformed(ActionEvent e) {
-                // Change super-entity
-                CayenneMapEntry superEntity = (CayenneMapEntry) superEntityCombo
-                        .getSelectedItem();
-                String name = (superEntity == null || superEntity == noInheritance)
-                        ? null
-                        : superEntity.getName();
+            ObjEntity entity = mediator.getCurrentObjEntity();
 
-                ObjEntity entity = mediator.getCurrentObjEntity();
+            if (!Util.nullSafeEquals(name, entity.getSuperEntityName())) {
+                List<ObjAttribute> duplicateAttributes = null;
+                if (name != null) {
+                    duplicateAttributes = getDuplicatedAttributes(superEntity);
+                }
 
-                if (!Util.nullSafeEquals(name, entity.getSuperEntityName())) {
-                    List<ObjAttribute> duplicateAttributes = null;
-                    if (name != null) {
-                        duplicateAttributes = getDuplicatedAttributes((ObjEntity) superEntity);
+                if (duplicateAttributes != null && duplicateAttributes.size() > 0) {
+                    DuplicatedAttributesDialog.showDialog(
+                            Application.getFrame(), duplicateAttributes, superEntity, entity);
+                    if (DuplicatedAttributesDialog.getResult().equals(DuplicatedAttributesDialog.CANCEL_RESULT)) {
+                        superEntityCombo.setSelectedItem(entity.getSuperEntity());
+                        superClassName.setText(entity.getSuperClassName());
+                        return;
                     }
+                }
+                entity.setSuperEntityName(name);
 
-                    if (duplicateAttributes != null && duplicateAttributes.size() > 0) {
-                        DuplicatedAttributesDialog.showDialog(
-                                Application.getFrame(),
-                                duplicateAttributes,
-                                (ObjEntity) superEntity,
-                                entity);
-                        if (DuplicatedAttributesDialog.getResult().equals(
-                                DuplicatedAttributesDialog.CANCEL_RESULT)) {
-                            superEntityCombo.setSelectedItem(entity.getSuperEntity());
-                            superClassName.setText(entity.getSuperClassName());
-                            return;
-                        }
-
-                    }
-                    entity.setSuperEntityName(name);
-
-                    // drop not valid dbAttributePath
-                    if (name == null) {
-                        for (ObjAttribute objAttribute : entity.getAttributes()) {
-                            if (objAttribute.getDbAttribute() == null) {
-                                objAttribute.setDbAttributePath(null);
-                            }
+                // drop not valid dbAttributePath
+                if (name == null) {
+                    for (ObjAttribute objAttribute : entity.getAttributes()) {
+                        if (objAttribute.getDbAttribute() == null) {
+                            objAttribute.setDbAttributePath(null);
                         }
                     }
-                    
-                    if (name == null) {
-                        dbEntityCombo.setEnabled(true);
-                    }
-                    else {
-                        dbEntityCombo.setEnabled(false);
-                        dbEntityCombo.getModel().setSelectedItem(null);
-                    }
-
-                    // if a super-entity selected, disable table selection
-                    // and also update parent DbEntity selection...
-                    toggleEnabled(name == null, !serverOnly.isSelected());
-                    dbEntityCombo.getModel().setSelectedItem(entity.getDbEntity());
-                    superClassName.setText(entity.getSuperClassName());
-
-                    // fire both EntityEvent and EntityDisplayEvent;
-                    // the later is to update attribute and relationship display
-
-                    DataChannelDescriptor domain = (DataChannelDescriptor) mediator
-                            .getProject()
-                            .getRootNode();
-                    DataMap map = mediator.getCurrentDataMap();
-
-                    mediator.fireObjEntityEvent(new EntityEvent(this, entity));
-                    mediator.fireObjEntityDisplayEvent(new EntityDisplayEvent(
-                            this,
-                            entity,
-                            map,
-                            domain));
                 }
+
+                if (name == null) {
+                    dbEntityCombo.setEnabled(true);
+                } else {
+                    dbEntityCombo.setEnabled(false);
+                    dbEntityCombo.getModel().setSelectedItem(null);
+                }
+
+                // if a super-entity selected, disable table selection
+                // and also update parent DbEntity selection...
+                toggleEnabled(name == null, !serverOnly.isSelected());
+                dbEntityCombo.getModel().setSelectedItem(entity.getDbEntity());
+                superClassName.setText(entity.getSuperClassName());
+
+                // fire both EntityEvent and EntityDisplayEvent;
+                // the later is to update attribute and relationship display
+
+                DataChannelDescriptor domain = (DataChannelDescriptor) mediator.getProject().getRootNode();
+                DataMap map = mediator.getCurrentDataMap();
+
+                mediator.fireObjEntityEvent(new EntityEvent(this, entity));
+                mediator.fireObjEntityDisplayEvent(new EntityDisplayEvent(this, entity, map, domain));
             }
         });
 
-        tableLabel.addActionListener(new ActionListener() {
-
-            public void actionPerformed(ActionEvent e) {
-                // Jump to DbEntity of the current ObjEntity
-                DbEntity entity = mediator.getCurrentObjEntity().getDbEntity();
-                if (entity != null) {
-                    DataChannelDescriptor dom = (DataChannelDescriptor) mediator
-                            .getProject()
-                            .getRootNode();
-                    mediator.fireDbEntityDisplayEvent(new EntityDisplayEvent(
-                            this,
-                            entity,
-                            entity.getDataMap(),
-                            dom));
-                }
+        tableLabel.addActionListener(e -> {
+            // Jump to DbEntity of the current ObjEntity
+            DbEntity entity = mediator.getCurrentObjEntity().getDbEntity();
+            if (entity != null) {
+                DataChannelDescriptor dom = (DataChannelDescriptor) mediator.getProject().getRootNode();
+                mediator.fireDbEntityDisplayEvent(new EntityDisplayEvent(this, entity, entity.getDataMap(), dom));
             }
         });
 
- 
-
-        readOnly.addActionListener(new ActionListener() {
-
-            public void actionPerformed(ActionEvent e) {
-                ObjEntity entity = mediator.getCurrentObjEntity();
-                if (entity != null) {
-                    entity.setReadOnly(readOnly.isSelected());
-                    mediator.fireObjEntityEvent(new EntityEvent(this, entity));
-                }
+        readOnly.addItemListener(e -> {
+            ObjEntity entity = mediator.getCurrentObjEntity();
+            if (entity != null) {
+                entity.setReadOnly(readOnly.isSelected());
+                mediator.fireObjEntityEvent(new EntityEvent(this, entity));
             }
         });
 
-        optimisticLocking.addActionListener(new ActionListener() {
-
-            public void actionPerformed(ActionEvent e) {
-                ObjEntity entity = mediator.getCurrentObjEntity();
-                if (entity != null) {
-                    entity.setDeclaredLockType(optimisticLocking.isSelected()
-                            ? ObjEntity.LOCK_TYPE_OPTIMISTIC
-                            : ObjEntity.LOCK_TYPE_NONE);
-                    mediator.fireObjEntityEvent(new EntityEvent(this, entity));
-                }
+        optimisticLocking.addItemListener(e -> {
+            ObjEntity entity = mediator.getCurrentObjEntity();
+            if (entity != null) {
+                entity.setDeclaredLockType(optimisticLocking.isSelected()
+                        ? ObjEntity.LOCK_TYPE_OPTIMISTIC
+                        : ObjEntity.LOCK_TYPE_NONE);
+                mediator.fireObjEntityEvent(new EntityEvent(this, entity));
             }
         });
 
-        excludeSuperclassListeners.addActionListener(new ActionListener() {
-
-            public void actionPerformed(ActionEvent e) {
-                ObjEntity entity = mediator.getCurrentObjEntity();
-                if (entity != null) {
-                    entity.setExcludingSuperclassListeners(excludeSuperclassListeners
-                            .isSelected());
-                    mediator.fireObjEntityEvent(new EntityEvent(this, entity));
-                }
+        serverOnly.addItemListener(e -> {
+            ObjEntity entity = mediator.getCurrentObjEntity();
+            if (entity != null) {
+                entity.setServerOnly(serverOnly.isSelected());
+                toggleEnabled(dbEntityCombo.isEnabled(), !serverOnly.isSelected());
+                mediator.fireObjEntityEvent(new EntityEvent(this, entity));
             }
         });
 
-        excludeDefaultListeners.addActionListener(new ActionListener() {
-
-            public void actionPerformed(ActionEvent e) {
-                ObjEntity entity = mediator.getCurrentObjEntity();
-                if (entity != null) {
-                    entity.setExcludingDefaultListeners(excludeDefaultListeners
-                            .isSelected());
-                    mediator.fireObjEntityEvent(new EntityEvent(this, entity));
-                }
-            }
-        });
-
-        serverOnly.addActionListener(new ActionListener() {
-
-            public void actionPerformed(ActionEvent e) {
-                ObjEntity entity = mediator.getCurrentObjEntity();
-                if (entity != null) {
-                    entity.setServerOnly(serverOnly.isSelected());
-                    toggleEnabled(dbEntityCombo.isEnabled(), !serverOnly.isSelected());
-                    mediator.fireObjEntityEvent(new EntityEvent(this, entity));
-                }
-            }
-        });
-
-        isAbstract.addActionListener(new ActionListener() {
-
-            public void actionPerformed(ActionEvent e) {
-                ObjEntity entity = mediator.getCurrentObjEntity();
-                if (entity != null) {
-                    entity.setAbstract(isAbstract.isSelected());
-                    mediator.fireObjEntityEvent(new EntityEvent(this, entity));
-                }
+        isAbstract.addItemListener(e -> {
+            ObjEntity entity = mediator.getCurrentObjEntity();
+            if (entity != null) {
+                entity.setAbstract(isAbstract.isSelected());
+                mediator.fireObjEntityEvent(new EntityEvent(this, entity));
             }
         });
     }
@@ -445,28 +362,25 @@ public class ObjEntityTab extends JPanel implements ObjEntityDisplayListener,
         readOnly.setSelected(entity.isReadOnly());
 
         isAbstract.setSelected(entity.isAbstract());
+        comment.setText(getComment(entity));
         serverOnly.setSelected(entity.isServerOnly());
         clientClassName.setText(entity.getClientClassName());
         clientSuperClassName.setText(entity.getClientSuperClassName());
 
-        qualifier.setText(new ExpressionConvertor().valueAsString(entity
-                .getDeclaredQualifier()));
+        qualifier.setText(new ExpressionConvertor().valueAsString(entity.getDeclaredQualifier()));
 
         // TODO: fix inheritance - we should allow to select optimistic
         // lock if superclass is not already locked,
         // otherwise we must keep this checked in but not editable.
-        optimisticLocking
-                .setSelected(entity.getDeclaredLockType() == ObjEntity.LOCK_TYPE_OPTIMISTIC);
-        excludeSuperclassListeners.setSelected(entity.isExcludingSuperclassListeners());
-        excludeDefaultListeners.setSelected(entity.isExcludingDefaultListeners());
+        optimisticLocking.setSelected(entity.getDeclaredLockType() == ObjEntity.LOCK_TYPE_OPTIMISTIC);
 
         // init DbEntities
         EntityResolver resolver = mediator.getEntityResolver();
         DataMap map = mediator.getCurrentDataMap();
-        Object[] dbEntities = resolver.getDbEntities().toArray();
+        DbEntity[] dbEntities = resolver.getDbEntities().toArray(new DbEntity[0]);
         Arrays.sort(dbEntities, Comparators.getDataMapChildrenComparator());
 
-        DefaultComboBoxModel dbModel = new DefaultComboBoxModel(dbEntities);
+        DefaultComboBoxModel<DbEntity> dbModel = new DefaultComboBoxModel<>(dbEntities);
         dbModel.setSelectedItem(entity.getDbEntity());
         dbEntityCombo.setRenderer(CellRenderers.entityListRendererWithIcons(map));
         dbEntityCombo.setModel(dbModel);
@@ -474,36 +388,18 @@ public class ObjEntityTab extends JPanel implements ObjEntityDisplayListener,
         boolean isUsedInheritance = entity.getSuperEntity() != null;
         dbEntityCombo.setEnabled(!isUsedInheritance);
 
-        // toggle visibilty and editability rules
+        // toggle visibility and editability rules
         toggleClientFieldsVisible(map.isClientSupported());
         toggleEnabled(entity.getSuperEntityName() == null, !entity.isServerOnly());
 
-        // init ObjEntities for inheritance
-        Predicate inheritanceFilter = new Predicate() {
+        // do not show this entity or any of the subentities
+        List<ObjEntity> objEntities = map.getObjEntities().stream()
+                .filter(object -> entity != object && !object.isSubentityOf(entity))
+                .sorted(Comparators.getDataMapChildrenComparator())
+                .collect(Collectors.toList());
+        objEntities.add(0, NO_INHERITANCE);
 
-            public boolean evaluate(Object object) {
-                // do not show this entity or any of the subentities
-                if (entity == object) {
-                    return false;
-                }
-
-                if (object instanceof ObjEntity) {
-                    return !((ObjEntity) object).isSubentityOf(entity);
-                }
-
-                return false;
-            }
-        };
-
-        Object[] objEntities = CollectionUtils.select(
-                map.getObjEntities(),
-                inheritanceFilter).toArray();
-        Arrays.sort(objEntities, Comparators.getDataMapChildrenComparator());
-        Object[] finalObjEntities = new Object[objEntities.length + 1];
-        finalObjEntities[0] = noInheritance;
-        System.arraycopy(objEntities, 0, finalObjEntities, 1, objEntities.length);
-
-        DefaultComboBoxModel superEntityModel = new DefaultComboBoxModel(finalObjEntities);
+        DefaultComboBoxModel<ObjEntity> superEntityModel = new DefaultComboBoxModel<>(objEntities.toArray(new ObjEntity[0]));
         superEntityModel.setSelectedItem(entity.getSuperEntity());
         superEntityCombo.setRenderer(CellRenderers.entityListRendererWithIcons(map));
         superEntityCombo.setModel(superEntityModel);
@@ -545,8 +441,7 @@ public class ObjEntityTab extends JPanel implements ObjEntityDisplayListener,
         ObjEntity entity = mediator.getCurrentObjEntity();
 
         // "ent" may be null if we quit editing by changing tree selection
-        if (entity != null
-                && !Util.nullSafeEquals(entity.getClientClassName(), className)) {
+        if (entity != null && !Util.nullSafeEquals(entity.getClientClassName(), className)) {
             entity.setClientClassName(className);
             mediator.fireObjEntityEvent(new EntityEvent(this, entity));
         }
@@ -573,18 +468,15 @@ public class ObjEntityTab extends JPanel implements ObjEntityDisplayListener,
 
         ObjEntity entity = mediator.getCurrentObjEntity();
         if (entity != null) {
-
             ExpressionConvertor convertor = new ExpressionConvertor();
             try {
-                String oldQualifier = convertor.valueAsString(entity
-                        .getDeclaredQualifier());
+                String oldQualifier = convertor.valueAsString(entity.getDeclaredQualifier());
                 if (!Util.nullSafeEquals(oldQualifier, text)) {
                     Expression exp = (Expression) convertor.stringAsValue(text);
                     entity.setDeclaredQualifier(exp);
                     mediator.fireObjEntityEvent(new EntityEvent(this, entity));
                 }
-            }
-            catch (IllegalArgumentException ex) {
+            } catch (IllegalArgumentException ex) {
                 // unparsable qualifier
                 throw new ValidationException(ex.getMessage());
             }
@@ -607,8 +499,7 @@ public class ObjEntityTab extends JPanel implements ObjEntityDisplayListener,
 
         if (newName == null) {
             throw new ValidationException("Entity name is required.");
-        }
-        else if (entity.getDataMap().getObjEntity(newName) == null) {
+        } else if (entity.getDataMap().getObjEntity(newName) == null) {
             // completely new name, set new name for entity
             EntityEvent e = new EntityEvent(this, entity, entity.getName());
             entity.setName(newName);
@@ -616,20 +507,15 @@ public class ObjEntityTab extends JPanel implements ObjEntityDisplayListener,
             mediator.fireObjEntityEvent(e);
 
             // suggest to update class name
-            ClassNameUpdater nameUpdater = new ClassNameUpdater(Application
-                    .getInstance()
-                    .getFrameController(), entity);
+            ClassNameUpdater nameUpdater = new ClassNameUpdater(Application.getInstance().getFrameController(), entity);
 
             if (nameUpdater.doNameUpdate()) {
                 className.setText(entity.getClassName());
                 clientClassName.setText(entity.getClientClassName());
             }
-        }
-        else {
+        } else {
             // there is an entity with the same name
-            throw new ValidationException("There is another entity with name '"
-                    + newName
-                    + "'.");
+            throw new ValidationException("There is another entity with name '" + newName + "'.");
         }
     }
 
@@ -649,8 +535,7 @@ public class ObjEntityTab extends JPanel implements ObjEntityDisplayListener,
         superClassName.getComponent().setEnabled(directTableMapping);
         superclassLabel.setEnabled(directTableMapping);
 
-        clientSuperClassName.getComponent().setEnabled(
-                directTableMapping && clientFieldsEnabled);
+        clientSuperClassName.getComponent().setEnabled(directTableMapping && clientFieldsEnabled);
         clientSuperClassNameLabel.setEnabled(directTableMapping && clientFieldsEnabled);
 
         clientClassNameLabel.setEnabled(clientFieldsEnabled);
@@ -677,7 +562,7 @@ public class ObjEntityTab extends JPanel implements ObjEntityDisplayListener,
     }
 
     private List<ObjAttribute> getDuplicatedAttributes(ObjEntity superEntity) {
-        List<ObjAttribute> result = new LinkedList<ObjAttribute>();
+        List<ObjAttribute> result = new LinkedList<>();
 
         ObjEntity entity = mediator.getCurrentObjEntity();
 
@@ -690,4 +575,18 @@ public class ObjEntityTab extends JPanel implements ObjEntityDisplayListener,
         return result;
     }
 
+    private void setComment(String value) {
+        ObjEntity entity = mediator.getCurrentObjEntity();
+        if (entity == null) {
+            return;
+        }
+
+        ObjectInfo.putToMetaData(mediator.getApplication().getMetaData(), entity, ObjectInfo.COMMENT, value);
+        mediator.fireObjEntityEvent(new EntityEvent(this, entity));
+    }
+
+    private String getComment(ObjEntity entity) {
+        return ObjectInfo.getFromMetaData(mediator.getApplication().getMetaData(), entity, ObjectInfo.COMMENT);
+    }
+
 }
