@@ -24,6 +24,7 @@ import org.apache.cayenne.map.event.RelationshipEvent;
 import org.apache.cayenne.modeler.ProjectController;
 import org.apache.cayenne.modeler.util.CayenneTableModel;
 import org.apache.cayenne.modeler.util.ProjectUtil;
+import org.apache.cayenne.project.extension.info.ObjectInfo;
 import org.apache.cayenne.util.Util;
 
 import java.util.ArrayList;
@@ -43,7 +44,8 @@ public class ObjRelationshipTableModel extends CayenneTableModel<ObjRelationship
     public static final int REL_SEMANTICS = 3;
     public static final int REL_DELETE_RULE = 4;
     public static final int REL_LOCKING = 5;
-    public static final int COLUMN_COUNT = 6;
+    public static final int REL_COMMENT = 6;
+    public static final int COLUMN_COUNT = 7;
 
     private ObjEntity entity;
 
@@ -52,7 +54,7 @@ public class ObjRelationshipTableModel extends CayenneTableModel<ObjRelationship
         this.entity = entity;
 
         // order using local comparator
-        Collections.sort(objectList, new RelationshipComparator());
+        objectList.sort(new RelationshipComparator());
     }
 
     public ObjEntity getEntity() {
@@ -86,6 +88,8 @@ public class ObjRelationshipTableModel extends CayenneTableModel<ObjRelationship
                 return "Delete Rule";
             case REL_TARGET_PATH:
                 return "DbRelationship Path";
+            case REL_COMMENT:
+                return "Comment";
             default:
                 return null;
         }
@@ -110,20 +114,23 @@ public class ObjRelationshipTableModel extends CayenneTableModel<ObjRelationship
     public Object getValueAt(int row, int column) {
         ObjRelationship relationship = getRelationship(row);
 
-        if (column == REL_NAME) {
-            return relationship.getName();
-        } else if (column == REL_TARGET) {
-            return relationship.getTargetEntity();
-        } else if (column == REL_LOCKING) {
-            return relationship.isUsedForLocking() ? Boolean.TRUE : Boolean.FALSE;
-        } else if (column == REL_SEMANTICS) {
-            return getSemantics(relationship);
-        } else if (column == REL_DELETE_RULE) {
-            return DeleteRule.deleteRuleName(relationship.getDeleteRule());
-        } else if (column == REL_TARGET_PATH) {
-            return relationship.getDbRelationshipPath();
-        } else {
-            return null;
+        switch (column) {
+            case REL_NAME:
+                return relationship.getName();
+            case REL_TARGET:
+                return relationship.getTargetEntity();
+            case REL_LOCKING:
+                return relationship.isUsedForLocking() ? Boolean.TRUE : Boolean.FALSE;
+            case REL_SEMANTICS:
+                return getSemantics(relationship);
+            case REL_DELETE_RULE:
+                return DeleteRule.deleteRuleName(relationship.getDeleteRule());
+            case REL_TARGET_PATH:
+                return relationship.getDbRelationshipPath();
+            case REL_COMMENT:
+                return getComment(relationship);
+            default:
+                return null;
         }
     }
 
@@ -153,41 +160,51 @@ public class ObjRelationshipTableModel extends CayenneTableModel<ObjRelationship
         ObjRelationship relationship = getRelationship(row);
         RelationshipEvent event = new RelationshipEvent(eventSource, relationship, entity);
 
-        if (column == REL_NAME) {
-            String text = (String) value;
-            event.setOldName(relationship.getName());
-            ProjectUtil.setRelationshipName(entity, relationship, text);
-            fireTableCellUpdated(row, column);
-        } else if (column == REL_TARGET) {
-            ObjEntity target = (ObjEntity) value;
-            relationship.setTargetEntityName(target);
+        switch (column) {
+            case REL_NAME:
+                String text = (String) value;
+                event.setOldName(relationship.getName());
+                ProjectUtil.setRelationshipName(entity, relationship, text);
+                fireTableCellUpdated(row, column);
+                break;
+            case REL_TARGET:
+                ObjEntity target = (ObjEntity) value;
+                relationship.setTargetEntityName(target);
 
-            // Clear existing relationships, otherwise addDbRelationship() might fail
-            relationship.clearDbRelationships();
+                // Clear existing relationships, otherwise addDbRelationship() might fail
+                relationship.clearDbRelationships();
 
-            // now try to connect DbEntities if we can do it in one step
-            if (target != null) {
-                DbEntity srcDB = relationship.getSourceEntity()
-                        .getDbEntity();
-                DbEntity targetDB = target.getDbEntity();
-                if (srcDB != null && targetDB != null) {
-                    Relationship anyConnector = srcDB.getAnyRelationship(targetDB);
-                    if (anyConnector != null) {
-                        relationship.addDbRelationship((DbRelationship) anyConnector);
+                // now try to connect DbEntities if we can do it in one step
+                if (target != null) {
+                    DbEntity srcDB = relationship.getSourceEntity()
+                            .getDbEntity();
+                    DbEntity targetDB = target.getDbEntity();
+                    if (srcDB != null && targetDB != null) {
+                        Relationship anyConnector = srcDB.getAnyRelationship(targetDB);
+                        if (anyConnector != null) {
+                            relationship.addDbRelationship((DbRelationship) anyConnector);
+                        }
                     }
                 }
-            }
 
-            fireTableRowsUpdated(row, row);
-        } else if (column == REL_DELETE_RULE) {
-            relationship.setDeleteRule(DeleteRule.deleteRuleForName((String) value));
-            fireTableCellUpdated(row, column);
-        } else if (column == REL_LOCKING) {
-            relationship.setUsedForLocking((value instanceof Boolean) && (Boolean) value);
-            fireTableCellUpdated(row, column);
-        } else if (column == REL_TARGET_PATH) {
-            relationship.setDbRelationshipPath((String) value);
-            fireTableCellUpdated(row, column);
+                fireTableRowsUpdated(row, row);
+                break;
+            case REL_DELETE_RULE:
+                relationship.setDeleteRule(DeleteRule.deleteRuleForName((String) value));
+                fireTableCellUpdated(row, column);
+                break;
+            case REL_LOCKING:
+                relationship.setUsedForLocking((value instanceof Boolean) && (Boolean) value);
+                fireTableCellUpdated(row, column);
+                break;
+            case REL_TARGET_PATH:
+                relationship.setDbRelationshipPath((String) value);
+                fireTableCellUpdated(row, column);
+                break;
+            case REL_COMMENT:
+                setComment((String)value, relationship);
+                fireTableRowsUpdated(row, row);
+                break;
         }
 
         mediator.fireObjRelationshipEvent(event);
@@ -208,7 +225,7 @@ public class ObjRelationshipTableModel extends CayenneTableModel<ObjRelationship
 
     private boolean isInherited(int row) {
         ObjRelationship relationship = getRelationship(row);
-        return (relationship != null) ? relationship.getSourceEntity() != entity : false;
+        return (relationship != null) && relationship.getSourceEntity() != entity;
     }
 
     @Override
@@ -247,7 +264,7 @@ public class ObjRelationshipTableModel extends CayenneTableModel<ObjRelationship
             case REL_SEMANTICS:
             case REL_DELETE_RULE:
             case REL_TARGET_PATH:
-                Collections.sort(objectList, new ObjRelationshipTableComparator(sortCol));
+                objectList.sort(new ObjRelationshipTableComparator(sortCol));
                 if (!isAscent) {
                     Collections.reverse(objectList);
                 }
@@ -266,7 +283,7 @@ public class ObjRelationshipTableModel extends CayenneTableModel<ObjRelationship
         }
 
         public int compare(ObjRelationship o1, ObjRelationship o2) {
-            if ((o1 == null && o2 == null) || o1 == o2) {
+            if (o1 == o2) {
                 return 0;
             } else if (o1 == null) {
                 return -1;
@@ -297,4 +314,12 @@ public class ObjRelationshipTableModel extends CayenneTableModel<ObjRelationship
             return value1.compareTo(value2);
         }
     }
+
+    private String getComment(ObjRelationship rel) {
+        return ObjectInfo.getFromMetaData(mediator.getApplication().getMetaData(), rel, ObjectInfo.COMMENT);
+    }
+
+    private void setComment(String newVal, ObjRelationship rel) {
+        ObjectInfo.putToMetaData(mediator.getApplication().getMetaData(), rel, ObjectInfo.COMMENT, newVal);
+    }
 }
