@@ -20,11 +20,10 @@
 package org.apache.cayenne.modeler.editor;
 
 import java.awt.BorderLayout;
-import java.awt.event.ActionEvent;
-import java.awt.event.ActionListener;
 
 import javax.swing.JCheckBox;
 
+import org.apache.cayenne.swing.components.JCayenneCheckBox;
 import org.apache.cayenne.modeler.ProjectController;
 import org.apache.cayenne.map.QueryDescriptor;
 import org.apache.cayenne.query.QueryMetadata;
@@ -49,7 +48,7 @@ public class ObjectQueryPropertiesPanel extends SelectPropertiesPanel {
         super.initView();
         // create widgets
 
-        dataRows = new JCheckBox();
+        dataRows = new JCayenneCheckBox();
 
         // assemble
         CellConstraints cc = new CellConstraints();
@@ -79,12 +78,9 @@ public class ObjectQueryPropertiesPanel extends SelectPropertiesPanel {
     protected void initController() {
         super.initController();
 
-        dataRows.addActionListener(new ActionListener() {
-
-            public void actionPerformed(ActionEvent event) {
-                Boolean b = dataRows.isSelected() ? Boolean.TRUE : Boolean.FALSE;
-                setQueryProperty(QueryMetadata.FETCHING_DATA_ROWS_PROPERTY, String.valueOf(b));
-            }
+        dataRows.addItemListener(e -> {
+            Boolean b = dataRows.isSelected() ? Boolean.TRUE : Boolean.FALSE;
+            setQueryProperty(QueryMetadata.FETCHING_DATA_ROWS_PROPERTY, String.valueOf(b));
         });
     }
 
