@@ -20,23 +20,22 @@
 package org.apache.cayenne.modeler.editor;
 
 import java.awt.BorderLayout;
-import java.awt.event.ItemEvent;
-import java.awt.event.ItemListener;
 import java.util.EventObject;
 
 import javax.swing.JCheckBox;
-import javax.swing.JLabel;
 import javax.swing.JPanel;
 import javax.swing.JTextField;
 
 import org.apache.cayenne.configuration.DataChannelDescriptor;
 import org.apache.cayenne.configuration.event.ProcedureEvent;
 import org.apache.cayenne.map.Procedure;
+import org.apache.cayenne.swing.components.JCayenneCheckBox;
 import org.apache.cayenne.modeler.ProjectController;
 import org.apache.cayenne.modeler.event.ProcedureDisplayEvent;
 import org.apache.cayenne.modeler.event.ProcedureDisplayListener;
 import org.apache.cayenne.modeler.util.ProjectUtil;
 import org.apache.cayenne.modeler.util.TextAdapter;
+import org.apache.cayenne.project.extension.info.ObjectInfo;
 import org.apache.cayenne.util.Util;
 import org.apache.cayenne.validation.ValidationException;
 
@@ -44,9 +43,7 @@ import com.jgoodies.forms.builder.DefaultFormBuilder;
 import com.jgoodies.forms.layout.FormLayout;
 
 /**
- * A panel for editing stored procedure general settings, such as name, schema,
- * etc.
- * 
+ * A panel for editing stored procedure general settings, such as name, schema, etc.
  */
 public class ProcedureTab extends JPanel implements ProcedureDisplayListener, ExistingSelectionProcessor {
 
@@ -54,6 +51,7 @@ public class ProcedureTab extends JPanel implements ProcedureDisplayListener, Ex
     protected TextAdapter name;
     protected TextAdapter schema;
     protected TextAdapter catalog;
+    protected TextAdapter comment;
     protected JCheckBox returnsValue;
     protected boolean ignoreChange;
 
@@ -68,31 +66,35 @@ public class ProcedureTab extends JPanel implements ProcedureDisplayListener, Ex
         // create widgets
 
         this.name = new TextAdapter(new JTextField()) {
-
+            @Override
             protected void updateModel(String text) {
                 setProcedureName(text);
             }
         };
 
         this.schema = new TextAdapter(new JTextField()) {
-
+            @Override
             protected void updateModel(String text) {
                 setSchema(text);
             }
         };
 
         this.catalog = new TextAdapter(new JTextField()) {
-
+            @Override
             protected void updateModel(String text) {
                 setCatalog(text);
             }
         };
 
-        JLabel returnValueHelp = new JLabel("(first parameter will be used as return value)");
-        returnValueHelp.setFont(returnValueHelp.getFont().deriveFont(10));
+        this.comment = new TextAdapter(new JTextField()) {
+            @Override
+            protected void updateModel(String text) {
+                setComment(text);
+            }
+        };
 
-        this.returnsValue = new JCheckBox();
-        this.returnsValue.setToolTipText(returnValueHelp.getText());
+        this.returnsValue = new JCayenneCheckBox();
+        this.returnsValue.setToolTipText("first parameter will be used as return value");
 
         FormLayout layout = new FormLayout("right:pref, 3dlu, fill:200dlu", "");
         DefaultFormBuilder builder = new DefaultFormBuilder(layout);
@@ -103,20 +105,18 @@ public class ProcedureTab extends JPanel implements ProcedureDisplayListener, Ex
         builder.append("Catalog:", catalog.getComponent());
         builder.append("Schema:", schema.getComponent());
         builder.append("Returns Value:", returnsValue);
+        builder.append("Comment:", comment.getComponent());
 
         this.setLayout(new BorderLayout());
         this.add(builder.getPanel(), BorderLayout.CENTER);
     }
 
     private void initController() {
-        returnsValue.addItemListener(new ItemListener() {
-
-            public void itemStateChanged(ItemEvent e) {
-                Procedure procedure = eventController.getCurrentProcedure();
-                if (procedure != null && !ignoreChange) {
-                    procedure.setReturningValue(returnsValue.isSelected());
-                    eventController.fireProcedureEvent(new ProcedureEvent(ProcedureTab.this, procedure));
-                }
+        returnsValue.addItemListener(e -> {
+            Procedure procedure = eventController.getCurrentProcedure();
+            if (procedure != null && !ignoreChange) {
+                procedure.setReturningValue(returnsValue.isSelected());
+                eventController.fireProcedureEvent(new ProcedureEvent(ProcedureTab.this, procedure));
             }
         });
 
@@ -141,6 +141,7 @@ public class ProcedureTab extends JPanel implements ProcedureDisplayListener, Ex
         name.setText(procedure.getName());
         schema.setText(procedure.getSchema());
         catalog.setText(procedure.getCatalog());
+        comment.setText(getComment(procedure));
 
         ignoreChange = true;
         returnsValue.setSelected(procedure.isReturningValue());
@@ -196,4 +197,19 @@ public class ProcedureTab extends JPanel implements ProcedureDisplayListener, Ex
             eventController.fireProcedureEvent(new ProcedureEvent(this, procedure));
         }
     }
+
+    void setComment(String comment) {
+        Procedure procedure = eventController.getCurrentProcedure();
+
+        if (procedure == null) {
+            return;
+        }
+
+        ObjectInfo.putToMetaData(eventController.getApplication().getMetaData(), procedure, ObjectInfo.COMMENT, comment);
+        eventController.fireProcedureEvent(new ProcedureEvent(this, procedure));
+    }
+
+    String getComment(Procedure procedure) {
+        return ObjectInfo.getFromMetaData(eventController.getApplication().getMetaData(), procedure, ObjectInfo.COMMENT);
+    }
 }
