@@ -20,10 +20,7 @@
 package org.apache.cayenne.modeler.editor;
 
 import java.awt.BorderLayout;
-import java.awt.event.ActionEvent;
-import java.awt.event.ActionListener;
 import java.util.ArrayList;
-import java.util.Collections;
 import java.util.List;
 
 import javax.swing.DefaultComboBoxModel;
@@ -33,6 +30,7 @@ import javax.swing.JComboBox;
 import org.apache.cayenne.map.DataMap;
 import org.apache.cayenne.map.ObjEntity;
 import org.apache.cayenne.modeler.Application;
+import org.apache.cayenne.swing.components.JCayenneCheckBox;
 import org.apache.cayenne.modeler.ProjectController;
 import org.apache.cayenne.modeler.util.CellRenderers;
 import org.apache.cayenne.modeler.util.Comparators;
@@ -51,7 +49,7 @@ import org.apache.cayenne.query.QueryMetadata;
 public abstract class RawQueryPropertiesPanel extends SelectPropertiesPanel {
 
     protected JCheckBox dataObjects;
-    protected JComboBox entities;
+    protected JComboBox<ObjEntity> entities;
 
     public RawQueryPropertiesPanel(ProjectController mediator) {
         super(mediator);
@@ -59,19 +57,11 @@ public abstract class RawQueryPropertiesPanel extends SelectPropertiesPanel {
 
     protected void initController() {
         super.initController();
-        dataObjects.addActionListener(new ActionListener() {
+        dataObjects.addItemListener(e -> setFetchingDataObjects(dataObjects.isSelected()));
 
-            public void actionPerformed(ActionEvent event) {
-                setFetchingDataObjects(dataObjects.isSelected());
-            }
-        });
-
-        entities.addActionListener(new ActionListener() {
-
-            public void actionPerformed(ActionEvent event) {
-                ObjEntity entity = (ObjEntity) entities.getModel().getSelectedItem();
-                setEntity(entity);
-            }
+        entities.addActionListener(event -> {
+            ObjEntity entity = (ObjEntity) entities.getModel().getSelectedItem();
+            setEntity(entity);
         });
     }
 
@@ -106,7 +96,7 @@ public abstract class RawQueryPropertiesPanel extends SelectPropertiesPanel {
 
         // create widgets
 
-        dataObjects = new JCheckBox();
+        dataObjects = new JCayenneCheckBox();
 
         entities = Application.getWidgetFactory().createUndoableComboBox();
         entities.setRenderer(CellRenderers.listRendererWithIcons());
@@ -130,15 +120,14 @@ public abstract class RawQueryPropertiesPanel extends SelectPropertiesPanel {
         // making it impossible to reference other DataMaps.
 
         DataMap map = mediator.getCurrentDataMap();
-        List objEntities = new ArrayList();
-        objEntities.addAll(map.getObjEntities());
+        List<ObjEntity> objEntities = new ArrayList<>(map.getObjEntities());
 
         if (objEntities.size() > 1) {
-            Collections.sort(objEntities, Comparators.getDataMapChildrenComparator());
+            objEntities.sort(Comparators.getDataMapChildrenComparator());
         }
 
         entities.setEnabled(fetchingDO && isEnabled());
-        DefaultComboBoxModel model = new DefaultComboBoxModel(objEntities.toArray());
+        DefaultComboBoxModel<ObjEntity> model = new DefaultComboBoxModel<>(objEntities.toArray(new ObjEntity[0]));
         model.setSelectedItem(getEntity(query));
         entities.setModel(model);
     }
