@@ -29,17 +29,20 @@ import org.apache.cayenne.map.ObjEntity;
 import org.apache.cayenne.map.QueryDescriptor;
 import org.apache.cayenne.modeler.Application;
 import org.apache.cayenne.modeler.ProjectController;
-import org.apache.cayenne.modeler.util.ProjectUtil;
+import org.apache.cayenne.modeler.util.Comparators;
 import org.apache.cayenne.modeler.util.TextAdapter;
+import org.apache.cayenne.project.extension.info.ObjectInfo;
 import org.apache.cayenne.query.CapsStrategy;
 import org.apache.cayenne.query.SQLTemplate;
-import org.apache.cayenne.util.Util;
-import org.apache.cayenne.validation.ValidationException;
 
-import javax.swing.*;
-import java.awt.*;
-import java.awt.event.ActionEvent;
-import java.awt.event.ActionListener;
+import javax.swing.DefaultComboBoxModel;
+import javax.swing.DefaultListCellRenderer;
+import javax.swing.JComboBox;
+import javax.swing.JList;
+import javax.swing.JTextField;
+import java.awt.BorderLayout;
+import java.awt.Component;
+import java.util.Arrays;
 import java.util.HashMap;
 import java.util.Map;
 
@@ -47,7 +50,7 @@ import java.util.Map;
  * A main panel for editing a SQLTemplate.
  * 
  */
-public class SQLTemplateMainTab extends JPanel {
+public class SQLTemplateMainTab extends BaseQueryMainTab {
 
     private static final String DEFAULT_CAPS_LABEL = "Database Default";
     private static final String LOWER_CAPS_LABEL = "Force Lower Case";
@@ -65,38 +68,49 @@ public class SQLTemplateMainTab extends JPanel {
         labelCapsLabels.put(CapsStrategy.UPPER, UPPER_CAPS_LABEL);
     }
 
-    protected ProjectController mediator;
-    protected TextAdapter name;
+    protected TextAdapter comment;
     protected SelectPropertiesPanel properties;
 
     public SQLTemplateMainTab(ProjectController mediator) {
-        this.mediator = mediator;
+        super(mediator);
 
+        initQueryRoot();
         initView();
     }
 
     private void initView() {
         // create widgets
         name = new TextAdapter(new JTextField()) {
-
+            @Override
             protected void updateModel(String text) {
                 setQueryName(text);
             }
         };
 
+        comment = new TextAdapter(new JTextField()) {
+            @Override
+            protected void updateModel(String text) {
+                setQueryComment(text);
+            }
+        };
+
         properties = new SQLTemplateQueryPropertiesPanel(mediator);
 
         // assemble
         CellConstraints cc = new CellConstraints();
         FormLayout layout = new FormLayout(
                 "right:max(80dlu;pref), 3dlu, fill:max(200dlu;pref)",
-                "p, 3dlu, p");
+                "p, 3dlu, p, 3dlu, p, 3dlu, p");
         PanelBuilder builder = new PanelBuilder(layout);
         builder.setDefaultDialogBorder();
 
         builder.addSeparator("SQLTemplate Settings", cc.xywh(1, 1, 3, 1));
         builder.addLabel("Query Name:", cc.xy(1, 3));
         builder.add(name.getComponent(), cc.xy(3, 3));
+        builder.addLabel("Comment:", cc.xy(1, 5));
+        builder.add(comment.getComponent(), cc.xy(3, 5));
+        builder.addLabel("Query Root:", cc.xy(1, 7));
+        builder.add(queryRoot, cc.xy(3, 7));
 
         this.setLayout(new BorderLayout());
         this.add(builder.getPanel(), BorderLayout.NORTH);
@@ -117,53 +131,28 @@ public class SQLTemplateMainTab extends JPanel {
 
         name.setText(query.getName());
         properties.initFromModel(query);
+        comment.setText(getQueryComment(query));
+
+        DataMap map = mediator.getCurrentDataMap();
+        ObjEntity[] roots = map.getObjEntities().toArray(new ObjEntity[0]);
+
+        if (roots.length > 1) {
+            Arrays.sort(roots, Comparators.getDataMapChildrenComparator());
+        }
+
+        DefaultComboBoxModel<ObjEntity> model = new DefaultComboBoxModel<>(roots);
+        model.setSelectedItem(query.getRoot());
+        queryRoot.setModel(model);
 
         setVisible(true);
     }
 
+    @Override
     protected QueryDescriptor getQuery() {
         QueryDescriptor query = mediator.getCurrentQuery();
         return (query != null && QueryDescriptor.SQL_TEMPLATE.equals(query.getType())) ? query : null;
     }
 
-    /**
-     * Initializes Query name from string.
-     */
-    void setQueryName(String newName) {
-        if (newName != null && newName.trim().length() == 0) {
-            newName = null;
-        }
-
-        QueryDescriptor query = getQuery();
-
-        if (query == null) {
-            return;
-        }
-
-        if (Util.nullSafeEquals(newName, query.getName())) {
-            return;
-        }
-
-        if (newName == null) {
-            throw new ValidationException("Query name is required.");
-        }
-
-        DataMap map = mediator.getCurrentDataMap();
-
-        if (map.getQueryDescriptor(newName) == null) {
-            // completely new name, set new name for entity
-            QueryEvent e = new QueryEvent(this, query, query.getName());
-            ProjectUtil.setQueryName(map, query, newName);
-            mediator.fireQueryEvent(e);
-        }
-        else {
-            // there is a query with the same name
-            throw new ValidationException("There is another query named '"
-                    + newName
-                    + "'. Use a different name.");
-        }
-    }
-
     /**
      * Returns an entity that maps to a procedure query result class.
      */
@@ -183,8 +172,21 @@ public class SQLTemplateMainTab extends JPanel {
         }
     }
 
-    final class LabelCapsRenderer extends DefaultListCellRenderer {
+    private void setQueryComment(String text) {
+        QueryDescriptor query = getQuery();
+        if (query == null) {
+            return;
+        }
+        ObjectInfo.putToMetaData(mediator.getApplication().getMetaData(), query, ObjectInfo.COMMENT, text);
+        mediator.fireQueryEvent(new QueryEvent(this, query));
+    }
 
+    private String getQueryComment(QueryDescriptor queryDescriptor) {
+        return ObjectInfo.getFromMetaData(mediator.getApplication().getMetaData(), queryDescriptor, ObjectInfo.COMMENT);
+    }
+
+    final class LabelCapsRenderer extends DefaultListCellRenderer {
+        @Override
         public Component getListCellRendererComponent(
                 JList list,
                 Object object,
@@ -198,22 +200,20 @@ public class SQLTemplateMainTab extends JPanel {
 
     final class SQLTemplateQueryPropertiesPanel extends RawQueryPropertiesPanel {
 
-        private JComboBox labelCase;
+        private JComboBox<CapsStrategy> labelCase;
 
         SQLTemplateQueryPropertiesPanel(ProjectController mediator) {
             super(mediator);
         }
 
+        @Override
         protected PanelBuilder createPanelBuilder() {
             labelCase = Application.getWidgetFactory().createUndoableComboBox();
             labelCase.setRenderer(new LabelCapsRenderer());
 
-            labelCase.addActionListener(new ActionListener() {
-
-                public void actionPerformed(ActionEvent event) {
-                    CapsStrategy value = (CapsStrategy) labelCase.getModel().getSelectedItem();
-                    setQueryProperty(SQLTemplate.COLUMN_NAME_CAPITALIZATION_PROPERTY, value.name());
-                }
+            labelCase.addActionListener(event -> {
+                CapsStrategy value = (CapsStrategy) labelCase.getModel().getSelectedItem();
+                setQueryProperty(SQLTemplate.COLUMN_NAME_CAPITALIZATION_PROPERTY, value.name());
             });
 
             PanelBuilder builder = super.createPanelBuilder();
@@ -230,25 +230,27 @@ public class SQLTemplateMainTab extends JPanel {
             return builder;
         }
 
+        @Override
         public void initFromModel(QueryDescriptor query) {
             super.initFromModel(query);
 
             if (query != null && QueryDescriptor.SQL_TEMPLATE.equals(query.getType())) {
-                DefaultComboBoxModel labelCaseModel = new DefaultComboBoxModel(
-                        LABEL_CAPITALIZATION);
-
+                DefaultComboBoxModel<CapsStrategy> labelCaseModel = new DefaultComboBoxModel<>(LABEL_CAPITALIZATION);
                 String columnNameCapitalization = query.getProperty(SQLTemplate.COLUMN_NAME_CAPITALIZATION_PROPERTY);
 
-                labelCaseModel.setSelectedItem(columnNameCapitalization != null ?
-                        CapsStrategy.valueOf(columnNameCapitalization) : CapsStrategy.DEFAULT);
+                labelCaseModel.setSelectedItem(columnNameCapitalization != null
+                        ? CapsStrategy.valueOf(columnNameCapitalization)
+                        : CapsStrategy.DEFAULT);
                 labelCase.setModel(labelCaseModel);
             }
         }
 
+        @Override
         protected void setEntity(ObjEntity entity) {
             SQLTemplateMainTab.this.setEntity(entity);
         }
 
+        @Override
         public ObjEntity getEntity(QueryDescriptor query) {
             if (query != null && QueryDescriptor.SQL_TEMPLATE.equals(query.getType())) {
                 return SQLTemplateMainTab.this.getEntity(query);
@@ -264,5 +266,5 @@ public class SQLTemplateMainTab extends JPanel {
                 setEntity(null);
             }
         }
-    };
+    }
 }
