@@ -20,17 +20,11 @@
 package org.apache.cayenne.modeler.editor;
 
 import java.awt.BorderLayout;
-import java.awt.event.ActionEvent;
-import java.awt.event.ActionListener;
-import java.awt.event.FocusEvent;
-import java.awt.event.FocusListener;
 import java.util.Arrays;
 import java.util.Iterator;
 
 import javax.swing.DefaultComboBoxModel;
 import javax.swing.JCheckBox;
-import javax.swing.JComboBox;
-import javax.swing.JPanel;
 import javax.swing.JTextField;
 
 import org.apache.cayenne.configuration.event.QueryEvent;
@@ -42,16 +36,14 @@ import org.apache.cayenne.map.Entity;
 import org.apache.cayenne.map.ObjEntity;
 import org.apache.cayenne.map.QueryDescriptor;
 import org.apache.cayenne.map.SelectQueryDescriptor;
-import org.apache.cayenne.modeler.Application;
+import org.apache.cayenne.query.SelectQuery;
+import org.apache.cayenne.swing.components.JCayenneCheckBox;
 import org.apache.cayenne.modeler.ProjectController;
-import org.apache.cayenne.modeler.util.CellRenderers;
 import org.apache.cayenne.modeler.util.Comparators;
 import org.apache.cayenne.modeler.util.ExpressionConvertor;
-import org.apache.cayenne.modeler.util.ProjectUtil;
 import org.apache.cayenne.modeler.util.TextAdapter;
 import org.apache.cayenne.modeler.util.ValidatorTextAdapter;
-import org.apache.cayenne.modeler.util.combo.AutoCompletion;
-import org.apache.cayenne.query.*;
+import org.apache.cayenne.project.extension.info.ObjectInfo;
 import org.apache.cayenne.util.CayenneMapEntry;
 import org.apache.cayenne.util.Util;
 import org.apache.cayenne.validation.ValidationException;
@@ -64,19 +56,17 @@ import com.jgoodies.forms.layout.FormLayout;
  * A tabbed pane that contains editors for various SelectQuery parts.
  * 
  */
-public class SelectQueryMainTab extends JPanel {
+public class SelectQueryMainTab extends BaseQueryMainTab {
 
-    protected ProjectController mediator;
-
-    protected TextAdapter name;
-    protected JComboBox<ObjEntity> queryRoot;
+    protected TextAdapter comment;
     protected TextAdapter qualifier;
     protected JCheckBox distinct;
     protected ObjectQueryPropertiesPanel properties;
 
     public SelectQueryMainTab(ProjectController mediator) {
-        this.mediator = mediator;
+        super(mediator);
 
+        initQueryRoot();
         initView();
         initController();
     }
@@ -91,10 +81,6 @@ public class SelectQueryMainTab extends JPanel {
             }
         };
 
-        queryRoot = Application.getWidgetFactory().createComboBox();
-        AutoCompletion.enable(queryRoot);
-        queryRoot.setRenderer(CellRenderers.listRendererWithIcons());
-
         qualifier = new ValidatorTextAdapter(new JTextField()) {
 
             @Override
@@ -108,7 +94,14 @@ public class SelectQueryMainTab extends JPanel {
             }
         };
 
-        distinct = new JCheckBox();
+        comment = new TextAdapter(new JTextField()) {
+            @Override
+            protected void updateModel(String text) {
+                setQueryComment(text);
+            }
+        };
+
+        distinct = new JCayenneCheckBox();
 
         properties = new ObjectQueryPropertiesPanel(mediator);
 
@@ -116,7 +109,7 @@ public class SelectQueryMainTab extends JPanel {
         CellConstraints cc = new CellConstraints();
         FormLayout layout = new FormLayout(
                 "right:max(80dlu;pref), 3dlu, fill:200dlu",
-                "p, 3dlu, p, 3dlu, p, 3dlu, p, 3dlu, p");
+                "p, 3dlu, p, 3dlu, p, 3dlu, p, 3dlu, p, 3dlu, p");
         PanelBuilder builder = new PanelBuilder(layout);
         builder.setDefaultDialogBorder();
 
@@ -129,6 +122,8 @@ public class SelectQueryMainTab extends JPanel {
         builder.add(qualifier.getComponent(), cc.xy(3, 7));
         builder.addLabel("Distinct:", cc.xy(1, 9));
         builder.add(distinct, cc.xy(3, 9));
+        builder.addLabel("Comment:", cc.xy(1, 11));
+        builder.add(comment.getComponent(), cc.xy(3, 11));
 
         this.setLayout(new BorderLayout());
         this.add(builder.getPanel(), BorderLayout.NORTH);
@@ -136,23 +131,13 @@ public class SelectQueryMainTab extends JPanel {
     }
 
     private void initController() {
-        RootSelectionHandler rootHandler = new RootSelectionHandler();
-
-        queryRoot.addActionListener(rootHandler);
-        queryRoot.addFocusListener(rootHandler);
-        queryRoot.getEditor().getEditorComponent().addFocusListener(rootHandler);
-
-        distinct.addActionListener(new ActionListener() {
-
-            public void actionPerformed(ActionEvent event) {
-                QueryDescriptor query = getQuery();
-                if (query != null) {
-                    query.setProperty(SelectQuery.DISTINCT_PROPERTY, Boolean.toString(distinct.isSelected()));
-                    mediator.fireQueryEvent(new QueryEvent(this, query));
-                }
+        distinct.addItemListener(e -> {
+            QueryDescriptor query = getQuery();
+            if (query != null) {
+                query.setProperty(SelectQuery.DISTINCT_PROPERTY, Boolean.toString(distinct.isSelected()));
+                mediator.fireQueryEvent(new QueryEvent(this, query));
             }
         });
-
     }
 
     /**
@@ -174,6 +159,7 @@ public class SelectQueryMainTab extends JPanel {
         qualifier.setText(query.getQualifier() != null ? query
                 .getQualifier()
                 .toString() : null);
+        comment.setText(getQueryComment(query));
 
         // init root choices and title label..
 
@@ -199,6 +185,7 @@ public class SelectQueryMainTab extends JPanel {
         setVisible(true);
     }
 
+    @Override
     protected SelectQueryDescriptor getQuery() {
         if(mediator.getCurrentQuery() == null) {
             return null;
@@ -260,45 +247,6 @@ public class SelectQueryMainTab extends JPanel {
         }
     }
 
-    /**
-     * Initializes Query name from string.
-     */
-    void setQueryName(String newName) {
-        if (newName != null && newName.trim().length() == 0) {
-            newName = null;
-        }
-
-        QueryDescriptor query = getQuery();
-
-        if (query == null) {
-            return;
-        }
-
-        if (Util.nullSafeEquals(newName, query.getName())) {
-            return;
-        }
-
-        if (newName == null) {
-            throw new ValidationException("SelectQuery name is required.");
-        }
-
-        DataMap map = mediator.getCurrentDataMap();
-        QueryDescriptor matchingQuery = map.getQueryDescriptor(newName);
-
-        if (matchingQuery == null) {
-            // completely new name, set new name for entity
-            QueryEvent e = new QueryEvent(this, query, query.getName());
-            ProjectUtil.setQueryName(map, query, newName);
-            mediator.fireQueryEvent(e);
-        }
-        else if (matchingQuery != query) {
-            // there is a query with the same name
-            throw new ValidationException("There is another query named '"
-                    + newName
-                    + "'. Use a different name.");
-        }
-    }
-
     /**
      * Advanced checking of an expression, needed because Expression.fromString()
      * might terminate normally, but returned Expression will not be appliable
@@ -335,74 +283,17 @@ public class SelectQueryMainTab extends JPanel {
             throw new ValidationException(eex.getUnlabeledMessage());
         }
     }
-    
-    /**
-     * Handler to user's actions with root selection combobox
-     */
-    class RootSelectionHandler implements FocusListener, ActionListener {
-        String newName = null;
-        boolean needChangeName;
 
-        public void actionPerformed(ActionEvent ae) {
-            QueryDescriptor query = getQuery();
-            if (query != null) {
-                Entity root = (Entity) queryRoot.getModel().getSelectedItem();
-
-                if (root != null) {
-                    query.setRoot(root);
-                    
-                    if (needChangeName) { //not changed by user
-                        /*
-                         * Doing auto name change, following CAY-888 #2
-                         */
-                        String newPrefix = root.getName() + "Query";
-                        newName = newPrefix;
-                        
-                        DataMap map = mediator.getCurrentDataMap();
-                        long postfix = 1;
-                        
-                        while (map.getQueryDescriptor(newName) != null) {
-                            newName = newPrefix + (postfix++);
-                        }
-                        
-                        name.setText(newName);
-                    }
-                }
-            }
+    private void setQueryComment(String text) {
+        QueryDescriptor query = getQuery();
+        if (query == null) {
+            return;
         }
+        ObjectInfo.putToMetaData(mediator.getApplication().getMetaData(), query, ObjectInfo.COMMENT, text);
+        mediator.fireQueryEvent(new QueryEvent(this, query));
+    }
 
-        public void focusGained(FocusEvent e) {
-            //reset new name tracking
-            newName = null;
-            
-            QueryDescriptor query = getQuery();
-            if (query != null) {
-                needChangeName = hasDefaultName(query);
-            } else {
-                needChangeName = false;
-            }
-        }
-
-        public void focusLost(FocusEvent e) {
-            if (newName != null) {
-                setQueryName(newName);
-            }
-            
-            newName = null;
-            needChangeName = false;
-        }
-
-        /**
-         * @return whether specified's query name is 'default' i.e. Cayenne generated
-         * A query's name is 'default' if it starts with 'UntitledQuery' or with root name.
-         * 
-         * We cannot follow user input because tab might be opened many times
-         */
-        boolean hasDefaultName(QueryDescriptor query) {
-            String prefix = query.getRoot() == null ? "UntitledQuery" :
-                CellRenderers.asString(query.getRoot()) + "Query";
-            
-            return name.getComponent().getText().startsWith(prefix);
-        }
+    private String getQueryComment(QueryDescriptor queryDescriptor) {
+        return ObjectInfo.getFromMetaData(mediator.getApplication().getMetaData(), queryDescriptor, ObjectInfo.COMMENT);
     }
 }
