@@ -28,21 +28,18 @@ import org.apache.cayenne.modeler.Application;
 import org.apache.cayenne.modeler.ProjectController;
 import org.apache.cayenne.modeler.util.CayenneTableModel;
 import org.apache.cayenne.modeler.util.ProjectUtil;
+import org.apache.cayenne.project.extension.info.ObjectInfo;
 
 import javax.swing.JOptionPane;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
-import java.util.Comparator;
-import java.util.Iterator;
 import java.util.List;
 
 /**
- * Model for DbEntity attributes. Allows adding/removing attributes, modifying types and
- * names.
- * 
+ * Model for DbEntity attributes. Allows adding/removing attributes, modifying types and names.
  */
-public class DbAttributeTableModel extends CayenneTableModel {
+public class DbAttributeTableModel extends CayenneTableModel<DbAttribute> {
 
     // Columns
     private static final int DB_ATTRIBUTE_NAME = 0;
@@ -51,19 +48,19 @@ public class DbAttributeTableModel extends CayenneTableModel {
     private static final int DB_ATTRIBUTE_MANDATORY = 3;
     private static final int DB_ATTRIBUTE_MAX = 4;
     private static final int DB_ATTRIBUTE_SCALE = 5;
+    private static final int DB_ATTRIBUTE_COMMENT = 6;
 
     protected DbEntity entity;
 
     public DbAttributeTableModel(DbEntity entity, ProjectController mediator,
             Object eventSource) {
-        this(entity, mediator, eventSource, new ArrayList<DbAttribute>(entity
-                .getAttributes()));
-        this.entity = entity;
+        this(entity, mediator, eventSource, new ArrayList<>(entity.getAttributes()));
     }
 
     public DbAttributeTableModel(DbEntity entity, ProjectController mediator,
             Object eventSource, List<DbAttribute> objectList) {
         super(mediator, eventSource, objectList);
+        this.entity = entity;
     }
 
     public int nameColumnInd() {
@@ -98,12 +95,12 @@ public class DbAttributeTableModel extends CayenneTableModel {
      * Returns the number of columns in the table.
      */
     public int getColumnCount() {
-        return 6;
+        return 7;
     }
 
     public DbAttribute getAttribute(int row) {
         return (row >= 0 && row < objectList.size())
-                ? (DbAttribute) objectList.get(row)
+                ? objectList.get(row)
                 : null;
     }
 
@@ -121,6 +118,8 @@ public class DbAttributeTableModel extends CayenneTableModel {
                 return "Mandatory";
             case DB_ATTRIBUTE_MAX:
                 return "Max Length";
+            case DB_ATTRIBUTE_COMMENT:
+                return "Comment";
             default:
                 return "";
         }
@@ -157,6 +156,8 @@ public class DbAttributeTableModel extends CayenneTableModel {
                 return isMandatory(attr);
             case DB_ATTRIBUTE_MAX:
                 return getMaxLength(attr);
+            case DB_ATTRIBUTE_COMMENT:
+                return getComment(attr);
             default:
                 return "";
         }
@@ -174,7 +175,7 @@ public class DbAttributeTableModel extends CayenneTableModel {
             case DB_ATTRIBUTE_NAME:
                 e.setOldName(attr.getName());
                 attr.setName((String) newVal);
-                ((DbEntity) attr.getEntity()).dbAttributeChanged(e);
+                attr.getEntity().dbAttributeChanged(e);
                 
                 fireTableCellUpdated(row, col);
                 break;
@@ -195,6 +196,9 @@ public class DbAttributeTableModel extends CayenneTableModel {
             case DB_ATTRIBUTE_MAX:
                 setMaxLength((String) newVal, attr);
                 break;
+            case DB_ATTRIBUTE_COMMENT:
+                setComment((String) newVal, attr);
+                break;
         }
 
         mediator.fireDbAttributeEvent(e);
@@ -224,21 +228,22 @@ public class DbAttributeTableModel extends CayenneTableModel {
         return (attr.isMandatory()) ? Boolean.TRUE : Boolean.FALSE;
     }
 
+    public String getComment(DbAttribute attr) {
+        return ObjectInfo.getFromMetaData(mediator.getApplication().getMetaData(), attr, ObjectInfo.COMMENT);
+    }
+
     public void setMaxLength(String newVal, DbAttribute attr) {
         if (newVal == null || newVal.trim().length() <= 0) {
             attr.setMaxLength(-1);
-        }
-        else {
+        } else {
             try {
                 attr.setMaxLength(Integer.parseInt(newVal));
-            }
-            catch (NumberFormatException ex) {
+            } catch (NumberFormatException ex) {
                 JOptionPane.showMessageDialog(
-                        null,
+                        mediator.getView(),
                         "Invalid Max Length (" + newVal + "), only numbers are allowed",
                         "Invalid Maximum Length",
                         JOptionPane.ERROR_MESSAGE);
-                return;
             }
         }
     }
@@ -250,14 +255,12 @@ public class DbAttributeTableModel extends CayenneTableModel {
     public void setScale(String newVal, DbAttribute attr) {
         if (newVal == null || newVal.trim().length() <= 0) {
             attr.setScale(-1);
-        }
-        else {
+        } else {
             try {
                 attr.setScale(Integer.parseInt(newVal));
-            }
-            catch (NumberFormatException ex) {
+            } catch (NumberFormatException ex) {
                 JOptionPane.showMessageDialog(
-                        null,
+                        mediator.getView(),
                         "Invalid precision (" + newVal + "), only numbers are allowed.",
                         "Invalid Precision Value",
                         JOptionPane.ERROR_MESSAGE);
@@ -267,7 +270,7 @@ public class DbAttributeTableModel extends CayenneTableModel {
 
     public boolean setPrimaryKey(Boolean newVal, DbAttribute attr, int row) {
 
-        boolean flag = newVal.booleanValue();
+        boolean flag = newVal;
 
         // when PK is unset, we need to fix some derived flags
         if (!flag) {
@@ -280,21 +283,14 @@ public class DbAttributeTableModel extends CayenneTableModel {
                     .addAll(ProjectUtil.getRelationshipsUsingAttributeAsSource(attr));
 
             if (relationships.size() > 0) {
-                Iterator<DbRelationship> it = relationships.iterator();
-                while (it.hasNext()) {
-                    DbRelationship relationship = it.next();
-                    if (!relationship.isToDependentPK()) {
-                        it.remove();
-                    }
-                }
+                relationships.removeIf(relationship -> !relationship.isToDependentPK());
 
                 // filtered only those that are to dep PK
                 if (relationships.size() > 0) {
                     String message = (relationships.size() == 1)
                             ? "Fix \"To Dep PK\" relationship using this attribute?"
-                            : "Fix "
-                                    + relationships.size()
-                                    + " \"To Dep PK\" relationships using this attribute?";
+                            : "Fix " + relationships.size()
+                                     + " \"To Dep PK\" relationships using this attribute?";
 
                     int answer = JOptionPane.showConfirmDialog(
                             Application.getFrame(),
@@ -321,29 +317,30 @@ public class DbAttributeTableModel extends CayenneTableModel {
     }
 
     public void setMandatory(Boolean newVal, DbAttribute attr) {
-        attr.setMandatory(newVal.booleanValue());
+        attr.setMandatory(newVal);
     }
 
     public void setGenerated(Boolean newVal, DbAttribute attr) {
-        attr.setGenerated(newVal.booleanValue());
+        attr.setGenerated(newVal);
+    }
+
+    public void setComment(String newVal, DbAttribute attr) {
+        ObjectInfo.putToMetaData(mediator.getApplication().getMetaData(), attr, ObjectInfo.COMMENT, newVal);
     }
 
     public boolean isCellEditable(int row, int col) {
         DbAttribute attrib = getAttribute(row);
         if (null == attrib) {
             return false;
-        }
-        else if (col == mandatoryColumnInd()) {
-            if (attrib.isPrimaryKey()) {
-                return false;
-            }
+        } else if (col == mandatoryColumnInd()) {
+            return !attrib.isPrimaryKey();
         }
         return true;
     }
 
     @Override
     public boolean isColumnSortable(int sortCol) {
-        return true;
+        return sortCol != DB_ATTRIBUTE_COMMENT;
     }
 
     @Override
@@ -353,27 +350,20 @@ public class DbAttributeTableModel extends CayenneTableModel {
                 sortByElementProperty("name", isAscent);
                 break;
             case DB_ATTRIBUTE_TYPE:
-                Collections.sort(objectList, new Comparator<DbAttribute>() {
-
-                    public int compare(DbAttribute o1, DbAttribute o2) {
-                        if ((o1 == null && o2 == null) || o1 == o2) {
-                            return 0;
-                        }
-                        else if (o1 == null && o2 != null) {
-                            return -1;
-                        }
-                        else if (o1 != null && o2 == null) {
-                            return 1;
-                        }
-                        
-                        String attrType1 = getAttributeType(o1);
-                        String attrType2 = getAttributeType(o2);
-                        
-                        return (attrType1 == null) ? -1 : (attrType2 == null)
-                                ? 1
-                                : attrType1.compareTo(attrType2);
+                objectList.sort((o1, o2) -> {
+                    if (o1 == o2) {
+                        return 0;
+                    } else if (o1 == null) {
+                        return -1;
+                    } else if (o2 == null) {
+                        return 1;
                     }
 
+                    String attrType1 = getAttributeType(o1);
+                    String attrType2 = getAttributeType(o2);
+
+                    return (attrType1 == null) ? -1
+                            : (attrType2 == null) ? 1 : attrType1.compareTo(attrType2);
                 });
                 if (!isAscent) {
                     Collections.reverse(objectList);
