@@ -21,8 +21,6 @@ package org.apache.cayenne.modeler.editor.dbentity;
 
 import java.awt.BorderLayout;
 import java.awt.CardLayout;
-import java.awt.event.ItemEvent;
-import java.awt.event.ItemListener;
 import java.util.EventObject;
 import javax.swing.BorderFactory;
 import javax.swing.DefaultComboBoxModel;
@@ -53,6 +51,7 @@ import org.apache.cayenne.modeler.event.EntityDisplayEvent;
 import org.apache.cayenne.modeler.graph.action.ShowGraphEntityAction;
 import org.apache.cayenne.modeler.util.ExpressionConvertor;
 import org.apache.cayenne.modeler.util.TextAdapter;
+import org.apache.cayenne.project.extension.info.ObjectInfo;
 import org.apache.cayenne.util.Util;
 import org.apache.cayenne.validation.ValidationException;
 
@@ -74,6 +73,7 @@ public class DbEntityTab extends JPanel implements ExistingSelectionProcessor, D
     protected TextAdapter catalog;
     protected TextAdapter schema;
     protected TextAdapter qualifier;
+    protected TextAdapter comment;
 
     protected JLabel catalogLabel;
     protected JLabel schemaLabel;
@@ -137,6 +137,13 @@ public class DbEntityTab extends JPanel implements ExistingSelectionProcessor, D
             }
         };
 
+        comment = new TextAdapter(new JTextField()) {
+            @Override
+            protected void updateModel(String text) throws ValidationException {
+                setComment(text);
+            }
+        };
+
         pkGeneratorType = new JComboBox<>();
         pkGeneratorType.setEditable(false);
         pkGeneratorType.setModel(new DefaultComboBoxModel<>(PK_GENERATOR_TYPES));
@@ -156,7 +163,8 @@ public class DbEntityTab extends JPanel implements ExistingSelectionProcessor, D
         builder.append("DbEntity Name:", name.getComponent());
         builder.append(catalogLabel, catalog.getComponent());
         builder.append(schemaLabel, schema.getComponent());
-        builder.append("Qualifier", qualifier.getComponent());
+        builder.append("Qualifier:", qualifier.getComponent());
+        builder.append("Comment:", comment.getComponent());
 
         builder.appendSeparator("Primary Key");
         builder.append("PK Generation Strategy:", pkGeneratorType);
@@ -175,19 +183,16 @@ public class DbEntityTab extends JPanel implements ExistingSelectionProcessor, D
     private void initController() {
         mediator.addDbEntityDisplayListener(this);
 
-        pkGeneratorType.addItemListener(new ItemListener() {
+        pkGeneratorType.addItemListener(e -> {
+            pkGeneratorDetailLayout.show(pkGeneratorDetail, (String) pkGeneratorType.getSelectedItem());
 
-            public void itemStateChanged(ItemEvent e) {
-                pkGeneratorDetailLayout.show(pkGeneratorDetail, (String) pkGeneratorType.getSelectedItem());
+            for (int i = 0; i < pkGeneratorDetail.getComponentCount(); i++) {
+                if (pkGeneratorDetail.getComponent(i).isVisible()) {
 
-                for (int i = 0; i < pkGeneratorDetail.getComponentCount(); i++) {
-                    if (pkGeneratorDetail.getComponent(i).isVisible()) {
-
-                        DbEntity entity = mediator.getCurrentDbEntity();
-                        PKGeneratorPanel panel = (PKGeneratorPanel) pkGeneratorDetail.getComponent(i);
-                        panel.onInit(entity);
-                        break;
-                    }
+                    DbEntity entity = mediator.getCurrentDbEntity();
+                    PKGeneratorPanel panel = (PKGeneratorPanel) pkGeneratorDetail.getComponent(i);
+                    panel.onInit(entity);
+                    break;
                 }
             }
         });
@@ -215,6 +220,7 @@ public class DbEntityTab extends JPanel implements ExistingSelectionProcessor, D
         catalog.setText(entity.getCatalog());
         schema.setText(entity.getSchema());
         qualifier.setText(new ExpressionConvertor().valueAsString(entity.getQualifier()));
+        comment.setText(getComment(entity));
 
         String type = PK_DEFAULT_GENERATOR;
 
@@ -326,4 +332,19 @@ public class DbEntityTab extends JPanel implements ExistingSelectionProcessor, D
 
         }
     }
+
+    private String getComment(DbEntity entity) {
+        return ObjectInfo.getFromMetaData(mediator.getApplication().getMetaData(), entity, ObjectInfo.COMMENT);
+    }
+
+    private void setComment(String value) {
+        DbEntity entity = mediator.getCurrentDbEntity();
+
+        if(entity == null) {
+            return;
+        }
+
+        ObjectInfo.putToMetaData(mediator.getApplication().getMetaData(), entity, ObjectInfo.COMMENT, value);
+        mediator.fireDbEntityEvent(new EntityEvent(this, entity));
+    }
 }
