@@ -24,8 +24,6 @@ import java.awt.Font;
 import java.awt.Point;
 import java.awt.event.MouseAdapter;
 import java.awt.event.MouseEvent;
-import java.awt.event.MouseWheelEvent;
-import java.awt.event.MouseWheelListener;
 import java.awt.geom.Point2D;
 import java.awt.geom.Rectangle2D;
 import java.util.ArrayList;
@@ -39,6 +37,7 @@ import javax.swing.JPopupMenu;
 import javax.swing.border.LineBorder;
 import javax.swing.event.UndoableEditEvent;
 
+import org.apache.cayenne.configuration.ConfigurationNodeVisitor;
 import org.apache.cayenne.configuration.DataChannelDescriptor;
 import org.apache.cayenne.configuration.event.DataMapEvent;
 import org.apache.cayenne.configuration.event.DataMapListener;
@@ -56,6 +55,7 @@ import org.apache.cayenne.modeler.graph.action.EntityDisplayAction;
 import org.apache.cayenne.modeler.graph.action.RemoveEntityAction;
 import org.apache.cayenne.util.XMLEncoder;
 import org.jgraph.JGraph;
+import org.jgraph.graph.AttributeMap;
 import org.jgraph.graph.DefaultCellViewFactory;
 import org.jgraph.graph.DefaultEdge;
 import org.jgraph.graph.DefaultGraphCell;
@@ -72,7 +72,7 @@ import com.jgraph.layout.organic.JGraphOrganicLayout;
  */
 abstract class BaseGraphBuilder implements GraphBuilder, DataMapListener {
 
-    static final Font EDGE_FONT = new Font("Verdana", 0, 10);
+    static final Font EDGE_FONT = new Font("Verdana", Font.PLAIN, 10);
 
     /**
      * Graph
@@ -112,6 +112,7 @@ abstract class BaseGraphBuilder implements GraphBuilder, DataMapListener {
 
     boolean undoEventsDisabled;
 
+    @Override
     public void buildGraph(ProjectController mediator, DataChannelDescriptor domain, boolean doLayout) {
         if (graph != null) {
             // graph already built, exiting silently
@@ -128,31 +129,7 @@ abstract class BaseGraphBuilder implements GraphBuilder, DataMapListener {
         GraphLayoutCache view = new GraphLayoutCache(model, new DefaultCellViewFactory());
         graph.setGraphLayoutCache(view);
 
-        graph.addMouseListener(new MouseAdapter() {
-
-            public void mouseReleased(MouseEvent e) {
-                if (e.isPopupTrigger()) {
-                    Object selected = graph.getSelectionCell();
-                    if (selected != null && selected instanceof DefaultGraphCell) {
-                        Object userObject = ((DefaultGraphCell) selected).getUserObject();
-                        if (userObject instanceof EntityCellMetadata) {
-                            showPopup(e.getPoint(), ((EntityCellMetadata) userObject).fetchEntity());
-                        }
-                    }
-                }
-            }
-        });
-
-        graph.addMouseWheelListener(new MouseWheelListener() {
-
-            public void mouseWheelMoved(MouseWheelEvent e) {
-                // limit scale
-                double scale = graph.getScale() / Math.pow(ZOOM_FACTOR, e.getWheelRotation());
-                scale = Math.max(scale, 0.1);
-                scale = Math.min(scale, 3);
-                graph.setScale(scale);
-            }
-        });
+        addMouseListeners();
 
         entityCells = new HashMap<>();
         createdObjects = new ArrayList<>();
@@ -162,7 +139,7 @@ abstract class BaseGraphBuilder implements GraphBuilder, DataMapListener {
          * an array for entities that are not connected to anyone. We add them
          * separately so that layout doesn't touch them
          */
-        List<DefaultGraphCell> isolatedObjects = new ArrayList<DefaultGraphCell>();
+        List<DefaultGraphCell> isolatedObjects = new ArrayList<>();
 
         /*
          * 1. Add all entities
@@ -195,7 +172,24 @@ abstract class BaseGraphBuilder implements GraphBuilder, DataMapListener {
         }
         view.insert(createdObjects.toArray());
 
-        if (doLayout) {
+        setLayout(doLayout);
+
+        /*
+         * Adding isolated objects
+         * 
+         * We're placing them so that they will take maximum space in left top
+         * corner. The sample order is below:
+         * 
+         * 1 2 6 7... 3 5 8 ... 4 9... 10 ...
+         */
+        addIsolatedObjects(isolatedObjects);
+
+        view.insert(isolatedObjects.toArray());
+        graph.getModel().addUndoableEditListener(this);
+    }
+
+	private void setLayout(boolean doLayout) {
+		if (doLayout) {
             JGraphFacade facade = new JGraphFacade(graph);
 
             JGraphOrganicLayout layout = new JGraphOrganicLayout();
@@ -212,25 +206,41 @@ abstract class BaseGraphBuilder implements GraphBuilder, DataMapListener {
 
             // JGraphSimpleLayout layout = new JGraphSimpleLayout(JGraphSimpleLayout.TYPE_TILT, 4000, 2000);
             layout.run(facade);
-            Map nested = facade.createNestedMap(true, true); // Obtain a map of
-                                                             // the
-                                                             // resulting
-                                                             // attribute
-                                                             // changes from the
-                                                             // facade
+            // Obtain a map of the resulting attribute changes from the facade
+            Map nested = facade.createNestedMap(true, true);
 
-            edit(nested); // Apply the results to the actual graph
+            // Apply the results to the actual graph
+            edit(nested);
         }
+	}
 
-        /*
-         * Adding isolated objects
-         * 
-         * We're placing them so that they will take maximum space in left top
-         * corner. The sample order is below:
-         * 
-         * 1 2 6 7... 3 5 8 ... 4 9... 10 ...
-         */
-        if (isolatedObjects.size() > 0) {
+	private void addMouseListeners() {
+		graph.addMouseListener(new MouseAdapter() {
+            @Override
+            public void mouseReleased(MouseEvent e) {
+                if (e.isPopupTrigger()) {
+                    Object selected = graph.getSelectionCell();
+                    if (selected != null && selected instanceof DefaultGraphCell) {
+                        Object userObject = ((DefaultGraphCell) selected).getUserObject();
+                        if (userObject instanceof EntityCellMetadata) {
+                            showPopup(e.getPoint(), ((EntityCellMetadata) userObject).fetchEntity());
+                        }
+                    }
+                }
+            }
+        });
+		
+		graph.addMouseWheelListener(e -> {
+            // limit scale
+            double scale = graph.getScale() / Math.pow(ZOOM_FACTOR, e.getWheelRotation());
+            scale = Math.max(scale, 0.1);
+            scale = Math.min(scale, 3);
+            graph.setScale(scale);
+        });
+	}
+
+	private void addIsolatedObjects(List<DefaultGraphCell> isolatedObjects) {
+		if (isolatedObjects.size() > 0) {
             int n = isolatedObjects.size() / 2; // number of isolated entities
             int x = (int) Math.ceil((Math.sqrt(1 + 8 * n) - 1) / 2); // side of
                                                                      // triangle
@@ -256,10 +266,7 @@ abstract class BaseGraphBuilder implements GraphBuilder, DataMapListener {
                 row++;
             }
         }
-
-        view.insert(isolatedObjects.toArray());
-        graph.getModel().addUndoableEditListener(this);
-    }
+	}
 
     protected DefaultGraphCell createEntityCell(Entity entity) {
         DefaultGraphCell cell = new DefaultGraphCell(getCellMetadata(entity));
@@ -274,6 +281,7 @@ abstract class BaseGraphBuilder implements GraphBuilder, DataMapListener {
         return cell;
     }
 
+    @Override
     public DefaultGraphCell getEntityCell(String entityName) {
         return entityCells.get(entityName);
     }
@@ -342,6 +350,7 @@ abstract class BaseGraphBuilder implements GraphBuilder, DataMapListener {
         popup.show(graph, p.x, p.y);
     }
 
+    @Override
     public Entity getSelectedEntity() {
         return selectedEntity;
     }
@@ -372,7 +381,7 @@ abstract class BaseGraphBuilder implements GraphBuilder, DataMapListener {
             GraphConstants.setValue(cell.getAttributes(), getCellMetadata(e));
             GraphConstants.setResize(cell.getAttributes(), true);
 
-            Map nested = new HashMap();
+            Map<DefaultGraphCell, AttributeMap> nested = new HashMap<>();
             nested.put(cell, cell.getAttributes());
 
             edit(nested);
@@ -385,7 +394,7 @@ abstract class BaseGraphBuilder implements GraphBuilder, DataMapListener {
             if (edge != null) {
                 updateRelationshipLabels(edge, rel, rel.getReverseRelationship());
 
-                Map nested = new HashMap();
+                Map<DefaultEdge, AttributeMap> nested = new HashMap<>();
                 nested.put(edge, edge.getAttributes());
                 edit(nested);
             } else {
@@ -397,12 +406,7 @@ abstract class BaseGraphBuilder implements GraphBuilder, DataMapListener {
     protected void removeEntityCell(Entity e) {
         final DefaultGraphCell cell = entityCells.get(e.getName());
         if (cell != null) {
-            runWithUndoDisabled(new Runnable() {
-
-                public void run() {
-                    graph.getGraphLayoutCache().remove(new Object[] { cell }, true, true);
-                }
-            });
+            runWithUndoDisabled(() -> graph.getGraphLayoutCache().remove(new Object[] { cell }, true, true));
             entityCells.remove(e.getName());
         }
     }
@@ -410,12 +414,7 @@ abstract class BaseGraphBuilder implements GraphBuilder, DataMapListener {
     protected void removeRelationshipCell(Relationship rel) {
         final DefaultEdge edge = relCells.get(getQualifiedName(rel));
         if (edge != null) {
-            runWithUndoDisabled(new Runnable() {
-
-                public void run() {
-                    graph.getGraphLayoutCache().remove(new Object[] { edge });
-                }
-            });
+            runWithUndoDisabled(() -> graph.getGraphLayoutCache().remove(new Object[] { edge }));
             relCells.remove(getQualifiedName(rel));
         }
     }
@@ -481,21 +480,27 @@ abstract class BaseGraphBuilder implements GraphBuilder, DataMapListener {
                 reverse == null ? "" : reverse.getName() + " " + getRelationshipLabel(reverse) };
         GraphConstants.setExtraLabels(edge.getAttributes(), labels);
 
-        Point2D[] labelPositions = { new Point2D.Double(GraphConstants.PERMILLE * (0.1 + 0.2 * Math.random()), 10),
-                new Point2D.Double(GraphConstants.PERMILLE * (0.9 - 0.2 * Math.random()), -10) };
+        Point2D[] labelPositions = {
+                new Point2D.Double(GraphConstants.PERMILLE * (0.1 + 0.2 * Math.random()), 10),
+                new Point2D.Double(GraphConstants.PERMILLE * (0.9 - 0.2 * Math.random()), -10)
+        };
         GraphConstants.setExtraLabelPositions(edge.getAttributes(), labelPositions);
     }
 
+    @Override
     public JGraph getGraph() {
         return graph;
     }
 
+    @Override
     public void dataMapAdded(DataMapEvent e) {
     }
 
+    @Override
     public void dataMapChanged(DataMapEvent e) {
     }
 
+    @Override
     public void dataMapRemoved(DataMapEvent e) {
         for (Entity entity : getEntities(e.getDataMap())) {
             removeEntityCell(entity);
@@ -512,10 +517,12 @@ abstract class BaseGraphBuilder implements GraphBuilder, DataMapListener {
         this.domain = domain;
     }
 
+    @Override
     public DataChannelDescriptor getDataDomain() {
         return domain;
     }
 
+    @Override
     public void destroy() {
         mediator.removeDataMapListener(this);
     }
@@ -547,53 +554,33 @@ abstract class BaseGraphBuilder implements GraphBuilder, DataMapListener {
         return rel.getSourceEntity().getName() + "." + rel.getName();
     }
 
-    public void encodeAsXML(XMLEncoder encoder) {
-        encoder.print("<graph type=\"");
-        encoder.print(getType().toString());
-        encoder.print("\" scale=\"");
-        encoder.print(String.valueOf(graph.getScale()));
-        encoder.println("\">");
-        encoder.indent(1);
+    @Override
+    public void encodeAsXML(XMLEncoder encoder, ConfigurationNodeVisitor delegate) {
+        encoder.start("graph")
+                .attribute("type", getType().toString())
+                .attribute("scale", String.valueOf(graph.getScale()));
 
         for (Entry<String, DefaultGraphCell> entry : entityCells.entrySet()) {
-            encoder.print("<entity name=\"");
-            encoder.print(entry.getKey());
-            encoder.print("\" ");
+            Rectangle2D rect = graph.getCellBounds(entry.getValue());
 
-            DefaultGraphCell cell = entry.getValue();
-            Rectangle2D rect = graph.getCellBounds(cell);
-            encodeRecangle(encoder, rect);
-            encoder.println("/>");
+            encoder.start("entity")
+                    .attribute("name", entry.getKey())
+                    .attribute("x", String.valueOf(Math.round(100 * rect.getX()) / 100.0))
+                    .attribute("y", String.valueOf(Math.round(100 * rect.getY()) / 100.0))
+                    .attribute("width", String.valueOf(rect.getWidth()))
+                    .attribute("height", String.valueOf(rect.getHeight()))
+                    .end();
         }
 
-        encoder.indent(-1);
-        encoder.println("</graph>");
-    }
-
-    private void encodeRecangle(XMLEncoder encoder, Rectangle2D rect) {
-        encoder.print("x=\"");
-        encoder.print(rect.getX() + "\" y=\"");
-        encoder.print(rect.getY() + "\" width=\"");
-        encoder.print(rect.getWidth() + "\" height=\"");
-        encoder.print(rect.getHeight() + "\" ");
+        encoder.end();
     }
 
     private void edit(final Map map) {
-        runWithUndoDisabled(new Runnable() {
-
-            public void run() {
-                graph.getGraphLayoutCache().edit(map);
-            }
-        });
+        runWithUndoDisabled(() -> graph.getGraphLayoutCache().edit(map));
     }
 
     private void insert(final Object cell) {
-        runWithUndoDisabled(new Runnable() {
-
-            public void run() {
-                graph.getGraphLayoutCache().insert(cell);
-            }
-        });
+        runWithUndoDisabled(() -> graph.getGraphLayoutCache().insert(cell));
     }
 
     private void runWithUndoDisabled(Runnable r) {
@@ -605,6 +592,7 @@ abstract class BaseGraphBuilder implements GraphBuilder, DataMapListener {
         }
     }
 
+    @Override
     public void undoableEditHappened(UndoableEditEvent e) {
         if (!undoEventsDisabled) {
             // graph has been modified
