@@ -50,7 +50,8 @@ public class PasteUndoableEdit extends CayenneUndoableEdit {
     private Object where;
     private Object content;
 
-    public PasteUndoableEdit(DataChannelDescriptor domain, DataMap map, Object where, Object content) {
+    public PasteUndoableEdit(DataChannelDescriptor domain, DataMap map, Object where,
+            Object content) {
         this.domain = domain;
         this.map = map;
         this.where = where;
@@ -70,15 +71,23 @@ public class PasteUndoableEdit extends CayenneUndoableEdit {
     @Override
     public void redo() throws CannotRedoException {
         PasteAction action = actionManager.getAction(PasteAction.class);
+
         action.paste(where, content, domain, map);
     }
 
     @Override
     public void undo() throws CannotUndoException {
+        RemoveAttributeAction rAttributeAction = actionManager
+                .getAction(RemoveAttributeAction.class);
+
         RemoveAction rAction = actionManager.getAction(RemoveAction.class);
-        RemoveAttributeAction rAttributeAction = actionManager.getAction(RemoveAttributeAction.class);
-        RemoveRelationshipAction rRelationShipAction = actionManager.getAction(RemoveRelationshipAction.class);
-        RemoveCallbackMethodAction rCallbackMethodAction = actionManager.getAction(RemoveCallbackMethodAction.class);
+
+        RemoveRelationshipAction rRelationShipAction = actionManager
+                .getAction(RemoveRelationshipAction.class);
+
+        RemoveCallbackMethodAction rCallbackMethodAction = actionManager
+                .getAction(RemoveCallbackMethodAction.class);
+
         RemoveProcedureParameterAction rProcedureParamAction = actionManager
                 .getAction(RemoveProcedureParameterAction.class);
 
@@ -110,13 +119,13 @@ public class PasteUndoableEdit extends CayenneUndoableEdit {
                         map,
                         (DbEntity) where,
                         new DbAttribute[] {
-                                (DbAttribute) content
+                            (DbAttribute) content
                         });
             } else if (content instanceof DbRelationship) {
                 rRelationShipAction.removeDbRelationships(
                         (DbEntity) where,
                         new DbRelationship[] {
-                                (DbRelationship) content
+                            (DbRelationship) content
                         });
             }
         } else if (where instanceof ObjEntity) {
@@ -126,22 +135,22 @@ public class PasteUndoableEdit extends CayenneUndoableEdit {
                 rAttributeAction.removeObjAttributes(
                         (ObjEntity) where,
                         new ObjAttribute[] {
-                                (ObjAttribute) content
+                            (ObjAttribute) content
                         });
             } else if (content instanceof ObjRelationship) {
                 rRelationShipAction.removeObjRelationships(
                         (ObjEntity) where,
                         new ObjRelationship[] {
-                                (ObjRelationship) content
+                            (ObjRelationship) content
                         });
             } else if (content instanceof ObjCallbackMethod) {
-                ObjCallbackMethod[] methods = new ObjCallbackMethod[] {
-                        (ObjCallbackMethod) content };
-                for(ObjCallbackMethod callbackMethod : methods) {
-                    rCallbackMethodAction.removeCallbackMethod(
-                            methods[0].getCallbackType(),
-                            callbackMethod.getName());
-                }
+            		ObjCallbackMethod[] methods = new ObjCallbackMethod[] {
+                            (ObjCallbackMethod) content };
+            		for(ObjCallbackMethod callbackMethod : methods) {
+	            		rCallbackMethodAction.removeCallbackMethod(
+	                			methods[0].getCallbackType(), 
+	                			callbackMethod.getName());
+            		}
             }
         } else if (where instanceof Procedure) {
             final Procedure procedure = (Procedure) where;
@@ -149,18 +158,15 @@ public class PasteUndoableEdit extends CayenneUndoableEdit {
                 rProcedureParamAction.removeProcedureParameters(
                         procedure,
                         new ProcedureParameter[] {
-                                (ProcedureParameter) content
+                            (ProcedureParameter) content
                         });
             }
         } else if (where instanceof Embeddable) {
             if (content instanceof Embeddable) {
                 rAction.removeEmbeddable(map, (Embeddable) content);
             } else if (content instanceof EmbeddableAttribute) {
-                rAttributeAction.removeEmbeddableAttributes(
-                        (Embeddable) where,
-                        new EmbeddableAttribute[]{
-                            (EmbeddableAttribute) content
-                        });
+                rAttributeAction.removeEmbeddableAttributes((Embeddable) where,
+                        new EmbeddableAttribute[]{(EmbeddableAttribute) content});
             }
         }
     }
