@@ -22,7 +22,6 @@ package org.apache.cayenne.modeler.util;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
-import java.util.Iterator;
 import java.util.List;
 
 import org.apache.cayenne.configuration.DataChannelDescriptor;
@@ -87,7 +86,7 @@ public class ProjectUtil {
         }
     }
 
-    public static void setDataNodeName(DataChannelDescriptor domain, DataNodeDescriptor node, String newName) {
+    public static void setDataNodeName(DataNodeDescriptor node, String newName) {
         node.setName(newName);
     }
 
@@ -464,21 +463,18 @@ public class ProjectUtil {
                                                                                DbRelationship relationship) {
         DataChannelDescriptor domain = (DataChannelDescriptor) mediator.getProject().getRootNode();
         List<ObjAttribute> attributes = new ArrayList<>();
-        String[] dbAttrPathByDot;
         if (domain != null) {
             for (DataMap map : domain.getDataMaps()) {
                 for (ObjEntity entity : map.getObjEntities()) {
                     for (ObjAttribute objAttribute : entity.getAttributes()) {
                         if(objAttribute.isFlattened()) {
-                            Iterator<?> it = objAttribute.getDbPathIterator();
-                            while(it.hasNext()) {
-                                Object entry = it.next();
+                            objAttribute.getDbPathIterator().forEachRemaining(entry -> {
                                 if(entry instanceof DbRelationship) {
                                     if(entry.equals(relationship)) {
                                         attributes.add(objAttribute);
                                     }
                                 }
-                            }
+                            });
                         }
                     }
                 }
